@@ -1,16 +1,15 @@
-/* Copyright (c) 2002, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2002, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    Without limiting anything contained in the foregoing, this file,
    which is part of C Driver for MySQL (Connector/C), is also subject to the
@@ -40,7 +39,6 @@
 #include <bitset>
 #include <type_traits>
 
-#include "m_ctype.h"
 #include "m_string.h"
 #include "my_compiler.h"
 #include "my_dbug.h"
@@ -48,12 +46,16 @@
 #include "my_getopt.h"
 #include "my_inttypes.h"
 #include "my_io.h"
-#include "my_loglevel.h"
 #include "my_macros.h"
+#include "mysql/my_loglevel.h"
 #include "mysql/service_mysql_alloc.h"
+#include "mysql/strings/dtoa.h"
+#include "mysql/strings/int2str.h"
+#include "mysql/strings/m_ctype.h"
 #include "mysql_version.h"  // MYSQL_PERSIST_CONFIG_NAME
 #include "mysys/mysys_priv.h"
 #include "mysys_err.h"
+#include "strmake.h"
 #include "typelib.h"
 
 typedef void (*init_func_p)(const struct my_option *option, void *variable,
@@ -819,7 +821,7 @@ static int setval(const struct my_option *opts, void *value,
                   const char *argument, bool set_maximum_value,
                   bool boolean_as_int) {
   int err = 0, res = 0;
-  ulong var_type = opts->var_type & GET_TYPE_MASK;
+  const ulong var_type = opts->var_type & GET_TYPE_MASK;
 
   if (!argument) argument = enabled_my_option;
 
@@ -908,13 +910,13 @@ static int setval(const struct my_option *opts, void *value,
         };
         break;
       case GET_ENUM: {
-        int type = find_type(argument, opts->typelib, FIND_TYPE_BASIC);
+        const int type = find_type(argument, opts->typelib, FIND_TYPE_BASIC);
         if (type == 0) {
           /*
             Accept an integer representation of the enumerated item.
           */
           char *endptr;
-          ulong arg = strtoul(argument, &endptr, 10);
+          const ulong arg = strtoul(argument, &endptr, 10);
           if (*endptr || arg >= opts->typelib->count) {
             res = EXIT_ARGUMENT_INVALID;
             goto ret;
@@ -932,7 +934,7 @@ static int setval(const struct my_option *opts, void *value,
         if (err) {
           /* Accept an integer representation of the set */
           char *endptr;
-          ulonglong arg = (ulonglong)strtol(argument, &endptr, 10);
+          const ulonglong arg = (ulonglong)strtol(argument, &endptr, 10);
           if (*endptr || (arg >> 1) >= (1ULL << (opts->typelib->count - 1))) {
             res = EXIT_ARGUMENT_INVALID;
             goto ret;
@@ -1186,10 +1188,11 @@ ulonglong max_of_int_range(int var_type) {
 
 longlong getopt_ll_limit_value(longlong num, const struct my_option *optp,
                                bool *fix) {
-  longlong old = num;
+  const longlong old = num;
   bool adjusted = false;
   char buf1[255], buf2[255];
-  ulonglong block_size = (optp->block_size ? (ulonglong)optp->block_size : 1L);
+  const ulonglong block_size =
+      (optp->block_size ? (ulonglong)optp->block_size : 1L);
   const longlong max_of_type =
       (longlong)max_of_int_range(optp->var_type & GET_TYPE_MASK);
 
@@ -1258,7 +1261,7 @@ static ulonglong getopt_ull(const char *arg, bool set_maximum_value,
 ulonglong getopt_ull_limit_value(ulonglong num, const struct my_option *optp,
                                  bool *fix) {
   bool adjusted = false;
-  ulonglong old = num;
+  const ulonglong old = num;
   char buf1[255], buf2[255];
   const ulonglong max_of_type =
       max_of_int_range(optp->var_type & GET_TYPE_MASK);
@@ -1298,7 +1301,7 @@ ulonglong getopt_ull_limit_value(ulonglong num, const struct my_option *optp,
 double getopt_double_limit_value(double num, const struct my_option *optp,
                                  bool *fix) {
   bool adjusted = false;
-  double old = num;
+  const double old = num;
   double min, max;
 
   max = getopt_ulonglong2double(optp->max_value);
@@ -1507,7 +1510,8 @@ static uint print_name(const struct my_option *optp, FILE *file = stdout) {
 */
 
 void my_print_help(const struct my_option *options) {
-  uint col, name_space = 22, comment_space = 57;
+  uint col;
+  const uint name_space = 22, comment_space = 57;
   const char *line_end;
   const struct my_option *optp;
 
