@@ -1,16 +1,15 @@
-/* Copyright (c) 2000, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2000, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    Without limiting anything contained in the foregoing, this file,
    which is part of C Driver for MySQL (Connector/C), is also subject to the
@@ -213,10 +212,10 @@ void init_malloc_pointers() {
   // released with a FreeLibrary call, as the functions used from this
   // library can be called from global object destructors late in the
   // process lifecycle. Not calling FreeLibrary is benign is this case.
-  HMODULE hlib = LoadLibraryEx(jemalloc_dll_name, NULL,
+  HMODULE hlib = LoadLibraryEx(jemalloc_dll_name, nullptr,
                                LOAD_LIBRARY_SEARCH_APPLICATION_DIR);
-  if (NULL == hlib) {
-    DWORD err = GetLastError();
+  if (nullptr == hlib) {
+    const DWORD err = GetLastError();
     if (ERROR_MOD_NOT_FOUND == err) {
       // Normal behaviour: not finding the jemalloc dll means
       // we don't want to use it.
@@ -492,7 +491,7 @@ void *my_internal_realloc(void *oldpoint, size_t size, myf my_flags) {
   assert(size > 0);
   /* These flags are mutually exclusive. */
   assert(!((my_flags & MY_FREE_ON_ERROR) && (my_flags & MY_HOLD_ON_ERROR)));
-  DBUG_EXECUTE_IF("simulate_out_of_memory", point = NULL; goto end;);
+  DBUG_EXECUTE_IF("simulate_out_of_memory", point = nullptr; goto end;);
   if (!oldpoint && (my_flags & MY_ALLOW_ZERO_PTR))
     return my_raw_malloc<allocator>(size, my_flags);
 #if defined(MY_MSCRT_DEBUG)
@@ -547,7 +546,7 @@ void *my_memdup(PSI_memory_key key, const void *from, size_t length,
 
 char *my_strdup(PSI_memory_key key, const char *from, myf my_flags) {
   char *ptr;
-  size_t length = strlen(from) + 1;
+  const size_t length = strlen(from) + 1;
   if ((ptr = (char *)my_malloc(key, length, my_flags)))
     memcpy(ptr, from, length);
   return ptr;
