@@ -1,16 +1,15 @@
-/* Copyright (c) 2014, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2014, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,6 +38,7 @@
 #include "my_systime.h"
 #include "plugin/group_replication/include/plugin_psi.h"
 #include "sql/malloc_allocator.h"
+#include "string_with_len.h"
 
 void log_primary_member_details();
 
@@ -206,7 +206,7 @@ class Synchronized_queue : public Synchronized_queue_interface<T> {
   }
 
   bool pop(T *out) override {
-    *out = NULL;
+    *out = nullptr;
     mysql_mutex_lock(&lock);
     while (queue.empty())
       mysql_cond_wait(&cond, &lock); /* purecov: inspected */
@@ -228,7 +228,7 @@ class Synchronized_queue : public Synchronized_queue_interface<T> {
   }
 
   bool front(T *out) override {
-    *out = NULL;
+    *out = nullptr;
     mysql_mutex_lock(&lock);
     while (queue.empty()) mysql_cond_wait(&cond, &lock);
     *out = queue.front();
