@@ -1,16 +1,15 @@
-/* Copyright (c) 2013, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2013, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -43,6 +42,7 @@
 #ifndef NDEBUG
 #include "plugin/group_replication/include/sql_service/sql_command_test.h"
 #endif
+#include "string_with_len.h"
 
 /*
   Buffer to read the write_set value as a string.
@@ -50,26 +50,26 @@
 */
 #define BUFFER_READ_PKE 8
 
-void cleanup_transaction_write_set(
-    Transaction_write_set *transaction_write_set) {
+int add_write_set(Transaction_context_log_event *tcle, std::vector<uint64> *set,
+                  const THD *thd) {
   DBUG_TRACE;
-  if (transaction_write_set != nullptr) {
-    my_free(transaction_write_set->write_set);
-    my_free(transaction_write_set);
-  }
-}
-
-int add_write_set(Transaction_context_log_event *tcle,
-                  Transaction_write_set *set) {
-  DBUG_TRACE;
-  int iterator = set->write_set_size;
-  for (int i = 0; i < iterator; i++) {
+  for (std::vector<uint64>::iterator it = set->begin(); it != set->end();
+       ++it) {
     uchar buff[BUFFER_READ_PKE];
-    int8store(buff, set->write_set[i]);
+    int8store(buff, *it);
     uint64 const tmp_str_sz =
         base64_needed_encoded_length((uint64)BUFFER_READ_PKE);
     char *write_set_value =
         (char *)my_malloc(key_write_set_encoded, tmp_str_sz, MYF(MY_WME));
+    // key_write_set_encoded is being tracked for connection memory limits, if
+    // exceed thread will be killed
+    if (thd->is_killed()) {
+      LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_CONN_KILLED,
+                   "Generate write identification hash failed");
+      my_free(write_set_value);
+      return 1;
+    }
+
     if (!write_set_value) {
       /* purecov: begin inspected */
       LogPluginErr(ERROR_LEVEL,
@@ -123,14 +123,6 @@ int group_replication_trans_before_dml(Trans_param *param, int &out) {
     return 0;
   }
 
-  if ((out += (param->trans_ctx_info.transaction_write_set_extraction ==
-               HASH_ALGORITHM_OFF))) {
-    /* purecov: begin inspected */
-    LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_TRANS_WRITE_SET_EXTRACTION_NOT_SET);
-    return 0;
-    /* purecov: end */
-  }
-
   if (local_member_info->has_enforces_update_everywhere_checks() &&
       (out += (param->trans_ctx_info.tx_isolation == ISO_SERIALIZABLE))) {
     LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_UNSUPPORTED_TRANS_ISOLATION);
@@ -283,15 +275,20 @@ int group_replication_trans_before_commit(Trans_param *param) {
   const ulong transaction_size_limit = get_transaction_size_limit();
   my_off_t transaction_size = 0;
 
-  const bool is_gtid_specified = param->gtid_info.type == ASSIGNED_GTID;
+  bool is_gtid_specified = param->gtid_info.type == ASSIGNED_GTID;
+
+  mysql::gtid::Tag_plain automatic_tag;
+  automatic_tag.clear();
+
   Gtid gtid = {param->gtid_info.sidno, param->gtid_info.gno};
   if (!is_gtid_specified) {
-    // Dummy values that will be replaced after certification.
+    // sidno and gno are dummy values that will be replaced after certification
     gtid.sidno = 1;
     gtid.gno = 1;
+    automatic_tag = param->gtid_info.automatic_tag;
   }
 
-  const Gtid_specification gtid_specification = {ASSIGNED_GTID, gtid};
+  Gtid_specification gtid_specification = {ASSIGNED_GTID, gtid, automatic_tag};
   Gtid_log_event *gle = nullptr;
 
   Transaction_context_log_event *tcle = nullptr;
@@ -357,14 +354,16 @@ int group_replication_trans_before_commit(Trans_param *param) {
   }
 
   if (is_dml) {
-    Transaction_write_set *write_set =
-        get_transaction_write_set(param->thread_id);
+    Rpl_transaction_write_set_ctx *transaction_write_set_ctx =
+        param->thd->get_transaction()->get_transaction_write_set_ctx();
+
+    std::vector<uint64> *write_set = transaction_write_set_ctx->get_write_set();
     /*
       When GTID is specified we may have empty transactions, that is,
       a transaction may have not write set at all because it didn't
       change any data, it will just persist that GTID as applied.
     */
-    if ((write_set == nullptr) && (!is_gtid_specified) &&
+    if ((write_set->size() == 0) && (!is_gtid_specified) &&
         (!param->is_create_table_as_query_block)) {
       LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_FAILED_TO_EXTRACT_TRANS_WRITE_SET,
                    param->thread_id);
@@ -372,17 +371,13 @@ int group_replication_trans_before_commit(Trans_param *param) {
       goto err;
     }
 
-    if (write_set != nullptr) {
-      if (add_write_set(tcle, write_set)) {
-        /* purecov: begin inspected */
-        cleanup_transaction_write_set(write_set);
+    if (write_set->size() > 0) {
+      if (add_write_set(tcle, write_set, param->thd)) {
         LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_FAILED_TO_GATHER_TRANS_WRITE_SET,
                      param->thread_id);
         error = pre_wait_error;
         goto err;
-        /* purecov: end */
       }
-      cleanup_transaction_write_set(write_set);
       assert(is_gtid_specified || (tcle->get_write_set()->size() > 0));
     } else {
       /*
@@ -490,6 +485,15 @@ int group_replication_trans_before_commit(Trans_param *param) {
           transaction_size, consistency_level);
     }
 
+    // transaction_message use memory key being tracked for connection limits,
+    // if exceed thread will be killed
+    if (param->thd->is_killed()) {
+      LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_CONN_KILLED,
+                   "Generate transaction message failed");
+      error = pre_wait_error;
+      goto err;
+    }
+
     if (binary_event_serialize(tcle, transaction_msg) ||
         binary_event_serialize(gle, transaction_msg)) {
       LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_WRITE_TO_TRANSACTION_MESSAGE_FAILED,
@@ -692,7 +696,7 @@ int group_replication_trans_begin(Trans_param *param, int &out) {
        *transaction_observers) {
     out = transaction_observer->before_transaction_begin(
         param->thread_id, param->group_replication_consistency,
-        param->hold_timeout, param->rpl_channel_type);
+        param->hold_timeout, param->rpl_channel_type, param->thd);
     if (out) break;
   }
   group_transaction_observation_manager->unlock_observer_list();
