@@ -1,4 +1,4 @@
-/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -32,6 +32,7 @@
 #include <mysql/components/services/log_builtins.h>
 #include <mysqld_error.h>
 
+#include "m_string.h"
 #include "my_dbug.h"
 #include "my_inttypes.h"
 #include "my_io.h"
@@ -40,7 +41,9 @@
 #include "template_utils.h"
 #include "thr_cond.h"
 
-#define STRING_BUFFER 1024
+static constexpr int STRING_BUFFER = 1024 * 4;
+
+struct CHARSET_INFO;
 
 static const char *sep =
     "======================================================\n";
@@ -159,9 +162,8 @@ static int sql_start_result_metadata(void *, uint num_cols, uint,
                                      const CHARSET_INFO *resultcs) {
   DBUG_TRACE;
   DBUG_PRINT("info", ("resultcs->number: %d", resultcs->number));
-  DBUG_PRINT("info",
-             ("resultcs->csname: %s", replace_utf8_utf8mb3(resultcs->csname)));
-  DBUG_PRINT("info", ("resultcs->name: %s", resultcs->name));
+  DBUG_PRINT("info", ("resultcs->csname: %s", resultcs->csname));
+  DBUG_PRINT("info", ("resultcs->name: %s", resultcs->m_coll_name));
   row_count = 0;
   sql_num_cols = num_cols;
   sql_resultcs = resultcs;
@@ -331,7 +333,7 @@ const struct st_command_service_cbs sql_cbs = {
 
 /****************************************************************************************/
 
-static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
+static void test_com_query(void *p [[maybe_unused]]) {
   DBUG_TRACE;
 
   /* Session declarations */
@@ -345,7 +347,7 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
   WRITE_STR("COM_QUERY");
 
   /* Open session 1: Must pass */
-  st_session = srv_session_open(NULL, plugin_ctx);
+  st_session = srv_session_open(nullptr, plugin_ctx);
   if (!st_session) {
     LogPluginErr(ERROR_LEVEL, ER_LOG_PRINTF_MSG, "srv_session_open failed.");
   } else
@@ -360,7 +362,7 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
   cmd.com_query.length = strlen(cmd.com_query.query);
   WRITE_VAL("%s\n", cmd.com_query.query);
   fail = command_service_run_command(st_session, COM_QUERY, &cmd,
-                                     &my_charset_utf8_general_ci, &sql_cbs,
+                                     &my_charset_utf8mb3_general_ci, &sql_cbs,
                                      CS_TEXT_REPRESENTATION, &cbd);
   if (fail)
     LogPluginErrMsg(ERROR_LEVEL, ER_LOG_PRINTF_MSG, "sql_simple ret code: %d\n",
@@ -369,7 +371,7 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
     /* get values */
     WRITE_STR(
         "-----------------------------------------------------------------\n");
-    WRITE_VAL("%s\t\%s\n", sql_field[0][0].col_name, sql_field[0][1].col_name);
+    WRITE_VAL("%s\t%s\n", sql_field[0][0].col_name, sql_field[0][1].col_name);
     for (uint row = 0; row < sql_num_rows; row++) {
       for (uint col = 0; col < sql_num_cols; col++) {
         WRITE_VAL("%s\n", sql_str_value[col][row]);
@@ -384,7 +386,7 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
     } else {
       WRITE_VAL("server status: %d\n", cbd.server_status);
       WRITE_VAL("warn count: %d\n", cbd.warn_count);
-      //           WRITE_VAL("messsage: %s\n",msg);
+      //           WRITE_VAL("message: %s\n",msg);
     }
   }
 
@@ -401,7 +403,7 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
   WRITE_VAL("%s\n", cmd.com_query.query);
   cbd.reset();
   fail = command_service_run_command(st_session, COM_QUERY, &cmd,
-                                     &my_charset_utf8_general_ci, &sql_cbs,
+                                     &my_charset_utf8mb3_general_ci, &sql_cbs,
                                      CS_TEXT_REPRESENTATION, &cbd);
   if (fail)
     LogPluginErrMsg(ERROR_LEVEL, ER_LOG_PRINTF_MSG, "sql_simple ret code: %d\n",
@@ -410,10 +412,10 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
     /* get values */
     WRITE_STR(
         "-----------------------------------------------------------------\n");
-    WRITE_VAL("%s\t\%s\n", sql_field[0][0].col_name, sql_field[0][1].col_name);
+    WRITE_VAL("%s\t%s\n", sql_field[0][0].col_name, sql_field[0][1].col_name);
     for (uint row = 0; row < sql_num_rows; row++) {
       for (uint col = 0; col < sql_num_cols; col += 2) {
-        WRITE_VAL("%s\t\%s\n", sql_str_value[col][row],
+        WRITE_VAL("%s\t%s\n", sql_str_value[col][row],
                   sql_str_value[col + 1][row]);
       }
     }
@@ -436,7 +438,7 @@ static void test_com_query(void *p MY_ATTRIBUTE((unused))) {
   cmd.com_query.length = strlen(cmd.com_query.query);
 
   ENSURE_API_OK(command_service_run_command(
-      st_session, COM_QUERY, &cmd, &my_charset_utf8_general_ci, &sql_cbs,
+      st_session, COM_QUERY, &cmd, &my_charset_utf8mb3_general_ci, &sql_cbs,
       CS_TEXT_REPRESENTATION, &cbd));
 
   WRITE_VAL("error after bad SQL: %i: %s\n", cbd.err, cbd.errmsg.c_str());
@@ -453,7 +455,7 @@ static int test_com_init_db(void *p) {
 
   MYSQL_SESSION st_session;
 
-  ENSURE_API_NOT_NULL(st_session = srv_session_open(NULL, p));
+  ENSURE_API_NOT_NULL(st_session = srv_session_open(nullptr, p));
 
   if (st_session) switch_user(st_session, user_privileged);
   COM_DATA cmd;
@@ -465,7 +467,7 @@ static int test_com_init_db(void *p) {
   cmd.com_init_db.length = strlen("mysql");
   Callback_data cbd;
   ENSURE_API_OK(command_service_run_command(
-      st_session, COM_INIT_DB, &cmd, &my_charset_utf8_general_ci, &sql_cbs,
+      st_session, COM_INIT_DB, &cmd, &my_charset_utf8mb3_general_ci, &sql_cbs,
       CS_TEXT_REPRESENTATION, &cbd));
 
   db_name = srv_session_info_get_current_db(st_session);
@@ -476,49 +478,6 @@ static int test_com_init_db(void *p) {
   return 0;
 }
 
-/*
-static int test_com_list_fields(void *p)
-{
-  DBUG_TRACE;
-
-  MYSQL_SESSION st_session;
-
-  ENSURE_API_NOT_NULL(st_session = srv_session_open(NULL, p));
-
-  COM_DATA cmd;
-
-  cmd.com_init_db.db_name = "mysql";
-  cmd.com_init_db.length = strlen("mysql");
-  ENSURE_API_OK(command_service_run_command(st_session, COM_INIT_DB, &cmd,
-&my_charset_utf8_general_ci, &sql_cbs, CS_TEXT_REPRESENTATION, p));
-
-  WRITE_VAL("switched default db to: %s\n",
-srv_session_info_get_current_db(st_session));
-
-
-  WRITE_STR("field_list\n");
-  cmd.com_field_list.table_name = (unsigned char*)"user";
-  cmd.com_field_list.table_name_length = strlen((const
-char*)cmd.com_field_list.table_name); cmd.com_field_list.query = (unsigned
-char*)"%"; cmd.com_field_list.query_length = strlen((const
-char*)cmd.com_field_list.query);
-  ENSURE_API_OK(command_service_run_command(st_session, COM_FIELD_LIST, &cmd,
-&my_charset_utf8_general_ci, &sql_cbs, CS_TEXT_REPRESENTATION, p));
-
-  WRITE_STR("-----------------------------------------------------------------\n");
-  for (uint row_count=0;row_count < sql_num_rows;row_count++){
-    for (uint col_count=0;col_count < sql_num_cols;col_count+=2){
-      WRITE_VAL("%s\t\%s\n",sql_str_value[col_count][row_count],
-                  sql_str_value[col_count+1][row_count]);
-    }
-  }
-
-  ENSURE_API_OK(srv_session_close(st_session));
-
-  return 0;
-}
-*/
-
 struct Test_data {
   void *p;
   MYSQL_SESSION session;
@@ -570,9 +529,9 @@ static void *test_session_thread(Test_data *tdata) {
 
   tdata->go();
 
-  int r = command_service_run_command(tdata->session, COM_QUERY, &cmd,
-                                      &my_charset_utf8_general_ci, &sql_cbs,
-                                      CS_TEXT_REPRESENTATION, &cbdata);
+  const int r = command_service_run_command(
+      tdata->session, COM_QUERY, &cmd, &my_charset_utf8mb3_general_ci, &sql_cbs,
+      CS_TEXT_REPRESENTATION, &cbdata);
   WRITE_VAL("Killed run_command return value: %i\n", r);
 
   WRITE_VAL("thread shutdown: %i (%s)\n", cbdata.shutdown,
@@ -604,7 +563,7 @@ static int test_query_kill(void *p) {
 
   WRITE_STR("test_query_kill\n");
 
-  ENSURE_API_NOT_NULL(st_session = srv_session_open(NULL, p));
+  ENSURE_API_NOT_NULL(st_session = srv_session_open(nullptr, p));
 
   switch_user(st_session, user_privileged);
   MYSQL_SESSION st_session_victim;
@@ -645,7 +604,7 @@ static int test_query_kill(void *p) {
   cmd.com_query.query = buffer;
   cmd.com_query.length = strlen(buffer);
   ENSURE_API_OK(command_service_run_command(
-      st_session, COM_QUERY, &cmd, &my_charset_utf8_general_ci, &sql_cbs,
+      st_session, COM_QUERY, &cmd, &my_charset_utf8mb3_general_ci, &sql_cbs,
       CS_TEXT_REPRESENTATION, &cbd));
 
   void *ret;
@@ -658,40 +617,6 @@ static int test_query_kill(void *p) {
   return 0;
 }
 
-static int test_com_process_kill(void *p) {
-  DBUG_TRACE;
-
-  MYSQL_SESSION st_session;
-  Callback_data cbd;
-
-  WRITE_STR("COM_KILL\n");
-
-  ENSURE_API_NOT_NULL(st_session = srv_session_open(NULL, p));
-
-  switch_user(st_session, user_privileged);
-  MYSQL_SESSION st_session_victim;
-  ENSURE_API_NOT_NULL(st_session_victim =
-                          srv_session_open(session_error_cb, p));
-
-  WRITE_VAL("session is dead? %i\n",
-            thd_killed(srv_session_info_get_thd(st_session_victim)));
-
-  COM_DATA cmd;
-
-  cmd.com_kill.id = srv_session_info_get_session_id(st_session_victim);
-  ENSURE_API_OK(command_service_run_command(
-      st_session, COM_PROCESS_KILL, &cmd, &my_charset_utf8_general_ci, &sql_cbs,
-      CS_TEXT_REPRESENTATION, &cbd));
-
-  WRITE_VAL("session is dead now? %i\n",
-            thd_killed(srv_session_info_get_thd(st_session_victim)));
-
-  ENSURE_API_OK(srv_session_close(st_session));
-  ENSURE_API_OK(srv_session_close(st_session_victim));
-
-  return 0;
-}
-
 static int test_priv(void *p) {
   DBUG_TRACE;
 
@@ -701,7 +626,7 @@ static int test_priv(void *p) {
 
   WRITE_STR("COM_QUERY with priv\n");
 
-  ENSURE_API_NOT_NULL(root_session = srv_session_open(NULL, p));
+  ENSURE_API_NOT_NULL(root_session = srv_session_open(nullptr, p));
 
   switch_user(root_session, user_privileged);
 
@@ -709,14 +634,14 @@ static int test_priv(void *p) {
   cmd.com_query.query = "create user ordinary@localhost";
   cmd.com_query.length = strlen(cmd.com_query.query);
   ENSURE_API_OK(command_service_run_command(
-      root_session, COM_QUERY, &cmd, &my_charset_utf8_general_ci, &sql_cbs,
+      root_session, COM_QUERY, &cmd, &my_charset_utf8mb3_general_ci, &sql_cbs,
       CS_TEXT_REPRESENTATION, &cbd));
   WRITE_VAL("create user as root: %i %s\n", cbd.err, cbd.errmsg.c_str());
 
   WRITE_STR("now try as ordinary user\n");
   {
     MYSQL_SESSION ordinary_session;
-    ENSURE_API_NOT_NULL(ordinary_session = srv_session_open(NULL, p));
+    ENSURE_API_NOT_NULL(ordinary_session = srv_session_open(nullptr, p));
     switch_user(ordinary_session, user_ordinary);
 
     cbd.reset();
@@ -724,7 +649,7 @@ static int test_priv(void *p) {
     cmd.com_query.query = "create user bogus@localhost";
     cmd.com_query.length = strlen(cmd.com_query.query);
     ENSURE_API_OK(command_service_run_command(
-        ordinary_session, COM_QUERY, &cmd, &my_charset_utf8_general_ci,
+        ordinary_session, COM_QUERY, &cmd, &my_charset_utf8mb3_general_ci,
         &sql_cbs, CS_TEXT_REPRESENTATION, &cbd));
 
     WRITE_VAL("create user supposed to fail: %i %s\n", cbd.err,
@@ -738,7 +663,7 @@ static int test_priv(void *p) {
   cmd.com_query.query = "drop user ordinary@localhost";
   cmd.com_query.length = strlen(cmd.com_query.query);
   ENSURE_API_OK(command_service_run_command(
-      root_session, COM_QUERY, &cmd, &my_charset_utf8_general_ci, &sql_cbs,
+      root_session, COM_QUERY, &cmd, &my_charset_utf8mb3_general_ci, &sql_cbs,
       CS_TEXT_REPRESENTATION, &cbd));
   WRITE_VAL("drop user as root: %i %s\n", cbd.err, cbd.errmsg.c_str());
 
@@ -747,7 +672,7 @@ static int test_priv(void *p) {
   return 0;
 }
 
-static void test_sql(void *p MY_ATTRIBUTE((unused))) {
+static void test_sql(void *p [[maybe_unused]]) {
   DBUG_TRACE;
   LogPluginErr(INFORMATION_LEVEL, ER_LOG_PRINTF_MSG, "Installation.");
 
@@ -756,10 +681,6 @@ static void test_sql(void *p MY_ATTRIBUTE((unused))) {
   WRITE_SEP();
   test_com_init_db(p);
   WRITE_SEP();
-  //  test_com_list_fields(p);
-  //  WRITE_SEP();
-  test_com_process_kill(p);
-  WRITE_SEP();
   test_query_kill(p);
   WRITE_SEP();
   test_priv(p);
@@ -790,7 +711,7 @@ static int test_sql_service_plugin_init(void *p) {
   return 0;
 }
 
-static int test_sql_service_plugin_deinit(void *p MY_ATTRIBUTE((unused))) {
+static int test_sql_service_plugin_deinit(void *p [[maybe_unused]]) {
   DBUG_TRACE;
   LogPluginErr(INFORMATION_LEVEL, ER_LOG_PRINTF_MSG, "Uninstallation.");
   deinit_logging_service_for_plugin(&reg_srv, &log_bi, &log_bs);
