@@ -1,17 +1,16 @@
 /*
-  Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+  Copyright (c) 2019, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -225,16 +224,14 @@ template <class T, class BufferType,
               std::declval<typename std::add_lvalue_reference<T>::type>())),
           class End = decltype(net::buffer_sequence_end(
               std::declval<typename std::add_lvalue_reference<T>::type>()))>
-using buffer_sequence_requirements = std::integral_constant<
-    bool,
-    std::conjunction<
-        // check if buffer_sequence_begin(T &) and buffer_sequence_end(T &)
-        // exist and return the same type
-        std::is_same<Begin, End>,
-        // check if ::value_type of the retval of buffer_sequence_begin() can be
-        // converted into a BufferType
-        std::is_convertible<typename std::iterator_traits<Begin>::value_type,
-                            BufferType>>::value>;
+using buffer_sequence_requirements = std::bool_constant<std::conjunction_v<
+    // check if buffer_sequence_begin(T &) and buffer_sequence_end(T &)
+    // exist and return the same type
+    std::is_same<Begin, End>,
+    // check if ::value_type of the retval of buffer_sequence_begin() can be
+    // converted into a BufferType
+    std::is_convertible<typename std::iterator_traits<Begin>::value_type,
+                        BufferType>>>;
 
 template <class T, class BufferType, class = void>
 struct is_buffer_sequence : std::false_type {};
@@ -242,7 +239,7 @@ struct is_buffer_sequence : std::false_type {};
 template <class T, class BufferType>
 struct is_buffer_sequence<
     T, BufferType, std::void_t<buffer_sequence_requirements<T, BufferType>>>
-    : std::true_type {};
+    : buffer_sequence_requirements<T, BufferType> {};
 
 template <class T>
 struct is_const_buffer_sequence
@@ -799,15 +796,16 @@ class consuming_buffers {
     for (; (from_cur != from_end) && to_bufs.size() < to_bufs.max_size() &&
            max_size > 0;
          ++from_cur) {
-      if (from_cur->size() > to_skip) {
-        const size_t avail = from_cur->size() - to_skip;
+      auto cur_buf = net::buffer(*from_cur);
+
+      if (cur_buf.size() > to_skip) {
+        const size_t avail = cur_buf.size() - to_skip;
         const size_t to_use = std::min(avail, max_size);
-        to_bufs.push_back(
-            net::buffer(BufferType(net::buffer(*from_cur)) + to_skip, to_use));
+        to_bufs.push_back(net::buffer(BufferType(cur_buf) + to_skip, to_use));
         to_skip = 0;
         max_size -= to_use;
       } else {
-        to_skip -= from_cur->size();
+        to_skip -= cur_buf.size();
       }
     }
     return to_bufs;
@@ -987,7 +985,7 @@ std::enable_if_t<is_dynamic_buffer<DynamicBuffer>::value, void> async_read(
 // 17.7 [buffer.write]
 
 template <class SyncWriteStream, class ConstBufferSequence>
-std::enable_if_t<is_const_buffer_sequence<ConstBufferSequence>::value,
+std::enable_if_t<is_const_buffer_sequence_v<ConstBufferSequence>,
                  stdx::expected<size_t, std::error_code>>
 write(SyncWriteStream &stream, const ConstBufferSequence &buffers) {
   return write(stream, buffers, transfer_all());
@@ -995,7 +993,7 @@ write(SyncWriteStream &stream, const ConstBufferSequence &buffers) {
 
 template <class SyncWriteStream, class ConstBufferSequence,
           class CompletionCondition>
-std::enable_if_t<is_const_buffer_sequence<ConstBufferSequence>::value,
+std::enable_if_t<is_const_buffer_sequence_v<ConstBufferSequence>,
                  stdx::expected<size_t, std::error_code>>
 write(SyncWriteStream &stream, const ConstBufferSequence &buffers,
       CompletionCondition cond) {
@@ -1068,6 +1066,45 @@ write(SyncWriteStream &stream, DynamicBuffer &&b, CompletionCondition cond) {
 }
 
 // 17.8 [buffer.async.write]
+//
+template <class AsyncWriteStream, class ConstBufferSequence,
+          class CompletionCondition, class CompletionToken>
+std::enable_if_t<is_const_buffer_sequence_v<ConstBufferSequence>, void>
+async_write(AsyncWriteStream &stream, const ConstBufferSequence &buffers,
+            CompletionCondition cond, CompletionToken &&token) {
+  async_completion<CompletionToken, void(std::error_code, size_t)> init{token};
+
+  stream.async_wait(
+      net::impl::socket::wait_type::wait_write,
+      [&stream, &buffers, cond,
+       compl_handler = std::move(init.completion_handler)](std::error_code ec) {
+        if (ec) {
+          compl_handler(ec, 0);
+          return;
+        }
+
+        const auto res = net::write(stream, buffers, cond);
+
+        if (!res) {
+          compl_handler(res.error(), 0);
+        } else {
+          compl_handler({}, res.value());
+        }
+
+        return;
+      });
+
+  return init.result.get();
+}
+
+template <class AsyncWriteStream, class ConstBufferSequence,
+          class CompletionToken>
+std::enable_if_t<is_const_buffer_sequence_v<ConstBufferSequence>, void>
+async_write(AsyncWriteStream &stream, const ConstBufferSequence &buffers,
+            CompletionToken &&token) {
+  return async_write(stream, buffers, net::transfer_all(),
+                     std::forward<CompletionToken>(token));
+}
 
 template <class AsyncWriteStream, class DynamicBuffer,
           class CompletionCondition, class CompletionToken>
@@ -1121,6 +1158,7 @@ std::enable_if_t<is_dynamic_buffer<DynamicBuffer>::value, void> async_write(
 
   return init.result.get();
 }
+
 template <class AsyncWriteStream, class DynamicBuffer, class CompletionToken>
 std::enable_if_t<is_dynamic_buffer<DynamicBuffer>::value, void> async_write(
     AsyncWriteStream &stream, DynamicBuffer &&b, CompletionToken &&token) {
