@@ -1,17 +1,16 @@
 /*
-  Copyright (c) 2020, 2024, Oracle and/or its affiliates.
+  Copyright (c) 2020, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -217,7 +216,7 @@ class basic_named_pipe_impl : public basic_named_pipe_impl_base {
     do {
       native_handle_ =
           CreateFile(TEXT(ep.path().c_str()), GENERIC_READ | GENERIC_WRITE, 0,
-                     NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
+                     nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 
       if (native_handle_ == impl::named_pipe::kInvalidHandle) {
         auto const error_code = win32::last_error_code();
@@ -297,7 +296,7 @@ class basic_named_pipe : private basic_named_pipe_impl<Protocol> {
          ++bufcur) {
       DWORD numRead{0};
       if (!ReadFile(native_handle(), bufcur->data(), bufcur->size(), &numRead,
-                    NULL)) {
+                    nullptr)) {
         return stdx::make_unexpected(win32::last_error_code());
       }
 
@@ -322,7 +321,7 @@ class basic_named_pipe : private basic_named_pipe_impl<Protocol> {
       DWORD written{0};
 
       if (!WriteFile(native_handle(), bufcur->data(), bufcur->size(), &written,
-                     NULL)) {
+                     nullptr)) {
         return stdx::make_unexpected(win32::last_error_code());
       }
 
@@ -547,7 +546,7 @@ class basic_named_pipe_acceptor : public basic_named_pipe_impl<Protocol> {
           TEXT(ep_.path().c_str()), PIPE_ACCESS_DUPLEX,
           protocol.type() | protocol.protocol() | PIPE_REJECT_REMOTE_CLIENTS |
               flags,
-          back_log_, 1024 * 16, 1024 * 16, NMPWAIT_USE_DEFAULT_WAIT, NULL);
+          back_log_, 1024 * 16, 1024 * 16, NMPWAIT_USE_DEFAULT_WAIT, nullptr);
 
       if (handle == impl::named_pipe::kInvalidHandle) {
         auto ec = win32::last_error_code();
@@ -597,7 +596,7 @@ class basic_named_pipe_acceptor : public basic_named_pipe_impl<Protocol> {
 
     const auto protocol = protocol_type();
 
-    const bool connected = ConnectNamedPipe(native_handle(), NULL);
+    const bool connected = ConnectNamedPipe(native_handle(), nullptr);
     if (!connected) {
       auto last_ec = win32::last_error_code();
 
