@@ -1,17 +1,16 @@
 /*
-  Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+  Copyright (c) 2019, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -719,10 +718,7 @@ void MySQLXProtocol::encode_error(const ErrorResponse &err) {
   encode_message(Mysqlx::ServerMessages::ERROR, err_msg);
 }
 
-void MySQLXProtocol::encode_ok(
-    const uint64_t /*affected_rows*/,  // TODO: notice with this data?
-    const uint64_t /*last_insert_id*/, const uint16_t /*server_status*/,
-    const uint16_t /*warning_count*/) {
+void MySQLXProtocol::encode_ok(const OkResponse & /* msg */) {
   Mysqlx::Sql::StmtExecuteOk ok_msg;
   encode_message(Mysqlx::ServerMessages::SQL_STMT_EXECUTE_OK, ok_msg);
 }
@@ -758,7 +754,7 @@ void MySQLXProtocol::encode_resultset(const ResultsetResponse &response) {
 
   Mysqlx::Resultset::FetchDone fetch_done_msg;
   encode_message(Mysqlx::ServerMessages::RESULTSET_FETCH_DONE, fetch_done_msg);
-  encode_ok();
+  encode_ok({});
 }
 
 }  // namespace server_mock
