@@ -1,17 +1,16 @@
 /*
-  Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+  Copyright (c) 2019, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1099,15 +1098,22 @@ class StmtExecute {
 
     ParamDef(uint16_t type_and_flags_) : type_and_flags(type_and_flags_) {}
 
-    ParamDef(uint16_t type_and_flags_, string_type name_)
-        : type_and_flags(type_and_flags_), name(std::move(name_)) {}
+    ParamDef(uint16_t type_and_flags_, string_type name_,
+             bool param_already_sent_ = false)
+        : type_and_flags(type_and_flags_),
+          name(std::move(name_)),
+          param_already_sent(param_already_sent_) {}
 
     friend bool operator==(const ParamDef &lhs, const ParamDef &rhs) {
       return lhs.type_and_flags == rhs.type_and_flags && lhs.name == rhs.name;
     }
 
     uint16_t type_and_flags{};
+
     string_type name;
+
+    // param already send via stmt_param_append_data
+    bool param_already_sent{false};
   };
 
   /**
@@ -1257,6 +1263,11 @@ class Ping {};
 
 constexpr bool operator==(const Ping &, const Ping &) { return true; }
 
+// no content
+class Debug {};
+
+constexpr bool operator==(const Debug &, const Debug &) { return true; }
+
 template <bool Borrowed>
 class AuthMethodData {
  public:
@@ -1418,6 +1429,7 @@ using ListFields = borrowable::message::client::ListFields<false>;
 using Query = borrowable::message::client::Query<false>;
 using RegisterReplica = borrowable::message::client::RegisterReplica<false>;
 using Ping = borrowable::message::client::Ping;
+using Debug = borrowable::message::client::Debug;
 using Kill = borrowable::message::client::Kill;
 using ChangeUser = borrowable::message::client::ChangeUser<false>;
 using Reload = borrowable::message::client::Reload;
@@ -1465,6 +1477,7 @@ using InitSchema = borrowable::message::client::InitSchema<true>;
 using ListFields = borrowable::message::client::ListFields<true>;
 using RegisterReplica = borrowable::message::client::RegisterReplica<true>;
 using Ping = borrowable::message::client::Ping;
+using Debug = borrowable::message::client::Debug;
 using Kill = borrowable::message::client::Kill;
 using ChangeUser = borrowable::message::client::ChangeUser<true>;
 using Reload = borrowable::message::client::Reload;
