@@ -1,17 +1,16 @@
 /*
-  Copyright (c) 2016, 2024, Oracle and/or its affiliates.
+  Copyright (c) 2016, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,6 +32,7 @@
 #include "mysql/harness/event_state_tracker.h"
 #include "mysql/harness/logging/logging.h"
 #include "mysqld_error.h"
+#include "mysqlrouter/cluster_metadata_instance_attributes.h"
 #include "mysqlrouter/utils.h"  // strtoui_checked
 #include "mysqlrouter/utils_sqlstring.h"
 #include "router_config.h"  // MYSQL_ROUTER_VERSION
@@ -63,7 +63,7 @@ namespace mysqlrouter {
  * @return A string object encapsulation of the input character string. An empty
  *         string if input string is nullptr.
  */
-static std::string as_string(const char *input_str) {
+static std::string get_string(const char *input_str) {
   return input_str == nullptr ? "" : input_str;
 }
 
@@ -176,18 +176,19 @@ std::string to_string_md(const ClusterType cluster_type) {
 void update_router_info_v1(const uint32_t router_id,
                            const std::string &rw_endpoint,
                            const std::string &ro_endpoint,
+                           const std::string &rw_split_endpoint,
                            const std::string &rw_x_endpoint,
                            const std::string &ro_x_endpoint,
                            const std::string &username, MySQLSession *mysql) {
   sqlstring query(
       "UPDATE mysql_innodb_cluster_metadata.routers"
       " SET attributes = "
-      "   JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(IF("
-      "attributes "
-      "IS NULL, '{}', attributes),"
+      "JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET("
+      "IF(attributes IS NULL, '{}', attributes),"
       "    '$.version', ?),"
       "    '$.RWEndpoint', ?),"
       "    '$.ROEndpoint', ?),"
+      "    '$.RWSplitEndpoint', ?),"
       "    '$.RWXEndpoint', ?),"
       "    '$.ROXEndpoint', ?),"
       "    '$.MetadataUser', ?),"
@@ -195,7 +196,8 @@ void update_router_info_v1(const uint32_t router_id,
       " WHERE router_id = ?");
 
   query << MYSQL_ROUTER_VERSION;
-  query << rw_endpoint << ro_endpoint << rw_x_endpoint << ro_x_endpoint;
+  query << rw_endpoint << ro_endpoint << rw_split_endpoint << rw_x_endpoint
+        << ro_x_endpoint;
   query << username << to_string_md(ClusterType::GR_V1);
   query << router_id << sqlstring::end;
 
@@ -206,19 +208,20 @@ void update_router_info_v2(
     const mysqlrouter::ClusterType cluster_type, const uint32_t router_id,
     const std::string &cluster_id, const std::string &target_cluster,
     const std::string &rw_endpoint, const std::string &ro_endpoint,
-    const std::string &rw_x_endpoint, const std::string &ro_x_endpoint,
-    const std::string &username, MySQLSession *mysql) {
+    const std::string &rw_split_endpoint, const std::string &rw_x_endpoint,
+    const std::string &ro_x_endpoint, const std::string &username,
+    MySQLSession *mysql) {
   const std::string cluster_id_field =
       cluster_type == mysqlrouter::ClusterType::GR_CS ? "clusterset_id"
                                                       : "cluster_id";
   sqlstring query(
       "UPDATE mysql_innodb_cluster_metadata.v2_routers"
       " SET attributes = "
-      "   JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(IF(attributes "
-      "IS NULL, "
-      "'{}', attributes),"
+      "JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET("
+      "IF(attributes IS NULL, '{}', attributes),"
       "    '$.RWEndpoint', ?),"
       "    '$.ROEndpoint', ?),"
+      "    '$.RWSplitEndpoint', ?),"
       "    '$.RWXEndpoint', ?),"
       "    '$.ROXEndpoint', ?),"
       "    '$.MetadataUser', ?),"
@@ -227,9 +230,10 @@ void update_router_info_v2(
       " WHERE router_id = ?",
       {mysqlrouter::QuoteOnlyIfNeeded});
 
-  query << rw_endpoint << ro_endpoint << rw_x_endpoint << ro_x_endpoint
-        << username << to_string_md(cluster_type) << MYSQL_ROUTER_VERSION
-        << cluster_id_field << cluster_id << router_id << sqlstring::end;
+  query << rw_endpoint << ro_endpoint << rw_split_endpoint << rw_x_endpoint
+        << ro_x_endpoint << username << to_string_md(cluster_type)
+        << MYSQL_ROUTER_VERSION << cluster_id_field << cluster_id << router_id
+        << sqlstring::end;
 
   mysql->execute(query);
 
@@ -251,40 +255,47 @@ void update_router_info_v2(
 void ClusterMetadataGRV1::update_router_info(
     const uint32_t router_id, const std::string & /*cluster_id*/,
     const std::string & /*target_cluster*/, const std::string &rw_endpoint,
-    const std::string &ro_endpoint, const std::string &rw_x_endpoint,
-    const std::string &ro_x_endpoint, const std::string &username) {
-  update_router_info_v1(router_id, rw_endpoint, ro_endpoint, rw_x_endpoint,
-                        ro_x_endpoint, username, mysql_);
+    const std::string &ro_endpoint, const std::string &rw_split_endpoint,
+    const std::string &rw_x_endpoint, const std::string &ro_x_endpoint,
+    const std::string &username) {
+  update_router_info_v1(router_id, rw_endpoint, ro_endpoint, rw_split_endpoint,
+                        rw_x_endpoint, ro_x_endpoint, username, mysql_);
 }
 
 void ClusterMetadataGRV2::update_router_info(
     const uint32_t router_id, const std::string &cluster_id,
     const std::string &target_cluster, const std::string &rw_endpoint,
-    const std::string &ro_endpoint, const std::string &rw_x_endpoint,
-    const std::string &ro_x_endpoint, const std::string &username) {
+    const std::string &ro_endpoint, const std::string &rw_split_endpoint,
+    const std::string &rw_x_endpoint, const std::string &ro_x_endpoint,
+    const std::string &username) {
   update_router_info_v2(mysqlrouter::ClusterType::GR_V2, router_id, cluster_id,
-                        target_cluster, rw_endpoint, ro_endpoint, rw_x_endpoint,
-                        ro_x_endpoint, username, mysql_);
+                        target_cluster, rw_endpoint, ro_endpoint,
+                        rw_split_endpoint, rw_x_endpoint, ro_x_endpoint,
+                        username, mysql_);
 }
 
 void ClusterMetadataAR::update_router_info(
     const uint32_t router_id, const std::string &cluster_id,
     const std::string &target_cluster, const std::string &rw_endpoint,
-    const std::string &ro_endpoint, const std::string &rw_x_endpoint,
-    const std::string &ro_x_endpoint, const std::string &username) {
+    const std::string &ro_endpoint, const std::string &rw_split_endpoint,
+    const std::string &rw_x_endpoint, const std::string &ro_x_endpoint,
+    const std::string &username) {
   update_router_info_v2(mysqlrouter::ClusterType::RS_V2, router_id, cluster_id,
-                        target_cluster, rw_endpoint, ro_endpoint, rw_x_endpoint,
-                        ro_x_endpoint, username, mysql_);
+                        target_cluster, rw_endpoint, ro_endpoint,
+                        rw_split_endpoint, rw_x_endpoint, ro_x_endpoint,
+                        username, mysql_);
 }
 
 void ClusterMetadataGRInClusterSet::update_router_info(
     const uint32_t router_id, const std::string &cluster_id,
     const std::string &target_cluster, const std::string &rw_endpoint,
-    const std::string &ro_endpoint, const std::string &rw_x_endpoint,
-    const std::string &ro_x_endpoint, const std::string &username) {
+    const std::string &ro_endpoint, const std::string &rw_split_endpoint,
+    const std::string &rw_x_endpoint, const std::string &ro_x_endpoint,
+    const std::string &username) {
   update_router_info_v2(mysqlrouter::ClusterType::GR_CS, router_id, cluster_id,
-                        target_cluster, rw_endpoint, ro_endpoint, rw_x_endpoint,
-                        ro_x_endpoint, username, mysql_);
+                        target_cluster, rw_endpoint, ro_endpoint,
+                        rw_split_endpoint, rw_x_endpoint, ro_x_endpoint,
+                        username, mysql_);
 }
 
 namespace {
@@ -348,7 +359,7 @@ uint32_t register_router_v1(
           " WHERE host_id = ? AND router_name = ?");
       query << host_id << router_name << sqlstring::end;
       if (auto row = mysql->query_one(query)) {
-        const std::string router_id_str{(*row)[0]};
+        const std::string router_id_str{get_string((*row)[0])};
 
         size_t end_pos;
         const auto router_id =
@@ -706,6 +717,18 @@ uint64_t ClusterMetadataGRV2::query_cluster_count() {
   return query_gr_cluster_count(mysql_, /*metadata_v2=*/true);
 }
 
+static InstanceType get_instance_type(const std::string &attributes) {
+  const auto default_type = InstanceType::GroupMember;
+  const auto instance_type_attr =
+      InstanceAttributes::get_instance_type(attributes, default_type);
+
+  if (!instance_type_attr) {
+    return default_type;
+  }
+
+  return instance_type_attr.value();
+}
+
 static ClusterInfo query_metadata_servers(
     MySQLSession *mysql, const mysqlrouter::ClusterType cluster_type) {
   // Query the uuid and name of the cluster, and the instance addresses
@@ -715,7 +738,7 @@ static ClusterInfo query_metadata_servers(
     case mysqlrouter::ClusterType::RS_V2:
       query =
           "select c.cluster_id, c.cluster_id as uuid, c.cluster_name, "
-          "i.address from "
+          "i.address, i.attributes from "
           "mysql_innodb_cluster_metadata.v2_instances i join "
           "mysql_innodb_cluster_metadata.v2_clusters c on c.cluster_id = "
           "i.cluster_id";
@@ -723,7 +746,7 @@ static ClusterInfo query_metadata_servers(
     case mysqlrouter::ClusterType::GR_V2:
       query =
           "select c.cluster_id, c.group_name as uuid, c.cluster_name, "
-          "i.address from "
+          "i.address, i.attributes from "
           "mysql_innodb_cluster_metadata.v2_instances i join "
           "mysql_innodb_cluster_metadata.v2_gr_clusters c on c.cluster_id = "
           "i.cluster_id";
@@ -734,7 +757,8 @@ static ClusterInfo query_metadata_servers(
           "F.cluster_id, "
           "R.attributes->>'$.group_replication_group_name' as uuid, "
           "F.cluster_name, "
-          "JSON_UNQUOTE(JSON_EXTRACT(I.addresses, '$.mysqlClassic')) "
+          "JSON_UNQUOTE(JSON_EXTRACT(I.addresses, '$.mysqlClassic')), "
+          "'' as attributes "
           "FROM "
           "mysql_innodb_cluster_metadata.clusters AS F, "
           "mysql_innodb_cluster_metadata.instances AS I, "
@@ -756,16 +780,21 @@ static ClusterInfo query_metadata_servers(
   try {
     mysql->query(
         query, [&result](const std::vector<const char *> &row) -> bool {
+          const std::string attributes = get_string(row[4]);
+          if (get_instance_type(attributes) == InstanceType::ReadReplica) {
+            // we don't want Read Replicas as metadata servers
+            return true;
+          }
           if (result.cluster_id == "") {
-            result.cluster_id = as_string(row[0]);
-            result.cluster_type_specific_id = as_string(row[1]);
-            result.name = as_string(row[2]);
-          } else if (result.cluster_id != as_string(row[0])) {
+            result.cluster_id = get_string(row[0]);
+            result.cluster_type_specific_id = get_string(row[1]);
+            result.name = get_string(row[2]);
+          } else if (result.cluster_id != get_string(row[0])) {
             // metadata with more than 1 cluster not currently supported
             throw std::runtime_error("Metadata contains more than one cluster");
           }
 
-          result.metadata_servers.push_back("mysql://" + as_string(row[3]));
+          result.metadata_servers.push_back("mysql://" + get_string(row[3]));
           return true;
         });
   } catch (const MySQLSession::Error &e) {
@@ -786,6 +815,24 @@ ClusterInfo ClusterMetadataGRV2::fetch_metadata_servers() {
   return query_metadata_servers(mysql_, ClusterType::GR_V2);
 }
 
+InstanceType ClusterMetadataGRV2::fetch_current_instance_type() {
+  const std::string query =
+      "select i.attributes from mysql_innodb_cluster_metadata.v2_this_instance "
+      "ti left join mysql_innodb_cluster_metadata.v2_instances i "
+      "on ti.instance_id = i.instance_id";
+
+  try {
+    std::unique_ptr<MySQLSession::ResultRow> row(mysql_->query_one(query));
+    if (!row) {
+      return InstanceType::Unsupported;
+    }
+
+    return get_instance_type(get_string((*row)[0]));
+  } catch (const std::exception &e) {
+    throw std::runtime_error("Failed identifying instance type: "s + e.what());
+  }
+}
+
 ClusterMetadataGRInClusterSet::ClusterMetadataGRInClusterSet(
     const MetadataSchemaVersion &schema_version, MySQLSession *mysql,
     const OptionsMap &options, mysql_harness::SocketOperationsBase *sockops)
@@ -855,16 +902,16 @@ ClusterInfo ClusterMetadataGRInClusterSet::fetch_metadata_servers() {
         "expected 4 got " +
         std::to_string(result_cluster_info->size()));
   }
-  result.cluster_id = as_string((*result_cluster_info)[0]);
-  result.cluster_type_specific_id = as_string((*result_cluster_info)[1]);
-  result.name = as_string((*result_cluster_info)[2]);
-  result.is_primary = as_string((*result_cluster_info)[3]) == "PRIMARY";
+  result.cluster_id = get_string((*result_cluster_info)[0]);
+  result.cluster_type_specific_id = get_string((*result_cluster_info)[1]);
+  result.name = get_string((*result_cluster_info)[2]);
+  result.is_primary = get_string((*result_cluster_info)[3]) == "PRIMARY";
 
   // get all the nodes of all the Clusters that belong to the ClusterSet;
   // we want those that belong to the PRIMARY cluster to be first in the
   // resultset
   sqlstring query2 =
-      "SELECT i.address, csm.member_role "
+      "SELECT i.address, i.attributes, csm.member_role "
       "FROM mysql_innodb_cluster_metadata.v2_instances i "
       "LEFT JOIN mysql_innodb_cluster_metadata.v2_cs_members csm "
       "ON i.cluster_id = csm.cluster_id "
@@ -880,18 +927,24 @@ ClusterInfo ClusterMetadataGRInClusterSet::fetch_metadata_servers() {
   query2 << result.cluster_id;
   std::vector<std::string> replica_clusters_nodes;
   try {
-    mysql_->query(query2,
-                  [&result, &replica_clusters_nodes](
-                      const std::vector<const char *> &row) -> bool {
-                    // we want PRIMARY cluster nodes first, so we put them
-                    // directly in the result list, the non-PRIMARY ones we
-                    // buffer and append to the result at the end
-                    auto &servers = (as_string(row[1]) == "PRIMARY")
-                                        ? result.metadata_servers
-                                        : replica_clusters_nodes;
-                    servers.push_back("mysql://" + as_string(row[0]));
-                    return true;
-                  });
+    mysql_->query(
+        query2,
+        [&result, &replica_clusters_nodes](
+            const std::vector<const char *> &row) -> bool {
+          const std::string attributes = get_string(row[1]);
+          if (get_instance_type(attributes) == InstanceType::ReadReplica) {
+            // we don't want Read Replicas as metadata servers
+            return true;
+          }
+          // we want PRIMARY cluster nodes first, so we put them
+          // directly in the result list, the non-PRIMARY ones we
+          // buffer and append to the result at the end
+          auto &servers = (get_string(row[2]) == "PRIMARY")
+                              ? result.metadata_servers
+                              : replica_clusters_nodes;
+          servers.push_back("mysql://" + get_string(row[0]));
+          return true;
+        });
   } catch (const MySQLSession::Error &e) {
     throw std::runtime_error(std::string("Error querying metadata: ") +
                              e.what());
@@ -982,27 +1035,42 @@ static std::vector<std::string> do_get_routing_mode_queries(
             "WHERE F.cluster_name = " +
                 mysql->quote("some_cluster_name");
 
-  return {
-      // MDC startup
-      // source: mysqlrouter::get_group_replication_id(MySQLSession *mysql)
-      "select @@group_replication_group_name",
+  std::string gr_members_query;
+  // replication_group_members.member_role field was introduced in 8.0.2, otoh
+  // group_replication_primary_member gets removed in 8.3 so we need 2 different
+  // queries depending on a server version
+  const bool has_member_role_field = mysql->server_version() >= 80002;
+  if (has_member_role_field) {
+    gr_members_query =
+        "SELECT member_id, member_host, member_port, member_state, "
+        "member_role, @@group_replication_single_primary_mode FROM "
+        "performance_schema.replication_group_members"
+        " WHERE channel_name = 'group_replication_applier'";
+  } else {
+    gr_members_query =
+        "SELECT member_id, member_host, member_port, member_state, "
+        "IF(g.primary_uuid = '' OR member_id = g.primary_uuid, 'PRIMARY', "
+        "'SECONDARY') as member_role, @@group_replication_single_primary_mode "
+        "FROM (SELECT IFNULL(variable_value, '') AS primary_uuid FROM "
+        "performance_schema.global_status WHERE variable_name = "
+        "'group_replication_primary_member') g, "
+        "performance_schema.replication_group_members WHERE channel_name = "
+        "'group_replication_applier'";
+  }
 
-      /* next 3 are called during MDC Refresh; they access all tables that are
-       * GRANTed by bootstrap
-       */
+  return {// MDC startup
+          // source: mysqlrouter::get_group_replication_id(MySQLSession *mysql)
+          "select @@group_replication_group_name",
 
-      // source: ClusterMetadata::fetch_instances_from_metadata_server()
-      fetch_instances_query,
+          /* next 2 are called during MDC Refresh; they access all tables that
+           * are GRANTed by bootstrap
+           */
 
-      // source: find_group_replication_primary_member()
-      "show status like 'group_replication_primary_member'",
+          // source: ClusterMetadata::fetch_instances_from_metadata_server()
+          fetch_instances_query,
 
-      // source: fetch_group_replication_members()
-      "SELECT member_id, member_host, member_port, member_state, "
-      "@@group_replication_single_primary_mode FROM "
-      "performance_schema.replication_group_members WHERE channel_name = "
-      "'group_replication_applier'",
-  };
+          // source: fetch_group_replication_members()
+          gr_members_query};
 }
 
 std::vector<std::string> ClusterMetadataGRV1::get_routing_mode_queries() {
@@ -1157,7 +1225,7 @@ static bool was_bootstrapped_as_clusterset(MySQLSession *mysql,
     return false;
   }
 
-  return as_string((*row)[0]) == kClusterSet;
+  return get_string((*row)[0]) == kClusterSet;
 }
 
 ClusterType get_cluster_type(const MetadataSchemaVersion &schema_version,
@@ -1342,4 +1410,31 @@ stdx::expected<void, std::string> setup_metadata_session(
   return {};
 }
 
+std::optional<InstanceType> str_to_instance_type(const std::string &s) {
+  if (s == "group-member") {
+    return InstanceType::GroupMember;
+  } else if (s == "async-member") {
+    return InstanceType::AsyncMember;
+  } else if (s == "read-replica") {
+    return InstanceType::ReadReplica;
+  }
+
+  return std::nullopt;
+}
+
+std::string to_string(const InstanceType instance_type) {
+  switch (instance_type) {
+    case InstanceType::GroupMember:
+      return "group-member";
+    case InstanceType::AsyncMember:
+      return "async-member";
+    case InstanceType::ReadReplica:
+      return "read-replica";
+    case InstanceType::Unsupported:
+        /* fallthrough */;
+  }
+
+  return "unsupported";
+}
+
 }  // namespace mysqlrouter
