@@ -1,16 +1,15 @@
-/* Copyright (c) 2000, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2000, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    Without limiting anything contained in the foregoing, this file,
    which is part of C Driver for MySQL (Connector/C), is also subject to the
@@ -243,7 +242,7 @@ bool net_realloc(NET *net, size_t length) {
 #ifdef MYSQL_SERVER
   net->buff = net->write_pos = buff;
 #else
-  size_t cur_pos_offset = NET_ASYNC_DATA(net)->cur_pos - net->buff;
+  const size_t cur_pos_offset = NET_ASYNC_DATA(net)->cur_pos - net->buff;
   net->buff = net->write_pos = buff;
   NET_ASYNC_DATA(net)->cur_pos = net->buff + cur_pos_offset;
 #endif
@@ -538,11 +537,11 @@ static int begin_packet_write_state(NET *net, uchar command,
   }
   NET_ASYNC *net_async = NET_ASYNC_DATA(net);
   size_t total_len = packet_len + prefix_len;
-  bool include_command = (command < COM_END);
+  const bool include_command = (command < COM_END);
   if (include_command) {
     ++total_len;
   }
-  size_t packet_count = 1 + total_len / MAX_PACKET_LENGTH;
+  const size_t packet_count = 1 + total_len / MAX_PACKET_LENGTH;
   reset_packet_write_state(net);
 
   struct io_vec *vec;
@@ -663,7 +662,7 @@ static int begin_packet_write_state(NET *net, uchar command,
       Final iovec, the payload itself. Send however many bytes from
       packet we have left, and advance our packet pointer.
     */
-    size_t remaining_bytes = packet_size - bytes_queued;
+    const size_t remaining_bytes = packet_size - bytes_queued;
     (*vec).iov_base = const_cast<uchar *>(packet);
     (*vec).iov_len = remaining_bytes;
 
@@ -759,7 +758,7 @@ static net_async_status net_write_vector_nonblocking(NET *net, ssize_t *res) {
       }
       return NET_ASYNC_COMPLETE;
     }
-    size_t bytes_written = static_cast<size_t>(*res);
+    const size_t bytes_written = static_cast<size_t>(*res);
     vec->iov_len -= bytes_written;
     vec->iov_base = (char *)vec->iov_base + bytes_written;
 
@@ -903,9 +902,9 @@ bool net_write_command(NET *net, uchar command, const uchar *header,
   }
   int3store(buff, static_cast<uint>(length));
   buff[3] = (uchar)net->pkt_nr++;
-  bool rc = net_write_buff(net, buff, header_size) ||
-            (head_len && net_write_buff(net, header, head_len)) ||
-            net_write_buff(net, packet, len) || net_flush(net);
+  const bool rc = net_write_buff(net, buff, header_size) ||
+                  (head_len && net_write_buff(net, header, head_len)) ||
+                  net_write_buff(net, packet, len) || net_flush(net);
   return rc;
 }
 
@@ -932,7 +931,7 @@ bool net_write_command(NET *net, uchar command, const uchar *header,
   @retval
     0	ok
   @retval
-    1
+    1   error
 */
 
 static bool net_write_buff(NET *net, const uchar *packet, size_t len) {
@@ -991,7 +990,7 @@ static bool net_write_raw_loop(NET *net, const uchar *buf, size_t count) {
   unsigned int retry_count = 0;
 
   while (count) {
-    size_t sentcnt = vio_write(net->vio, buf, count);
+    const size_t sentcnt = vio_write(net->vio, buf, count);
 
     /* VIO_SOCKET_ERROR (-1) indicates an error. */
     if (sentcnt == VIO_SOCKET_ERROR) {
@@ -1056,6 +1055,9 @@ static bool net_write_raw_loop(NET *net, const uchar *buf, size_t count) {
     - Server finishes the @ref page_protocol_connection_phase with an
       @ref page_protocol_basic_ok_packet.
 
+   If both ::CLIENT_COMPRESS and ::CLIENT_ZSTD_COMPRESSION_ALGORITHM are set
+   then zlib is used.
+
    @subpage page_protocol_basic_compression_packet
 */
 
@@ -1080,6 +1082,9 @@ static bool net_write_raw_loop(NET *net, const uchar *buf, size_t count) {
   <td>compressed sequence id</td>
   <td>Sequence ID of the compressed packets, reset in the same way as the
      @ref sect_protocol_basic_packets_packet, but incremented independently</td></tr>
+  <tr><td>@ref a_protocol_type_int3 "int&lt;3&gt;"</td>
+  <td>length of uncompressed payload</td>
+  <td>Length of payload before compression</td></tr>
   </table>
 
   @section sect_protocol_basic_compression_packet_compressed_payload Compressed Payload
@@ -1088,10 +1093,11 @@ static bool net_write_raw_loop(NET *net, const uchar *buf, size_t count) {
   @ref sect_protocol_basic_compression_packet_header is followed by the
   compressed payload.
 
-  It uses the *deflate* algorithm as described in
+  Depending on which capability flags are set it uses the *deflate* algorithm as described in
   [RFC 1951](http://tools.ietf.org/html/rfc1951.html) and implemented in
-  [zlib](http://zlib.org/). The header of the compressed packet has the
-  parameters of the `uncompress()` function in mind:
+  [zlib](http://zlib.org/) or [Zstandard](https://facebook.github.io/zstd/).
+
+  When using zlib, the header of the compressed packet has the parameters of the `uncompress()` function in mind:
 
   ~~~~~~~~~~~~~
   ZEXTERN int ZEXPORT uncompress OF((Bytef *dest,   uLongf *destLen,
@@ -1355,7 +1361,7 @@ static bool net_read_raw_loop(NET *net, size_t count) {
   time_t start_time = 0;
   if (timeout_on_full_packet) start_time = time(&start_time);
   while (count) {
-    size_t recvcnt = vio_read(net->vio, buf, count);
+    const size_t recvcnt = vio_read(net->vio, buf, count);
 
     /* VIO_SOCKET_ERROR (-1) indicates an error. */
     if (recvcnt == VIO_SOCKET_ERROR) {
@@ -1844,9 +1850,9 @@ begin:
                       "net->where_b : %lu, multi_byte_packet : %u ",
                       buf_length, net->remain_in_buf, first_packet_offset,
                       start_of_packet, net->where_b, multi_byte_packet));
-  size_t remain_in_buf = buf_length - start_of_packet;
+  const size_t remain_in_buf = buf_length - start_of_packet;
   if (remain_in_buf >= NET_HEADER_SIZE) {
-    size_t read_length = uint3korr(net->buff + start_of_packet);
+    const size_t read_length = uint3korr(net->buff + start_of_packet);
     DBUG_PRINT("info", ("read_length : %zu", read_length));
     if (!read_length) {
       start_of_packet += NET_HEADER_SIZE; /* End of multi-byte packet */
@@ -1923,8 +1929,8 @@ static ulong net_read_update_offsets(NET *net, size_t start_of_packet,
   net->read_pos = net->buff + first_packet_offset + NET_HEADER_SIZE;
   net->buf_length = buf_length;
   net->remain_in_buf = (ulong)(buf_length - start_of_packet);
-  ulong len = ((ulong)(start_of_packet - first_packet_offset) -
-               NET_HEADER_SIZE - multi_byte_packet);
+  const ulong len = ((ulong)(start_of_packet - first_packet_offset) -
+                     NET_HEADER_SIZE - multi_byte_packet);
   if (net->remain_in_buf) {
     /*
       If multi byte packet is non-zero then there is a zero length
@@ -2166,7 +2172,7 @@ static void net_read_uncompressed_packet(NET *net, size_t &len) {
   len = net_read_packet(net, &complen);
   if (len == MAX_PACKET_LENGTH) {
     /* First packet of a multi-packet.  Concatenate the packets */
-    ulong save_pos = net->where_b;
+    const ulong save_pos = net->where_b;
     size_t total_length = 0;
     do {
       net->where_b += len;
