@@ -1,16 +1,15 @@
-/* Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2019, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,6 +24,7 @@
 
 #include <errno.h>
 #include <fcntl.h>
+#include <stdint.h>
 #include <sys/types.h>
 
 #include "sql/dd/upgrade/server.h"
@@ -33,9 +33,10 @@
 #endif
 #include <vector>
 
-#include "lex_string.h"
 #include "my_dbug.h"
 #include "mysql/components/services/log_builtins.h"
+#include "mysql/strings/m_ctype.h"
+#include "nulls.h"
 #include "scripts/mysql_fix_privilege_tables_sql.h"
 #include "scripts/sql_commands_system_tables_data_fix.h"
 #include "scripts/sql_firewall_stored_procedures.h"
@@ -65,8 +66,9 @@
 #include "sql/thd_raii.h"
 #include "sql/trigger.h"  // Trigger
 #include "sql/trigger_def.h"
+#include "string_with_len.h"
 
-typedef ulonglong sql_mode_t;
+using sql_mode_t = uint64_t;
 extern const char *mysql_sys_schema[];
 extern const char *fill_help_tables[];
 
