@@ -1,19 +1,18 @@
 #ifndef SQL_ITERATORS_HASH_JOIN_ITERATOR_H_
 #define SQL_ITERATORS_HASH_JOIN_ITERATOR_H_
 
-/* Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2019, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +24,9 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 #include <stdio.h>
+#include <cassert>
 #include <cstdint>
+#include <memory>
 #include <vector>
 
 #include "my_alloc.h"
@@ -40,10 +41,10 @@
 #include "sql/join_type.h"
 #include "sql/mem_root_array.h"
 #include "sql/pack_rows.h"
-#include "sql/table.h"
 #include "sql_string.h"
 
 class Item;
+class JOIN;
 class THD;
 
 struct ChunkPair {
@@ -250,6 +251,15 @@ struct ChunkPair {
 /// a lookup structure using a row ID as the key. Due to this, we will
 /// reconsider this if the hash join type IN_MEMORY_WITH_HASH_TABLE_REFILL goes
 /// away.
+
+/// The two inputs that we read from when executing a hash join.
+enum class HashJoinInput {
+  /// We build the hash table from this input.
+  kBuild,
+  /// For each row from this input, we try to find a match in the hash table.
+  kProbe
+};
+
 class HashJoinIterator final : public RowIterator {
  public:
   /// Construct a HashJoinIterator.
@@ -296,6 +306,9 @@ class HashJoinIterator final : public RowIterator {
   ///   A list of extra conditions that the iterator will evaluate after a
   ///   lookup in the hash table is done, but before the row is returned. The
   ///   conditions are AND-ed together into a single Item.
+  /// @param first_input
+  ///   The first input (build or probe) to read from. (If this is empty, we
+  ///   will not have to read from the other.)
   /// @param probe_input_batch_mode
   ///   Whether we need to enable batch mode on the probe input table.
   ///   Only make sense if it is a single table, and we are not on the
@@ -316,7 +329,7 @@ class HashJoinIterator final : public RowIterator {
                    const std::vector<HashJoinCondition> &join_conditions,
                    bool allow_spill_to_disk, JoinType join_type,
                    const Mem_root_array<Item *> &extra_conditions,
-                   bool probe_input_batch_mode,
+                   HashJoinInput first_input, bool probe_input_batch_mode,
                    uint64_t *hash_table_generation);
 
   bool Init() override;
@@ -324,6 +337,10 @@ class HashJoinIterator final : public RowIterator {
   int Read() override;
 
   void SetNullRowFlag(bool is_null_row) override {
+    // Don't call this after Init() but before calling Read() for the first
+    // time. Init() may have loaded a row that is (partially or fully) a null
+    // row, so resetting the null row flags is incorrect.
+    assert(!m_probe_row_read || m_state == State::END_OF_ROWS);
     m_build_input->SetNullRowFlag(is_null_row);
     m_probe_input->SetNullRowFlag(is_null_row);
   }
@@ -535,6 +552,15 @@ class HashJoinIterator final : public RowIterator {
   // It is incremented during the state LOADING_NEXT_CHUNK_PAIR.
   int m_current_chunk{-1};
 
+  // Which row we currently are reading from each of the hash join chunk file.
+  ha_rows m_build_chunk_current_row = 0;
+  ha_rows m_probe_chunk_current_row = 0;
+
+  // How many rows we assume there will be when reading the build input.
+  // This is used to choose how many chunks we break it into on disk.
+  const double m_estimated_build_rows;
+
+ public:
   // The seed that is by xxHash64 when calculating the hash from a join
   // key. We use xxHash64 when calculating the hash that is used for
   // determining which chunk file a row should be placed in (in case of
@@ -544,14 +570,6 @@ class HashJoinIterator final : public RowIterator {
   // no special meaning.
   static constexpr uint32_t kChunkPartitioningHashSeed{899339};
 
-  // Which row we currently are reading from each of the hash join chunk file.
-  ha_rows m_build_chunk_current_row = 0;
-  ha_rows m_probe_chunk_current_row = 0;
-
-  // How many rows we assume there will be when reading the build input.
-  // This is used to choose how many chunks we break it into on disk.
-  const double m_estimated_build_rows;
-
   // The maximum number of HashJoinChunks that is allocated for each of the
   // inputs in case we spill to disk. We might very well end up with an amount
   // less than this number, but we keep an upper limit so we don't risk running
@@ -560,6 +578,7 @@ class HashJoinIterator final : public RowIterator {
   // should be placed in.
   static constexpr size_t kMaxChunks = 128;
 
+ private:
   // A buffer that is used during two phases:
   // 1) when constructing a join key from join conditions.
   // 2) when moving a row between tables' record buffers and the hash table.
@@ -575,6 +594,10 @@ class HashJoinIterator final : public RowIterator {
   // duration of the iterator, so that we (most likely) avoid reallocations.
   String m_temporary_row_and_join_key_buffer;
 
+  /// The first input (build or probe) to read from. (If this is empty, we will
+  /// not have to read from the other.)
+  HashJoinInput m_first_input;
+
   // Whether we should turn on batch mode for the probe input. Batch mode is
   // enabled if the probe input consists of exactly one table, and said table
   // can return more than one row and has no associated subquery condition.
@@ -654,6 +677,21 @@ class HashJoinIterator final : public RowIterator {
   // row, causing any local match flag to lose the match flag info from the last
   // probe row read.
   bool m_probe_row_match_flag{false};
+
+  /// If true, a row was already read from the probe input, in order to check if
+  /// that input was empty. If so, we should process that row before reading
+  /// another.
+  bool m_probe_row_read{false};
+
+  /// Helper function for Init(). Read the first row from m_probe_input.
+  /// @returns 'true' if there was an error.
+  bool ReadFirstProbeRow();
+
+  /// Helper function for Init(). Build the hash table and check for empty query
+  /// results (empty build input or non-empty build input in case of degenerate
+  /// antijoin.)
+  /// @returns 'true' in case of error.
+  bool InitHashTable();
 };
 
 #endif  // SQL_ITERATORS_HASH_JOIN_ITERATOR_H_
