@@ -50,7 +50,7 @@ namespace memory {
 static inline size_t _cache_line_size() {
   size_t line_size{0};
   size_t sizeof_line_size = sizeof(line_size);
-  sysctlbyname("hw.cachelinesize", &line_size, &sizeof_line_size, 0, 0);
+  sysctlbyname("hw.cachelinesize", &line_size, &sizeof_line_size, nullptr, 0);
   return line_size;
 }
 
@@ -135,6 +135,10 @@ static inline size_t minimum_cacheline_for() {
   return size;
 }
 
+/// @brief Template that may access Aligned_atomic internals
+template <class T>
+class Aligned_atomic_accessor;
+
 /**
   @class memory::Aligned_atomic
 
@@ -295,6 +299,9 @@ class Aligned_atomic {
    */
   size_t allocated_size() const;
 
+  template <typename Accessor_type>
+  friend class Aligned_atomic_accessor;
+
  private:
   /** The size of the byte buffer. */
   size_t m_storage_size{0};
