@@ -109,10 +109,9 @@ typedef Bitmap<((MAX_INDEXES + 7) / 8 * 8)> Key_map; /* Used for finding keys */
 #define TEST_NO_TEMP_TABLES \
   8192 /**< No temp table engine is loaded, so use dummy costs. */
 
-#define SPECIAL_NO_NEW_FUNC 2     /* Skip new functions */
-#define SPECIAL_SKIP_SHOW_DB 4    /* Don't allow 'show db' */
-#define SPECIAL_NO_RESOLVE 64     /* Don't use gethostname */
-#define SPECIAL_NO_HOST_CACHE 512 /* Don't cache hosts */
+#define SPECIAL_NO_NEW_FUNC 2  /* Skip new functions */
+#define SPECIAL_SKIP_SHOW_DB 4 /* Don't allow 'show db' */
+#define SPECIAL_NO_RESOLVE 64  /* Don't use gethostname */
 #define SPECIAL_SHORT_LOG_FORMAT 1024
 
 extern bool dynamic_plugins_are_initialized;
@@ -171,7 +170,6 @@ extern bool opt_disable_networking, opt_skip_show_db;
 extern bool opt_skip_name_resolve;
 extern bool opt_help;
 extern bool opt_verbose;
-extern bool opt_character_set_client_handshake;
 extern MYSQL_PLUGIN_IMPORT std::atomic<int32>
     connection_events_loop_aborted_flag;
 extern bool opt_no_dd_upgrade;
@@ -204,12 +202,6 @@ extern bool read_only, opt_readonly;
 extern bool super_read_only, opt_super_readonly;
 extern bool lower_case_file_system;
 
-enum enum_slave_rows_search_algorithms {
-  SLAVE_ROWS_TABLE_SCAN = (1U << 0),
-  SLAVE_ROWS_INDEX_SCAN = (1U << 1),
-  SLAVE_ROWS_HASH_SCAN = (1U << 2)
-};
-extern ulonglong slave_rows_search_algorithms_options;
 extern bool opt_require_secure_transport;
 
 extern bool opt_replica_preserve_commit_order;
@@ -228,7 +220,7 @@ extern bool opt_allow_suspicious_udfs;
 extern const char *opt_secure_file_priv;
 extern bool opt_log_slow_admin_statements, opt_log_slow_replica_statements;
 extern bool sp_automatic_privileges, opt_noacl;
-extern bool opt_old_style_user_limits, trust_function_creators;
+extern bool trust_function_creators;
 extern bool check_proxy_users, mysql_native_password_proxy_users,
     sha256_password_proxy_users;
 #ifdef _WIN32
@@ -322,7 +314,6 @@ extern uint replica_net_timeout;
 extern ulong opt_mts_replica_parallel_workers;
 extern ulonglong opt_mts_pending_jobs_size_max;
 extern ulong rpl_stop_replica_timeout;
-extern bool log_bin_use_v1_row_events;
 extern ulong what_to_log, flush_time;
 extern ulong max_prepared_stmt_count, prepared_stmt_count;
 extern ulong open_files_limit;
@@ -382,6 +373,7 @@ extern struct my_option my_long_early_options[];
 extern "C" MYSQL_PLUGIN_IMPORT bool mysqld_server_started;
 extern "C" MYSQL_PLUGIN_IMPORT int orig_argc;
 extern "C" MYSQL_PLUGIN_IMPORT char **orig_argv;
+extern bool server_shutting_down;
 extern my_thread_attr_t connection_attrib;
 extern bool old_mode;
 extern bool avoid_temporal_upgrade;
@@ -472,7 +464,7 @@ extern PSI_rwlock_key key_rwlock_LOCK_logger;
 extern PSI_rwlock_key key_rwlock_channel_map_lock;
 extern PSI_rwlock_key key_rwlock_channel_lock;
 extern PSI_rwlock_key key_rwlock_gtid_mode_lock;
-extern PSI_rwlock_key key_rwlock_receiver_sid_lock;
+extern PSI_rwlock_key key_rwlock_receiver_tsid_lock;
 extern PSI_rwlock_key key_rwlock_rpl_filter_lock;
 extern PSI_rwlock_key key_rwlock_channel_to_filter_lock;
 extern PSI_rwlock_key key_rwlock_resource_group_mgr_map_lock;
@@ -568,8 +560,8 @@ extern PSI_stage_info stage_execution_of_init_command;
 extern PSI_stage_info stage_explaining;
 extern PSI_stage_info
     stage_finished_reading_one_binlog_switching_to_next_binlog;
-extern PSI_stage_info stage_flushing_relay_log_and_source_info_repository;
-extern PSI_stage_info stage_flushing_relay_log_info_file;
+extern PSI_stage_info stage_flushing_applier_and_connection_metadata;
+extern PSI_stage_info stage_flushing_applier_metadata;
 extern PSI_stage_info stage_freeing_items;
 extern PSI_stage_info stage_fulltext_initialization;
 extern PSI_stage_info stage_init;
@@ -733,6 +725,7 @@ extern mysql_cond_t COND_manager;
 extern mysql_rwlock_t LOCK_sys_init_connect;
 extern mysql_rwlock_t LOCK_sys_init_replica;
 extern mysql_rwlock_t LOCK_system_variables_hash;
+extern mysql_rwlock_t LOCK_server_shutting_down;
 
 extern ulong opt_ssl_fips_mode;
 
@@ -829,6 +822,7 @@ extern mysql_component_t mysql_component_performance_schema;
 /* This variable is a registry handler, defined in mysql_server component and
    used as a output parameter for minimal chassis. */
 extern SERVICE_TYPE_NO_CONST(registry) * srv_registry;
+extern SERVICE_TYPE_NO_CONST(registry) * srv_registry_no_lock;
 /* These global variables which are defined and used in
    mysql_server component */
 extern SERVICE_TYPE(dynamic_loader_scheme_file) * scheme_file_srv;
