@@ -1,16 +1,15 @@
-/* Copyright (c) 2016, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2016, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,7 +41,6 @@
 
 #include "keyring_operations_helper.h"
 #include "lex_string.h"
-#include "m_ctype.h"
 #include "m_string.h"
 #include "my_aes.h"
 #include "my_compiler.h"
@@ -50,7 +48,6 @@
 #include "my_default.h"  // check_file_permissions
 #include "my_getopt.h"
 #include "my_io.h"
-#include "my_loglevel.h"
 #include "my_macros.h"
 #include "my_rnd.h"
 #include "my_sys.h"
@@ -62,12 +59,15 @@
 #include "mysql/components/services/log_builtins.h"
 #include "mysql/components/services/log_shared.h"
 #include "mysql/components/services/system_variable_source_type.h"
+#include "mysql/my_loglevel.h"
 #include "mysql/psi/mysql_file.h"
 #include "mysql/psi/mysql_memory.h"
 #include "mysql/psi/mysql_mutex.h"
 #include "mysql/status_var.h"
+#include "mysql/strings/m_ctype.h"
 #include "mysql_version.h"
 #include "mysqld_error.h"
+#include "nulls.h"
 #include "prealloced_array.h"
 #include "scope_guard.h"
 #include "sql-common/json_dom.h"
@@ -199,7 +199,7 @@ std::string tolower_varname(const char *name) {
 
 st_persist_var::st_persist_var() {
   if (current_thd) {
-    my_timeval tv =
+    const my_timeval tv =
         current_thd->query_start_timeval_trunc(DATETIME_MAX_DECIMALS);
     timestamp = tv.m_tv_sec * 1000000ULL + tv.m_tv_usec;
   } else
@@ -208,7 +208,7 @@ st_persist_var::st_persist_var() {
 }
 
 st_persist_var::st_persist_var(THD *thd) {
-  my_timeval tv = thd->query_start_timeval_trunc(DATETIME_MAX_DECIMALS);
+  const my_timeval tv = thd->query_start_timeval_trunc(DATETIME_MAX_DECIMALS);
   timestamp = tv.m_tv_sec * 1000000ULL + tv.m_tv_usec;
   user = thd->security_context()->user().str;
   host = thd->security_context()->host().str;
@@ -351,7 +351,7 @@ Persisted_variables_cache *Persisted_variables_cache::get_instance() {
 */
 static bool check_boolean_value(const char *value, String &bool_str) {
   bool ret = false;
-  bool result = get_bool_argument(value, &ret);
+  const bool result = get_bool_argument(value, &ret);
   if (ret) return true;
   if (result) {
     bool_str = String("ON", system_charset_info);
@@ -391,6 +391,7 @@ bool Persisted_variables_cache::set_variable(THD *thd, set_var *setvar) {
       String bool_str;
       if (setvar->value) {
         res = setvar->value->val_str(&str);
+        if (setvar->value->is_null()) is_null = true;
         if (system_var->get_var_type() == GET_BOOL) {
           if (res == nullptr ||
               check_boolean_value(res->c_ptr_quick(), bool_str)) {
@@ -433,7 +434,7 @@ bool Persisted_variables_cache::set_variable(THD *thd, set_var *setvar) {
 
     auto assign_value = [&](const char *name) -> bool {
       struct st_persist_var tmp_var(thd);
-      bool is_sensitive = system_var->is_sensitive();
+      const bool is_sensitive = system_var->is_sensitive();
 
       if (is_sensitive && !m_keyring_support_available) {
         if (!opt_persist_sensitive_variables_in_plaintext) {
@@ -674,7 +675,7 @@ bool Persisted_variables_cache::write_persist_file_v2(String &dest,
                                                       bool &clean_up) {
   clean_up = false;
   Json_object main_json_object;
-  string key_version("Version");
+  const string key_version("Version");
   Json_int value_version(static_cast<int>(File_version::VERSION_V2));
   main_json_object.add_clone(key_version.c_str(), &value_version);
 
@@ -766,8 +767,7 @@ bool Persisted_variables_cache::write_persist_file_v2(String &dest,
   Json_wrapper json_wrapper(&main_json_object);
   json_wrapper.set_alias();
   String str;
-  json_wrapper.to_string(&str, true, String().ptr(),
-                         JsonDocumentDefaultDepthHandler);
+  json_wrapper.to_string(&str, true, String().ptr(), JsonDepthErrorHandler);
   dest.append(str);
 
   if (encryption_success == return_status::SUCCESS) {
@@ -940,7 +940,8 @@ bool Persisted_variables_cache::set_persisted_options(
     bool plugin_options, const char *target_var_name,
     int target_var_name_length) {
   THD *thd;
-  bool result = false, new_thd = false;
+  const bool result = false;
+  bool new_thd = false;
   const std::vector<std::string> priv_list = {
       "ENCRYPTION_KEY_ADMIN", "ROLE_ADMIN",          "SYSTEM_VARIABLES_ADMIN",
       "AUDIT_ADMIN",          "TELEMETRY_LOG_ADMIN", "CONNECTION_ADMIN"};
@@ -1905,7 +1906,7 @@ int Persisted_variables_cache::read_persist_file() {
     /* parse the file contents to check if it is in json format or not */
     json = Json_dom::parse(
         parsed_value.c_str(), parsed_value.length(),
-        [](const char *, size_t) {}, JsonDocumentDefaultDepthHandler);
+        [](const char *, size_t) {}, JsonDepthErrorHandler);
     if (!json.get()) return true;
     return false;
   };
@@ -2095,7 +2096,7 @@ bool Persisted_variables_cache::append_read_only_variables(
    reasd only options to be appendded
   */
   if (my_args.size()) {
-    unsigned int extra_args = (arg_separator_added == false) ? 2 : 1;
+    const unsigned int extra_args = (arg_separator_added == false) ? 2 : 1;
     char **res = new (&alloc) char *[my_args.size() + *argc + extra_args];
     if (res == nullptr) goto err;
     memset(res, 0, (sizeof(char *) * (my_args.size() + *argc + extra_args)));
@@ -2151,7 +2152,7 @@ bool Persisted_variables_cache::reset_persisted_variables(THD *thd,
                                                           const char *name,
                                                           bool if_exists) {
   bool result = false, found = false;
-  bool reset_all = (name ? 0 : 1);
+  const bool reset_all = (name ? 0 : 1);
   /* update on m_persisted_dynamic_variables/m_persisted_static_variables must
    * be thread safe */
   lock();
@@ -2448,7 +2449,7 @@ bool Persisted_variables_cache::get_file_encryption_key(
       return retval;
 
     /* encrypt file key */
-    size_t encrypted_key_length =
+    const size_t encrypted_key_length =
         (file_key_length / MY_AES_BLOCK_SIZE) * MY_AES_BLOCK_SIZE;
     std::unique_ptr<unsigned char[]> encrypted_key =
         std::make_unique<unsigned char[]>(encrypted_key_length);
@@ -2472,8 +2473,8 @@ bool Persisted_variables_cache::get_file_encryption_key(
     retval = false;
   } else {
     /* File key exists, decrypt it */
-    std::string unhex_key = from_hex(m_key_info.m_file_key);
-    std::string unhex_iv = from_hex(m_key_info.m_file_key_iv);
+    const std::string unhex_key = from_hex(m_key_info.m_file_key);
+    const std::string unhex_iv = from_hex(m_key_info.m_file_key_iv);
 
     std::unique_ptr<unsigned char[]> decrypted_file_key =
         std::make_unique<unsigned char[]>(unhex_key.length());
@@ -2536,13 +2537,13 @@ Persisted_variables_cache::encrypt_sensitive_variables() {
   Json_wrapper json_wrapper(&sensitive_variables_object);
   json_wrapper.set_alias();
   String str;
-  json_wrapper.to_string(&str, true, String().ptr(),
-                         JsonDocumentDefaultDepthHandler);
+  json_wrapper.to_string(&str, true, String().ptr(), JsonDepthErrorHandler);
 
   /* Encrypt sensitive variables */
   unsigned char iv[16];
   if (my_rand_buffer(iv, sizeof(iv))) return retval;
-  size_t data_len = (str.length() / MY_AES_BLOCK_SIZE + 1) * MY_AES_BLOCK_SIZE;
+  const size_t data_len =
+      (str.length() / MY_AES_BLOCK_SIZE + 1) * MY_AES_BLOCK_SIZE;
   std::unique_ptr<unsigned char[]> encrypted_buffer =
       std::make_unique<unsigned char[]>(data_len);
   if (encrypted_buffer.get() == nullptr) return retval;
@@ -2588,8 +2589,8 @@ Persisted_variables_cache::decrypt_sensitive_variables() {
   if (get_file_encryption_key(file_key, file_key_length, false)) return retval;
 
   /* Convert from hex to binary */
-  std::string unhex_iv = from_hex(m_iv);
-  std::string unhex_data = from_hex(m_sensitive_variables_blob);
+  const std::string unhex_iv = from_hex(m_iv);
+  const std::string unhex_data = from_hex(m_sensitive_variables_blob);
 
   /* Decrypt the blob */
   std::unique_ptr<unsigned char[]> decrypted_data =
@@ -2611,7 +2612,7 @@ Persisted_variables_cache::decrypt_sensitive_variables() {
   /* Parse the decrypted blob */
   std::unique_ptr<Json_dom> json(Json_dom::parse(
       reinterpret_cast<char *>(decrypted_data.get()), error,
-      [](const char *, size_t) {}, JsonDocumentDefaultDepthHandler));
+      [](const char *, size_t) {}, JsonDepthErrorHandler));
   if (!json.get()) return retval;
 
   if (json.get()->json_type() != enum_json_type::J_OBJECT) return retval;
