@@ -1,4 +1,4 @@
-/* Copyright (c) 2011, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2011, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -35,26 +35,26 @@
 #include "sql/psi_memory_key.h"
 #include "sql/rpl_gtid.h"
 
-Owned_gtids::Owned_gtids(Checkable_rwlock *_sid_lock)
-    : sid_lock(_sid_lock),
+Owned_gtids::Owned_gtids(Checkable_rwlock *_tsid_lock)
+    : tsid_lock(_tsid_lock),
       sidno_to_hash(key_memory_Owned_gtids_sidno_to_hash) {}
 
 Owned_gtids::~Owned_gtids() {
   // destructor should only be called when no other thread may access object
-  // sid_lock->assert_no_lock();
+  // tsid_lock->assert_no_lock();
   // need to hold lock before calling get_max_sidno
-  sid_lock->rdlock();
+  tsid_lock->rdlock();
   rpl_sidno max_sidno = get_max_sidno();
   for (int sidno = 1; sidno <= max_sidno; sidno++) {
     delete get_hash(sidno);
   }
-  sid_lock->unlock();
-  // sid_lock->assert_no_lock();
+  tsid_lock->unlock();
+  // tsid_lock->assert_no_lock();
 }
 
 enum_return_status Owned_gtids::ensure_sidno(rpl_sidno sidno) {
   DBUG_TRACE;
-  sid_lock->assert_some_wrlock();
+  tsid_lock->assert_some_wrlock();
   rpl_sidno max_sidno = get_max_sidno();
   if (sidno > max_sidno || get_hash(sidno) == nullptr) {
     for (int i = max_sidno; i < sidno; i++) {
@@ -70,8 +70,10 @@ enum_return_status Owned_gtids::add_gtid_owner(const Gtid &gtid,
                                                my_thread_id owner) {
   DBUG_TRACE;
   assert(gtid.sidno <= get_max_sidno());
+  assert(gtid.gno > 0);
+  assert(gtid.gno < GNO_END);
   Node *n =
-      (Node *)my_malloc(key_memory_Sid_map_Node, sizeof(Node), MYF(MY_WME));
+      (Node *)my_malloc(key_memory_tsid_map_Node, sizeof(Node), MYF(MY_WME));
   if (n == nullptr) RETURN_REPORTED_ERROR;
   n->gno = gtid.gno;
   n->owner = owner;
@@ -100,7 +102,7 @@ void Owned_gtids::remove_gtid(const Gtid &gtid, const my_thread_id owner) {
 
 bool Owned_gtids::is_intersection_nonempty(const Gtid_set *other) const {
   DBUG_TRACE;
-  if (sid_lock != nullptr) sid_lock->assert_some_wrlock();
+  if (tsid_lock != nullptr) tsid_lock->assert_some_wrlock();
   Gtid_iterator git(this);
   Gtid g = git.get();
   while (g.sidno != 0) {
@@ -114,7 +116,7 @@ bool Owned_gtids::is_intersection_nonempty(const Gtid_set *other) const {
 void Owned_gtids::get_gtids(Gtid_set &gtid_set) const {
   DBUG_TRACE;
 
-  if (sid_lock != nullptr) sid_lock->assert_some_wrlock();
+  if (tsid_lock != nullptr) tsid_lock->assert_some_wrlock();
 
   Gtid_iterator git(this);
   Gtid g = git.get();
@@ -128,7 +130,7 @@ void Owned_gtids::get_gtids(Gtid_set &gtid_set) const {
 bool Owned_gtids::contains_gtid(const Gtid &gtid) const {
   malloc_unordered_multimap<rpl_gno, unique_ptr_my_free<Node>> *hash =
       get_hash(gtid.sidno);
-  sid_lock->assert_some_lock();
+  tsid_lock->assert_some_lock();
   return hash->count(gtid.gno) != 0;
 }
 
