@@ -1,4 +1,4 @@
-/* Copyright (c) 2020, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2020, 2023, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
@@ -43,8 +43,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 #include "mysql/psi/mysql_mutex.h"
 #include "sql/log.h"
 #include "sql/psi_memory_key.h"  // key_memory_log_error_stack
-
-extern bool log_builtins_inited;
+#include "sql/server_component/log_builtins_internal.h"
 
 /**
   Make sure only one instance of the buffered "writer" runs at a time.
@@ -70,52 +69,22 @@ extern bool log_builtins_inited;
   buffer / backlog. As this backlog can be added to by all threads,
   it must be protected by a lock (once we have fully initialized
   the subsystem with log_builtins_init() and support multi-threaded
-  mode anyway, as indicated by log_builtins_inited being true, see
-  below). This is that lock.
+  mode anyway, as indicated by log_builtins_started being non-zero,
+  see below). This is that lock.
 */
 mysql_mutex_t THR_LOCK_log_buffered;
 
-struct log_line_buffer {
-  log_line ll;            ///< log-event we're buffering
-  log_line_buffer *next;  ///< chronologically next log-event
-};
 /// Pointer to the first element in the list of buffered log messages
 static log_line_buffer *log_line_buffer_start = nullptr;
 /// Where to write the pointer to the newly-created tail-element of the list
 static log_line_buffer **log_line_buffer_tail = &log_line_buffer_start;
 
-/**
-  Timestamp: During buffered logging, when should we next consider flushing?
-  This variable is set to the time we'll next check whether we'll want to
-  flush buffered log events.
-  I.e. it is set to a future time (current time + window length); once
-  the value expires (turns into present/past), we check whether we need
-  to flush and update the variable to the next time we should check.
-*/
-static ulonglong log_buffering_timeout = 0;
-
-/// If after this many seconds we're still buffering, flush!
-#ifndef LOG_BUFFERING_TIMEOUT_AFTER
-#define LOG_BUFFERING_TIMEOUT_AFTER (60)
-#endif
-/// Thereafter, if still buffering after this many more seconds, flush again!
-#ifndef LOG_BUFFERING_TIMEOUT_EVERY
-#define LOG_BUFFERING_TIMEOUT_EVERY (10)
-#endif
-/// Time function returns microseconds, we want seconds.
-#ifndef LOG_BUFFERING_TIME_SCALE
-#define LOG_BUFFERING_TIME_SCALE 1000000
-#endif
-
-/// Does buffer contain SYSTEM or ERROR prio messages? Flush early only then!
-int log_buffering_flushworthy = false;
-
 /**
   Timestamp of the last event we put into the error-log buffer
   during buffered mode (while starting up). New items must
   receive a LOG_ITEM_LOG_BUFFERED timestamp greater than this.
 */
-static ulonglong log_sink_buffer_last = 0;
+static ulonglong log_sink_buffer_latest_buffered = 0;
 
 /**
   Duplicate a log-event. This is a deep copy where the items (key/value pairs)
@@ -206,7 +175,7 @@ fail:                           /* purecov: begin inspected */
   @retval          -1                   can not add event to buffer (OOM?)
   @retval          >0                   number of added fields
 */
-int log_sink_buffer(void *instance MY_ATTRIBUTE((unused)), log_line *ll) {
+int log_sink_buffer(void *instance [[maybe_unused]], log_line *ll) {
   log_line_buffer *llb = nullptr;  ///< log-line buffer
   ulonglong now = 0;
   int count = 0;
@@ -230,26 +199,13 @@ int log_sink_buffer(void *instance MY_ATTRIBUTE((unused)), log_line *ll) {
       there at least until we return.)
     */
     log_line_duplicate(&llb->ll, ll);
-
-    /*
-      Remember it when an ERROR or SYSTEM prio event was buffered.
-      If buffered logging times out and the buffer contains such an event,
-      we force a premature flush so the user will know what's going on.
-    */
-    {
-      int index_prio = log_line_index_by_type(&llb->ll, LOG_ITEM_LOG_PRIO);
-
-      if ((index_prio >= 0) &&
-          (llb->ll.item[index_prio].data.data_integer <= ERROR_LEVEL))
-        log_buffering_flushworthy = true;
-    }
   }
 
   /*
     Insert the new last event into the buffer
     (a singly linked list of events).
   */
-  if (log_builtins_inited) mysql_mutex_lock(&THR_LOCK_log_buffered);
+  if (log_builtins_started()) mysql_mutex_lock(&THR_LOCK_log_buffered);
 
   now = my_micro_time();
 
@@ -258,10 +214,10 @@ int log_sink_buffer(void *instance MY_ATTRIBUTE((unused)), log_line *ll) {
       Prevent two events from receiving the exact same timestamp on
       systems with low resolution clocks.
     */
-    if (now > log_sink_buffer_last)
-      log_sink_buffer_last = now;
+    if (now > log_sink_buffer_latest_buffered)
+      log_sink_buffer_latest_buffered = now;
     else
-      log_sink_buffer_last++;
+      log_sink_buffer_latest_buffered++;
 
     /*
       Save the current time so we can regenerate the textual timestamp
@@ -270,7 +226,7 @@ int log_sink_buffer(void *instance MY_ATTRIBUTE((unused)), log_line *ll) {
     */
     if (!log_line_full(&llb->ll)) {
       log_line_item_set(&llb->ll, LOG_ITEM_LOG_BUFFERED)->data_integer =
-          log_sink_buffer_last;
+          log_sink_buffer_latest_buffered;
     }
 
     *log_line_buffer_tail = llb;
@@ -283,84 +239,18 @@ int log_sink_buffer(void *instance MY_ATTRIBUTE((unused)), log_line *ll) {
     count = llb->ll.count;
   }
 
-  /*
-    Handle buffering time-out!
-  */
-
-  // Buffering very first event; set up initial time-out ...
-  if (log_buffering_timeout == 0)
-    log_buffering_timeout =
-        now + (LOG_BUFFERING_TIMEOUT_AFTER * LOG_BUFFERING_TIME_SCALE);
-
-  if (log_error_stage_get() == LOG_ERROR_STAGE_BUFFERING_UNIPLEX) {
-    /*
-      When not multiplexing several log-writers into the same stream,
-      we need not delay.
-    */
-    log_sink_buffer_flush(LOG_BUFFER_REPORT_AND_KEEP);
-  }
-
-  // Need to flush? Check on time-out, or when explicitly asked to.
-  else if ((now > log_buffering_timeout) || (ll == nullptr)) {
-    // We timed out. Flush, and set up new, possibly shorter subsequent timeout.
-
-    /*
-      Timing out is somewhat awkward. Ideally, it shouldn't happen at all;
-      but as long as it does, it is extremely unlikely to happen during early
-      set-up -- instead, it might happen during engine set-up ("cannot lock
-      DB file, another server instance already has it", "applying large
-      binlog", etc.).
-
-      The good news is that this means we've already parsed the command line
-      options; we have the timestamp format, the error log file, the verbosity,
-      and the suppression list (if any).
-
-      The bad news is, if the engine we're waiting for is InnoDB, which the
-      component framework persists its component list in, the log-writers
-      selected by the DBA won't have been loaded yet. This of course means
-      that the time-out flushes will only be available in the built-in,
-      "traditional" format, but at least this way, the user gets updates
-      during long waits. Additionally if the server exits during start-up
-      (i.e. before full logging is available), we'll have log info of what
-      happened (albeit not in the preferred format).
-
-      If start-up completes and external log-services become available,
-      we will flush all buffered messages to any external log-writers
-      requested by the user (using their preferred log-filtering set-up
-      as well).
-    */
-
-    // If anything of sufficient priority is in the buffer ...
-    if (log_buffering_flushworthy) {
-      /*
-        ... log it now to the traditional log, but keep the buffered
-        events around in case we need to write them to loadable log-sinks
-        later.
-      */
-      log_sink_buffer_flush(LOG_BUFFER_REPORT_AND_KEEP);
-      // Remember that all high-prio events so far have now been shown.
-      log_buffering_flushworthy = false;
-    }
-
-    // Whether we've needed to flush or not, start a new window:
-    log_buffering_timeout =
-        now + (LOG_BUFFERING_TIMEOUT_EVERY * LOG_BUFFERING_TIME_SCALE);
-  }
-
-  if (log_builtins_inited) mysql_mutex_unlock(&THR_LOCK_log_buffered);
+  if (log_builtins_started()) mysql_mutex_unlock(&THR_LOCK_log_buffered);
 
   return count;
 }
 
-/**
-  Convenience function. Same as log_sink_buffer(), except we only
-  check whether the time-out for buffered logging has been reached
-  during start-up, and act accordingly; no new logging information
-  is added (i.e., we only provide functionality 1 described in the
-  preamble for log_sink_buffer() above).
+/*
+  Release all buffered log-events (discard_error_log_messages()),
+  optionally after running them through the error log stack first
+  (flush_error_log_messages()). Safe to call repeatedly (though
+  subsequent calls will only output anything if further events
+  occurred after the previous flush).
 */
-void log_sink_buffer_check_timeout(void) { log_sink_buffer(nullptr, nullptr); }
-
 void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
   log_line_buffer *llp, *local_head, *local_tail = nullptr;
 
@@ -385,21 +275,14 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
 
   /*
     If the lock hasn't been init'd yet, don't get it.
-
-    Likewise don't get it in LOG_BUFFER_REPORT_AND_KEEP mode as
-    then the caller already has it. We generally only grab the lock
-    here when coming from log.cc's discard_error_log_messages() or
-    flush_error_log_messages().
   */
-  if (log_builtins_inited && (mode != LOG_BUFFER_REPORT_AND_KEEP))
-    mysql_mutex_lock(&THR_LOCK_log_buffered);
+  if (log_builtins_started()) mysql_mutex_lock(&THR_LOCK_log_buffered);
 
   local_head = log_line_buffer_start;             // save list head
   log_line_buffer_start = nullptr;                // empty public list
   log_line_buffer_tail = &log_line_buffer_start;  // adjust tail of public list
 
-  if (log_builtins_inited && (mode != LOG_BUFFER_REPORT_AND_KEEP))
-    mysql_mutex_unlock(&THR_LOCK_log_buffered);
+  if (log_builtins_started()) mysql_mutex_unlock(&THR_LOCK_log_buffered);
 
   // get head element from list of buffered log events
   llp = local_head;
@@ -412,27 +295,29 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
       we'll just throw the information away.
     */
     if (mode != LOG_BUFFER_DISCARD_ONLY) {
-      log_service_instance *lsi = log_service_instances;
+      // Fetch integer timestamp of when we buffered the event.
+      ulonglong now = 0;
+      const int index_buff =
+          log_line_index_by_type(&llp->ll, LOG_ITEM_LOG_BUFFERED);
 
-      // regenerate timestamp with the correct options
-      char local_time_buff[iso8601_size];
-      int index_buff = log_line_index_by_type(&llp->ll, LOG_ITEM_LOG_BUFFERED);
-      int index_time = log_line_index_by_type(&llp->ll, LOG_ITEM_LOG_TIMESTAMP);
-      ulonglong now;
+      if (index_buff >= 0) now = llp->ll.item[index_buff].data.data_integer;
 
-      if (index_buff >= 0)
-        now = llp->ll.item[index_buff].data.data_integer;
-      else  // we failed to set a timestamp earlier (OOM?), use current time!
-        now = my_micro_time(); /* purecov: inspected */
+      // We failed to set a timestamp earlier (OOM?). Use current time!
+      if (now == 0) now = my_micro_time(); /* purecov: inspected */
 
       DBUG_EXECUTE_IF("log_error_normalize", { now = 0; });
 
+      // Regenerate timestamp with the correct options.
+      char local_time_buff[iso8601_size];
       make_iso8601_timestamp(local_time_buff, now,
                              iso8601_sysvar_logtimestamps);
       char *date = my_strndup(key_memory_log_error_stack, local_time_buff,
                               strlen(local_time_buff) + 1, MYF(0));
 
       if (date != nullptr) {
+        const int index_time =
+            log_line_index_by_type(&llp->ll, LOG_ITEM_LOG_TIMESTAMP);
+
         if (index_time >= 0) {
           // release old timestamp value
           if (llp->ll.item[index_time].alloc & LOG_ITEM_FREE_VALUE) {
@@ -449,10 +334,9 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
           log_item_data *d =
               log_line_item_set(&llp->ll, LOG_ITEM_LOG_TIMESTAMP);
           if (d != nullptr) {
-            d->data_string.str = local_time_buff;
+            d->data_string.str = date;
             d->data_string.length = strlen(d->data_string.str);
-            llp->ll.item[llp->ll.count].alloc |= LOG_ITEM_FREE_VALUE;
-            llp->ll.seen |= LOG_ITEM_LOG_TIMESTAMP;
+            llp->ll.item[llp->ll.count - 1].alloc |= LOG_ITEM_FREE_VALUE;
           } else
             my_free(date);  // couldn't create key/value pair for timestamp
         } else
@@ -471,75 +355,50 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
         goes wrong, information with undesired formatting is still
         better than not knowing about the issue at all.
       */
-      if ((lsi == nullptr) || (lsi->sce->chistics & LOG_SERVICE_BUFFER)) {
+      if ((log_error_stage_get() != LOG_ERROR_STAGE_COMPONENTS) &&
+          (log_error_stage_get() != LOG_ERROR_STAGE_COMPONENTS_AND_PFS)) {
         /*
-          This is a fallback used when start-up takes very long.
+          This is a fallback used when the user's log_error_services
+          has not been made active yet (and loadable logging-components
+          have not been loaded yet).
 
           In fallback modes, we run with default settings and
           services.
-
-          In "keep" mode (that is, "start-up's taking a long time,
-          so show the user the info so far in the basic format, but
-          keep the log-events so we can log them properly later"),
-          we expect to be able to log the events with the correct
-          settings and services later (if start-up gets that far).
-          As the services we use in the meantime may change or even
-          remove log events, we'll let the services work on a
-          temporary copy of the events here. The final logging will
-          then use the original event. This way, we don't later log
-          with an intersection of the early and the final settings.
         */
-        if (mode == LOG_BUFFER_REPORT_AND_KEEP) {
-          log_line temp_line;  // copy the line so the filter may mangle it
 
-          log_line_duplicate(&temp_line, &llp->ll);
+        // LOG_BUFFER_PROCESS_AND_DISCARD
 
-          // Only run the built-in filter if any rules are defined.
-          if (log_filter_builtin_rules != nullptr)
-            log_builtins_filter_run(log_filter_builtin_rules, &temp_line);
+        /*
+          This is a fallback used primarily when start-up is aborted.
 
-          // Emit to the built-in writer. Empty lines will be ignored.
-          log_sink_trad(nullptr, &temp_line);
+          If we get here, flush_error_log_messages() was called
+          before logging came out of buffered mode. (If it was
+          called after buffered modes completes, we should land
+          in the following branch instead.)
 
-          log_line_item_free_all(&temp_line);  // release our temporary copy
+          We're asked to print all log-info so far using basic
+          logging, and to then throw it away (rather than keep
+          it around for proper logging). This usually implies
+          that we're shutting down because some unrecoverable
+          situation has arisen during start-up, so a) the user
+          needs to know about it even if full logging (as
+          configured) is not available yet, and b) we'll shut
+          down before we'll ever get full logging, so keeping
+          the info around is pointless.
+        */
 
-          local_tail = llp;
-          llp = llp->next;  // go to next element, keep head pointer the same
-          continue;         // skip the free()-ing
+        if (log_filter_builtin_rules != nullptr)
+          log_builtins_filter_run(log_filter_builtin_rules, &llp->ll);
 
-        } else {  // LOG_BUFFER_PROCESS_AND_DISCARD
-          /*
-            This is a fallback used primarily when start-up is aborted.
-
-            If we get here, flush_error_log_messages() was called
-            before logging came out of buffered mode. (If it was
-            called after buffered modes completes, we should land
-            in the following branch instead.)
-
-            We're asked to print all log-info so far using basic
-            logging, and to then throw it away (rather than keep
-            it around for proper logging). This usually implies
-            that we're shutting down because some unrecoverable
-            situation has arisen during start-up, so a) the user
-            needs to know about it even if full logging (as
-            configured) is not available yet, and b) we'll shut
-            down before we'll ever get full logging, so keeping
-            the info around is pointless.
-          */
-
-          if (log_filter_builtin_rules != nullptr)
-            log_builtins_filter_run(log_filter_builtin_rules, &llp->ll);
-
-          log_sink_trad(nullptr, &llp->ll);
-        }
-      } else {  // !LOG_SERVICE_BUFFER
+        log_sink_trad(nullptr, &llp->ll);
+      } else {  // no longer buffering
         /*
           If we get here, logging has left the buffered phase, and
           we can write out the log-events using the configuration
           requested by the user, as it should be!
         */
         log_line_submit(&llp->ll);  // frees keys + values (but not llp itself)
-        goto kv_freed;
+        goto kv_freed;              // skip freeing of keys + values
       }
     }
 
@@ -548,17 +407,16 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
     local_head = local_head->next;  // delist event
     my_free(llp);                   // free buffered event
     llp = local_head;
-  }
+  }  // while (any_more_buffered_events_to_process)
 
-  if (log_builtins_inited && (mode != LOG_BUFFER_REPORT_AND_KEEP))
-    mysql_mutex_lock(&THR_LOCK_log_buffered);
+  if (log_builtins_started()) mysql_mutex_lock(&THR_LOCK_log_buffered);
 
   /*
     At this point, if (local_head == nullptr), we either didn't have
     a list to begin with, or we just emptied the local version.
     Since we also emptied the global version at the top, whatever's
     in there now (still empty, or new events attached while we were
-    processing) is now authoritive, and no change is needed here.
+    processing) is now authoritative, and no change is needed here.
 
     If local_head is non-NULL, we started with a non-empty local list
     and mode was KEEP. In that case, we merge the local list back into
@@ -566,6 +424,12 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
   */
 
   if (local_head != nullptr) {
+    /*
+      Since local_head was non-NULL, we started with a non-empty
+      (local) list. Therefore, local_tail should point at the last
+      element in that list (as it is only allowed to be NULL if
+      the list is empty).
+    */
     assert(local_tail != nullptr);
 
     /*
@@ -587,6 +451,23 @@ void log_sink_buffer_flush(enum log_sink_buffer_flush_mode mode) {
     log_line_buffer_start = local_head;
   }
 
-  if (log_builtins_inited && (mode != LOG_BUFFER_REPORT_AND_KEEP))
-    mysql_mutex_unlock(&THR_LOCK_log_buffered);
+  if (log_builtins_started()) mysql_mutex_unlock(&THR_LOCK_log_buffered);
+}
+
+/**
+  Prepend a list of log-events to the already buffered events.
+
+  @param[in]  head  Head of the list to prepend to the main list
+  @param[out] tail  Pointer to the `next` pointer in last element to prepend
+*/
+void log_sink_buffer_prepend_list(log_line_buffer *head,
+                                  log_line_buffer **tail) {
+  if ((head == nullptr) || (tail == nullptr)) return;
+
+  mysql_mutex_lock(&THR_LOCK_log_buffered);
+
+  *tail = log_line_buffer_start;
+  log_line_buffer_start = head;
+
+  mysql_mutex_unlock(&THR_LOCK_log_buffered);
 }
