@@ -51,9 +51,9 @@
 #include "my_systime.h"
 #include "mysql/strings/m_ctype.h"
 #include "nulls.h"
+#include "sql-common/my_decimal.h"
 #include "sql/field.h"
 #include "sql/item.h"
-#include "sql/my_decimal.h"
 #include "sql/protocol.h"
 #include "sql/psi_memory_key.h"
 #include "sql/query_options.h"
