@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_MY_SQL_PARSER_VAR_LIB_PB2_SB_1_12964073_1697111053_03_DIST_GPL_SQL_SQL_YACC_H_INCLUDED
-# define YY_MY_SQL_PARSER_VAR_LIB_PB2_SB_1_12964073_1697111053_03_DIST_GPL_SQL_SQL_YACC_H_INCLUDED
+#ifndef YY_MY_SQL_PARSER_VAR_LIB_PB2_SB_1_13732547_1702565708_68_DIST_GPL_SQL_SQL_YACC_H_INCLUDED
+# define YY_MY_SQL_PARSER_VAR_LIB_PB2_SB_1_13732547_1702565708_68_DIST_GPL_SQL_SQL_YACC_H_INCLUDED
 /* Debug traces.  */
 #ifndef MY_SQL_PARSER_DEBUG
 # if defined YYDEBUG
@@ -854,11 +854,12 @@ extern int my_sql_parser_debug;
     GTIDS_SYM = 1207,
     PARALLEL_SYM = 1208,
     S3_SYM = 1209,
-    KEYWORD_USED_AS_IDENT = 1211,
-    KEYWORD_USED_AS_KEYWORD = 1212,
-    CONDITIONLESS_JOIN = 1213,
-    SUBQUERY_AS_EXPR = 1214,
-    EMPTY_FROM_CLAUSE = 1215
+    QUALIFY_SYM = 1210,
+    KEYWORD_USED_AS_IDENT = 1212,
+    KEYWORD_USED_AS_KEYWORD = 1213,
+    CONDITIONLESS_JOIN = 1214,
+    SUBQUERY_AS_EXPR = 1215,
+    EMPTY_FROM_CLAUSE = 1216
   };
 #endif
 /* Tokens.  */
@@ -1663,11 +1664,12 @@ extern int my_sql_parser_debug;
 #define GTIDS_SYM 1207
 #define PARALLEL_SYM 1208
 #define S3_SYM 1209
-#define KEYWORD_USED_AS_IDENT 1211
-#define KEYWORD_USED_AS_KEYWORD 1212
-#define CONDITIONLESS_JOIN 1213
-#define SUBQUERY_AS_EXPR 1214
-#define EMPTY_FROM_CLAUSE 1215
+#define QUALIFY_SYM 1210
+#define KEYWORD_USED_AS_IDENT 1212
+#define KEYWORD_USED_AS_KEYWORD 1213
+#define CONDITIONLESS_JOIN 1214
+#define SUBQUERY_AS_EXPR 1215
+#define EMPTY_FROM_CLAUSE 1216
 
 /* Value type.  */
 
@@ -1689,4 +1691,4 @@ struct MY_SQL_PARSER_LTYPE
 
 int my_sql_parser_parse (class THD *YYTHD, class Parse_tree_root **parse_tree);
 
-#endif /* !YY_MY_SQL_PARSER_VAR_LIB_PB2_SB_1_12964073_1697111053_03_DIST_GPL_SQL_SQL_YACC_H_INCLUDED  */
+#endif /* !YY_MY_SQL_PARSER_VAR_LIB_PB2_SB_1_13732547_1702565708_68_DIST_GPL_SQL_SQL_YACC_H_INCLUDED  */
