@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+Copyright (c) 2017, 2023, Oracle and/or its affiliates.
 
 Portions of this file contain modifications contributed and copyrighted by
 Google, Inc. Those modifications are gratefully acknowledged and are described
@@ -12,13 +12,12 @@ This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License, version 2.0, as published by the
 Free Software Foundation.
 
-This program is designed to work with certain software (including
-but not limited to OpenSSL) that is licensed under separate terms,
-as designated in a particular file or component or in included license
-documentation.  The authors of MySQL hereby grant you an additional
-permission to link the program and your derivative works with the
-separately licensed software that they have either included with
-the program or referenced in the documentation.
+This program is also distributed with certain software (including but not
+limited to OpenSSL) that is licensed under separate terms, as designated in a
+particular file or component or in included license documentation. The authors
+of MySQL hereby grant you an additional permission to link the program and
+your derivative works with the separately licensed software that they have
+included with MySQL.
 
 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -185,6 +184,8 @@ class DDL_Record {
   @param[in]    len     length of the data. */
   void set_new_file_path(const byte *data, ulint len);
 
+  bool validate() const;
+
   /** Print the DDL record to specified output stream
   @param[in,out]        out     output stream
   @return output stream */
@@ -226,6 +227,12 @@ class DDL_Record {
   bool m_deletable;
 };
 
+inline bool DDL_Record::validate() const {
+  ut_a(m_type >= Log_Type::SMALLEST_LOG);
+  ut_a(m_type <= Log_Type::BIGGEST_LOG);
+  return true;
+}
+
 /** Forward declaration */
 class THD;
 struct que_thr_t;
