@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2024, Oracle and/or its affiliates.
+Copyright (c) 1995, 2023, Oracle and/or its affiliates.
 Copyright (c) 2008, Google Inc.
 
 Portions of this file contain modifications contributed and copyrighted by
@@ -13,13 +13,12 @@ This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License, version 2.0, as published by the
 Free Software Foundation.
 
-This program is designed to work with certain software (including
-but not limited to OpenSSL) that is licensed under separate terms,
-as designated in a particular file or component or in included license
-documentation.  The authors of MySQL hereby grant you an additional
-permission to link the program and your derivative works with the
-separately licensed software that they have either included with
-the program or referenced in the documentation.
+This program is also distributed with certain software (including but not
+limited to OpenSSL) that is licensed under separate terms, as designated in a
+particular file or component or in included license documentation. The authors
+of MySQL hereby grant you an additional permission to link the program and
+your derivative works with the separately licensed software that they have
+included with MySQL.
 
 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -41,6 +40,9 @@ this program; if not, write to the Free Software Foundation, Inc.,
 #ifndef sync0rw_h
 #define sync0rw_h
 
+#include <atomic>
+#include <cstdint>
+
 #include "univ.i"
 #ifndef UNIV_HOTBACKUP
 #include "os0event.h"
@@ -385,7 +387,20 @@ struct rw_lock_t
   std::atomic<bool> recursive;
 
   /** number of granted SX locks. */
-  volatile ulint sx_recursive;
+  std::atomic<uint64_t> sx_recursive;
+
+  void decrement_sx_recursive() {
+    auto old_value = sx_recursive.load(std::memory_order_relaxed);
+    auto new_value = old_value - 1;
+    sx_recursive.store(new_value, std::memory_order_relaxed);
+  }
+
+  uint64_t increment_sx_recursive() {
+    auto old_value = sx_recursive.load(std::memory_order_relaxed);
+    auto new_value = old_value + 1;
+    sx_recursive.store(new_value, std::memory_order_relaxed);
+    return old_value;
+  }
 
   /** Thread id of writer thread. Is only guaranteed to have non-stale value if
   recursive flag is set, otherwise it may contain native thread ID of a
