@@ -1,18 +1,17 @@
 /*****************************************************************************
 
-Copyright (c) 1996, 2024, Oracle and/or its affiliates.
+Copyright (c) 1996, 2023, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License, version 2.0, as published by the
 Free Software Foundation.
 
-This program is designed to work with certain software (including
-but not limited to OpenSSL) that is licensed under separate terms,
-as designated in a particular file or component or in included license
-documentation.  The authors of MySQL hereby grant you an additional
-permission to link the program and your derivative works with the
-separately licensed software that they have either included with
-the program or referenced in the documentation.
+This program is also distributed with certain software (including but not
+limited to OpenSSL) that is licensed under separate terms, as designated in a
+particular file or component or in included license documentation. The authors
+of MySQL hereby grant you an additional permission to link the program and
+your derivative works with the separately licensed software that they have
+included with MySQL.
 
 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -96,6 +95,10 @@ static void lock_wait_table_release_slot(
   ut_ad(slot >= lock_sys->waiting_threads);
   ut_ad(slot < upper);
 
+  if (slot->thr->lock_state == QUE_THR_LOCK_ROW) {
+    srv_stats.n_lock_wait_current_count.dec();
+  }
+
   slot->thr->slot = nullptr;
   slot->thr = nullptr;
   slot->in_use = false;
@@ -160,6 +163,10 @@ static srv_slot_t *lock_wait_table_reserve_slot(
       slot->suspended = true;
       slot->suspend_time = std::chrono::steady_clock::now();
       slot->wait_timeout = wait_timeout;
+      if (thr->lock_state == QUE_THR_LOCK_ROW) {
+        srv_stats.n_lock_wait_count.inc();
+        srv_stats.n_lock_wait_current_count.inc();
+      }
 
       if (slot == lock_sys->last_slot) {
         ++lock_sys->last_slot;
@@ -198,7 +205,6 @@ void lock_wait_request_check_for_cycles() { lock_set_timeout_event(); }
 void lock_wait_suspend_thread(que_thr_t *thr) {
   srv_slot_t *slot;
   trx_t *trx;
-  std::chrono::steady_clock::time_point start_time;
 
   trx = thr_get_trx(thr);
 
@@ -240,13 +246,6 @@ void lock_wait_suspend_thread(que_thr_t *thr) {
 
   slot = lock_wait_table_reserve_slot(thr, lock_wait_timeout);
 
-  if (thr->lock_state == QUE_THR_LOCK_ROW) {
-    srv_stats.n_lock_wait_count.inc();
-    srv_stats.n_lock_wait_current_count.inc();
-
-    start_time = std::chrono::steady_clock::now();
-  }
-
   lock_wait_mutex_exit();
 
   /* We hold trx->mutex here, which is required to call
@@ -316,13 +315,12 @@ void lock_wait_suspend_thread(que_thr_t *thr) {
   }
 
   /* Release the slot for others to use */
-
+  const auto start_time = slot->suspend_time;
   lock_wait_table_release_slot(slot);
 
   if (thr->lock_state == QUE_THR_LOCK_ROW) {
     const auto diff_time = std::chrono::steady_clock::now() - start_time;
 
-    srv_stats.n_lock_wait_current_count.dec();
     srv_stats.n_lock_wait_time.add(
         std::chrono::duration_cast<std::chrono::microseconds>(diff_time)
             .count());
