@@ -261,8 +261,6 @@ void trx_purge_sys_initialize(uint32_t n_purge_threads,
 
   trx_sys->mvcc->clone_oldest_view(&purge_sys->view);
 
-  purge_sys->view_active = true;
-
   purge_sys->rseg_iter = ut::new_withkey<TrxUndoRsegsIterator>(
       UT_NEW_THIS_FILE_PSI_KEY, purge_sys);
 }
@@ -2406,12 +2404,8 @@ ulint trx_purge(ulint n_purge_threads, /*!< in: number of purge tasks
 
   rw_lock_x_lock(&purge_sys->latch, UT_LOCATION_HERE);
 
-  purge_sys->view_active = false;
-
   trx_sys->mvcc->clone_oldest_view(&purge_sys->view);
 
-  purge_sys->view_active = true;
-
   rw_lock_x_unlock(&purge_sys->latch);
 
 #ifdef UNIV_DEBUG
