@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2003, 2025, Oracle and/or its affiliates.
+   Copyright (c) 2003, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -40,7 +39,7 @@ class NdbRecAttr;
  *
  * Brief description on how to work with events:
  *
- * - An event, represented by an NdbDictionary::Event, is created in the
+ * - An event, represented by an NdbDictionary::Event, i created in the
  *   Database through
  *   NdbDictionary::Dictionary::createEvent() (note that this can be done
  *   by any application or thread and not necessarily by the "listener")
@@ -158,11 +157,11 @@ class NdbEventOperation {
    *                    the attribute, or a NULL pointer
    *                    (indicating error).
    */
-  NdbRecAttr *getValue(const char *anAttrName, char *aValue = 0);
+  NdbRecAttr *getValue(const char *anAttrName, char *aValue = nullptr);
   /**
    * See getValue().
    */
-  NdbRecAttr *getPreValue(const char *anAttrName, char *aValue = 0);
+  NdbRecAttr *getPreValue(const char *anAttrName, char *aValue = nullptr);
 
   /**
    * These methods replace getValue/getPreValue for blobs.  Each
@@ -172,14 +171,6 @@ class NdbEventOperation {
   NdbBlob *getBlobHandle(const char *anAttrName);
   NdbBlob *getPreBlobHandle(const char *anAttrName);
 
-  /**
-     Whether EventOperation should filter out potentially partial
-     data from epochs < the StartEpoch for this operation.
-
-     Automatically implied by mergeEvents.
-  */
-  void setFilterPreStartEpochs(bool flag);
-
   int isOverrun() const;
 
   /**
@@ -310,17 +301,7 @@ class NdbEventOperation {
    * Check whether the consumed event data marks an error epoch
    * and get the error.
    */
-  bool isErrorEpoch(NdbDictionary::Event::TableEvent *error_type = 0);
-
-  /**
-   * Get first epoch value guaranteed to have all row change
-   * events for this event operation.
-   *
-   * Lower epochs may have a partial set of row change events.
-   *
-   * Only valid for executing EventOperations
-   */
-  Uint64 getStartEpoch() const;
+  bool isErrorEpoch(NdbDictionary::Event::TableEvent *error_type = nullptr);
 
 #ifndef DOXYGEN_SHOULD_SKIP_INTERNAL
   /** these are subject to change at any time */
