@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2000, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2000, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -54,9 +53,7 @@ int ndbcluster_binlog_start();
 
 void ndbcluster_binlog_set_server_started();
 
-void ndbcluster_binlog_pre_dd_shutdown();
-
-void ndbcluster_binlog_end();
+int ndbcluster_binlog_end();
 
 /*
   Will return true when the ndb binlog component is properly setup
@@ -130,7 +127,6 @@ bool ndbcluster_binlog_check_schema_async(const std::string &schema_name);
 /**
  @brief Retrieve information about objects currently excluded from sync
  @param excluded_table  Pointer to excluded objects table object
- @return void
 */
 void ndbcluster_binlog_retrieve_sync_excluded_objects(
     Ndb_sync_excluded_objects_table *excluded_table);
@@ -144,7 +140,6 @@ unsigned int ndbcluster_binlog_get_sync_excluded_objects_count();
 /**
  @brief Retrieve information about objects currently pending sync
  @param pending_table  Pointer to pending objects table object
- @return void
 */
 void ndbcluster_binlog_retrieve_sync_pending_objects(
     Ndb_sync_pending_objects_table *pending_table);
