@@ -21,39 +21,36 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+#include <sys/stat.h>
 #include <cinttypes>  // PRIuPTR
 #include <cstdint>
 #include <memory>
-#include <sys/stat.h>
 
-#include "openssl/ssl.h"
 #include "openssl/err.h"
+#include "openssl/ssl.h"
 #include "openssl/x509v3.h"
 
 #include "debugger/EventLogger.hpp"
 #include "portlib/ndb_openssl_version.h"
-#include "util/ndb_openssl3_compat.h"
 #include "util/NodeCertificate.hpp"
-#include "util/cstrbuf.h"
-#include "util/require.h"
 #include "util/TlsKeyManager.hpp"
+#include "util/cstrbuf.h"
+#include "util/ndb_openssl3_compat.h"
+#include "util/require.h"
 
-
-TlsKeyManager::TlsKeyManager() {
-  NdbMutex_Init(& m_cert_table_mutex);
-}
+TlsKeyManager::TlsKeyManager() { NdbMutex_Init(&m_cert_table_mutex); }
 
 void TlsKeyManager::free_path_strings() {
-  if(m_search_path) delete m_search_path;
-  if(m_path_string) free(m_path_string);
+  if (m_search_path) delete m_search_path;
+  if (m_path_string) free(m_path_string);
   m_search_path = nullptr;
   m_path_string = nullptr;
 }
 
 TlsKeyManager::~TlsKeyManager() {
-  if(m_ctx) SSL_CTX_free(m_ctx);
+  if (m_ctx) SSL_CTX_free(m_ctx);
   free_path_strings();
-  NdbMutex_Deinit(& m_cert_table_mutex);
+  NdbMutex_Deinit(&m_cert_table_mutex);
 }
 
 void TlsKeyManager::log_error(TlsKeyError::code err) {
@@ -62,7 +59,7 @@ void TlsKeyManager::log_error(TlsKeyError::code err) {
 }
 
 void TlsKeyManager::log_error() const {
-  if(m_error < TlsKeyError::END_GENERIC_ERRORS)
+  if (m_error < TlsKeyError::END_GENERIC_ERRORS)
     g_eventLogger->error("TLS key error: %s.\n", TlsKeyError::message(m_error));
   else
     g_eventLogger->error("TLS key error: %s (with path: %s).\n",
@@ -71,13 +68,13 @@ void TlsKeyManager::log_error() const {
 
 #if OPENSSL_VERSION_NUMBER < NDB_TLS_MINIMUM_OPENSSL
 
-void TlsKeyManager::init(int, const NodeCertificate *) { }
+void TlsKeyManager::init(int, const NodeCertificate *) {}
 
-void TlsKeyManager::init(const char *, int, int, bool) { }
+void TlsKeyManager::init(const char *, int, int) {}
 
-void TlsKeyManager::init(const char *, int, Node::Type, UserType) { }
+void TlsKeyManager::init(const char *, int, Node::Type) {}
 
-void TlsKeyManager::init(int, struct stack_st_X509 *, struct evp_pkey_st *) { }
+void TlsKeyManager::init(int, struct stack_st_X509 *, struct evp_pkey_st *) {}
 
 #else
 
@@ -85,12 +82,12 @@ void TlsKeyManager::init(int, struct stack_st_X509 *, struct evp_pkey_st *) { }
  * It includes all TLS 1.3 cipher suites, plus one TLS 1.2 cipher suite,
  * ECDHE-ECDSA-AES128-GCM-SHA256.
  */
-static constexpr const char * cipher_list =
- "TLS_CHACHA20_POLY1305_SHA256:TLS_AES_256_GCM_SHA384:"
- "TLS_AES_128_GCM_SHA256:TLS_AES_128_CCM_SHA256:TLS_AES_128_CCM_8_SHA256:"
- "ECDHE-ECDSA-AES128-GCM-SHA256";
+static constexpr const char *cipher_list =
+    "TLS_CHACHA20_POLY1305_SHA256:TLS_AES_256_GCM_SHA384:"
+    "TLS_AES_128_GCM_SHA256:TLS_AES_128_CCM_SHA256:TLS_AES_128_CCM_8_SHA256:"
+    "ECDHE-ECDSA-AES128-GCM-SHA256";
 
-static int error_callback(const char *str, size_t, void * vp) {
+static int error_callback(const char *str, size_t, void *vp) {
   intptr_t r = reinterpret_cast<intptr_t>(vp);
   g_eventLogger->error("NDB TLS [%" PRIuPTR "]: %s", r, str);
   return 0;
@@ -100,18 +97,16 @@ static void log_openssl_errors(intptr_t r) {
   ERR_print_errors_cb(error_callback, reinterpret_cast<void *>(r));
 }
 
-void TlsKeyManager::init(const char * tls_search_path, int node_id, 
-                         int ndb_node_type, bool is_primary) {
-  UserType userType = is_primary ? Primary : SecondaryApi;
+void TlsKeyManager::init(const char *tls_search_path, int node_id,
+                         int ndb_node_type) {
   require(ndb_node_type >= NODE_TYPE_DB && ndb_node_type <= NODE_TYPE_MGM);
   Node::Type nodeType = cert_type[ndb_node_type];
-  init(tls_search_path, node_id, nodeType, userType);
+  init(tls_search_path, node_id, nodeType);
 }
 
-void TlsKeyManager::init(const char * tls_search_path, int node_id,
-                         Node::Type node_type, UserType user_type)
-{
-  if(m_ctx) return;   // already initialized
+void TlsKeyManager::init(const char *tls_search_path, int node_id,
+                         Node::Type node_type) {
+  if (m_ctx) return;  // already initialized
 
   /* Set node id and type */
   m_node_id = node_id;
@@ -122,25 +117,20 @@ void TlsKeyManager::init(const char * tls_search_path, int node_id,
   m_path_string = m_search_path->expanded_path_string();
 
   /* Open active certificate; initialize NodeCertificate.  */
-  if(! open_active_cert()) {
+  if (!open_active_cert()) {
     free_path_strings();
     return;
   }
 
   initialize_context();
 
-  if(m_ctx) {
-    if(user_type == Primary)
-      g_eventLogger->info("NDB TLS 1.3 available using certificate file '%s'",
-                          m_cert_file.c_str());
-    else if(user_type == SecondaryApi)
-      g_eventLogger->info("NDB TLS available in secondary connection "
-                          "(node id %d)", node_id);
-  }
+  if (m_ctx && (node_type != Node::Type::Client))
+    g_eventLogger->info("NDB TLS 1.3 available using certificate file '%s'",
+                        m_cert_file.c_str());
 }
 
 /* Versions of init() used by test harness */
-void TlsKeyManager::init(int node_id, STACK_OF(X509) * certs, EVP_PKEY * key) {
+void TlsKeyManager::init(int node_id, STACK_OF(X509) * certs, EVP_PKEY *key) {
   assert(m_ctx == nullptr);
   assert(certs);
   assert(key);
@@ -154,37 +144,38 @@ void TlsKeyManager::init(int node_id, STACK_OF(X509) * certs, EVP_PKEY * key) {
   initialize_context();
 }
 
-void TlsKeyManager::init(int node_id, const NodeCertificate *nc ) {
+void TlsKeyManager::init(int node_id, const NodeCertificate *nc) {
   init(node_id, nc->all_certs(), nc->key());
 }
 
-
 class SSL_CTX_owner {
-public:
-  SSL_CTX * ctx {nullptr};
-  ~SSL_CTX_owner() { if(ctx) SSL_CTX_free(ctx); }
+ public:
+  SSL_CTX *ctx{nullptr};
+  ~SSL_CTX_owner() {
+    if (ctx) SSL_CTX_free(ctx);
+  }
 };
 
 void TlsKeyManager::initialize_context() {
   SSL_CTX_owner g;
-  SSL_CTX * & ctx = g.ctx;
+  SSL_CTX *&ctx = g.ctx;
 
   /* Initialize Context */
   g.ctx = SSL_CTX_new(TLS_method());
-  if(! ctx) return log_openssl_errors(-3);
+  if (!ctx) return log_openssl_errors(-3);
 
   /* Set the active key and certificate in the context */
-  if(SSL_CTX_use_certificate(ctx, m_node_cert.cert()) != 1)
+  if (SSL_CTX_use_certificate(ctx, m_node_cert.cert()) != 1)
     return log_openssl_errors(-4);
 
-  if(SSL_CTX_use_PrivateKey(ctx, m_node_cert.key()) != 1)
+  if (SSL_CTX_use_PrivateKey(ctx, m_node_cert.key()) != 1)
     return log_openssl_errors(-5);
 
   /* Create a Verify Store for use in the CTX, using the CAs starting
      from the 2nd certificate in the NodeCertificate stack.
   */
-  X509_STORE * store = X509_STORE_new();
-  if(! store) return log_openssl_errors(-6);
+  X509_STORE *store = X509_STORE_new();
+  if (!store) return log_openssl_errors(-6);
 
   /* For X509_STORE_set_depth() see X509_VERIFY_PARAM_SET_FLAGS(3)
      "With a depth limit of 1 there can be one intermediate CA certificate
@@ -192,33 +183,32 @@ void TlsKeyManager::initialize_context() {
   */
   X509_STORE_set_depth(store, 1);
 
-  const STACK_OF(X509) * CAs = m_node_cert.all_certs();
-  if(! CAs) {
+  const STACK_OF(X509) *CAs = m_node_cert.all_certs();
+  if (!CAs) {
     X509_STORE_free(store);
     return log_error(TlsKeyError::active_cert_invalid);
   }
 
   int ncerts = sk_X509_num(CAs);
-  if(ncerts < 2) {
+  if (ncerts < 2) {
     X509_STORE_free(store);
     g_eventLogger->error("NDB TLS: No CA chain in active certificate: %s",
                          m_cert_file.c_str());
     return;
   }
 
-  for(int i = 1 ; i < ncerts; i++) {
-    X509 * CA_cert = sk_X509_value(CAs, i);
+  for (int i = 1; i < ncerts; i++) {
+    X509 *CA_cert = sk_X509_value(CAs, i);
     X509_STORE_add_cert(store, CA_cert);
   }
   SSL_CTX_set1_cert_store(ctx, store);
   X509_STORE_free(store);
 
   /* Check the private key */
-  if(SSL_CTX_check_private_key(ctx) != 1)
-    return log_openssl_errors(-7);
+  if (SSL_CTX_check_private_key(ctx) != 1) return log_openssl_errors(-7);
 
   /* Set the cipher list */
-  if(SSL_CTX_set_cipher_list(ctx, cipher_list) != 1)
+  if (SSL_CTX_set_cipher_list(ctx, cipher_list) != 1)
     return log_openssl_errors(-8);
 
   /* Set the minimum protocol version */
@@ -228,8 +218,7 @@ void TlsKeyManager::initialize_context() {
      RSA keys must be at least 2048 bits, and ECC keys must be at least
      256 bits.
   */
-  if(SSL_CTX_get_security_level(ctx) < 2)
-    SSL_CTX_set_security_level(ctx, 2);
+  if (SSL_CTX_get_security_level(ctx) < 2) SSL_CTX_set_security_level(ctx, 2);
 
   /* Never use the Subject Common Name for hostname checking, since we will
      often put something like "NDB Node 3" in it. Use Subject Alt Names instead.
@@ -242,8 +231,7 @@ void TlsKeyManager::initialize_context() {
                      TlsKeyManager::on_verify);
 
   /* Store the SSL_CTX in m_ctx */
-  if(SSL_CTX_up_ref(g.ctx) != 1)
-    return log_openssl_errors(-9);
+  if (SSL_CTX_up_ref(g.ctx) != 1) return log_openssl_errors(-9);
   m_ctx = g.ctx;
 
   /* Store our own NodeCertificate in the cert table */
@@ -252,15 +240,15 @@ void TlsKeyManager::initialize_context() {
 
 #endif
 
-int TlsKeyManager::on_verify(int result, X509_STORE_CTX * store) {
+int TlsKeyManager::on_verify(int result, X509_STORE_CTX *store) {
   /* If result is 0, verification has failed, and this callback is
      our opportunity to write a log message.
   */
-  if(! result) {
+  if (!result) {
     NodeCertificate peer_node_cert;
-    X509 * cert = X509_STORE_CTX_get_current_cert(store);
+    X509 *cert = X509_STORE_CTX_get_current_cert(store);
     int err = X509_STORE_CTX_get_error(store);
-    if(cert) {
+    if (cert) {
       char name[128];
       Certificate::get_common_name(cert, name, 128);
       peer_node_cert.init_from_x509(cert);
@@ -276,94 +264,89 @@ int TlsKeyManager::on_verify(int result, X509_STORE_CTX * store) {
   return result;
 }
 
-int TlsKeyManager::check_server_host_auth(const NdbSocket & socket,
-                                          const char * hostname) {
-  if(! socket.has_tls()) return TlsKeyError::no_error;
+int TlsKeyManager::check_server_host_auth(const NdbSocket &socket,
+                                          const char *hostname) {
+  if (!socket.has_tls()) return TlsKeyError::no_error;
 
   /* Get TLS peer's X509 Certificate */
-  X509 * x509 = socket.peer_certificate();
-  if(! x509) return TlsKeyError::auth2_no_cert;
+  X509 *x509 = socket.peer_certificate();
+  if (!x509) return TlsKeyError::auth2_no_cert;
   int r = TlsKeyManager::check_server_host_auth(x509, hostname);
   Certificate::free(x509);
   return r;
 }
 
-int TlsKeyManager::check_server_host_auth(X509 * peer_x509,
-                                          const char * hostname) {
+int TlsKeyManager::check_server_host_auth(X509 *peer_x509,
+                                          const char *hostname) {
   NodeCertificate peer_cert;
   peer_cert.init_from_x509(peer_x509);
-  if(! peer_cert.name_is_conforming())
+  if (!peer_cert.name_is_conforming())
     return TlsKeyError::auth2_bad_common_name;
 
   return check_server_host_auth(peer_cert, hostname);
 }
 
-int TlsKeyManager::check_server_host_auth(const NodeCertificate & nc,
-                                          const char * hostname) {
-
+int TlsKeyManager::check_server_host_auth(const NodeCertificate &nc,
+                                          const char *hostname) {
   /* If the certificate is not bound to a hostname, auth has succeeded */
   int n_bound_hosts = nc.bound_hostnames();
-  if(n_bound_hosts == 0) return 0;
+  if (n_bound_hosts == 0) return 0;
 
   /* If the server's certificate is bound to the name "localhost",
      the server's configured HostName must be either "" or "localhost" */
-  if(nc.bound_localhost()) {
-    if(strlen(hostname) && strcmp(hostname, "localhost"))
+  if (nc.bound_localhost()) {
+    if (strlen(hostname) && strcmp(hostname, "localhost"))
       return TlsKeyError::auth2_bad_hostname;
     return 0;
   }
 
   /* Check configured hostname against certificate hostname */
-  for(int n = 0; n < n_bound_hosts ; n++)
-    if(nc.bound_hostname(n) == hostname)
-      return 0;
+  for (int n = 0; n < n_bound_hosts; n++)
+    if (nc.bound_hostname(n) == hostname) return 0;
 
   return TlsKeyError::auth2_bad_hostname;
 }
 
 class ClientAuthorization {
-public:
+ public:
   ndb_sockaddr m_sockaddr;
   std::unique_ptr<const NodeCertificate> m_cert;
 
-  ClientAuthorization(X509 * x509) : m_cert(NodeCertificate::for_peer(x509)) {}
+  ClientAuthorization(X509 *x509) : m_cert(NodeCertificate::for_peer(x509)) {}
 
-  ClientAuthorization(const struct addrinfo * ai, X509 * x509) :
-    m_sockaddr(ai->ai_addr, ai->ai_addrlen),
-    m_cert(NodeCertificate::for_peer(x509)) {}
+  ClientAuthorization(const struct addrinfo *ai, X509 *x509)
+      : m_sockaddr(ai->ai_addr, ai->ai_addrlen),
+        m_cert(NodeCertificate::for_peer(x509)) {}
 
   int run();
   int run_check_name(int);
   bool compare_list(const addrinfo *) const;
 };
 
-int TlsKeyManager::check_socket_for_auth(const NdbSocket & socket,
-                                         ClientAuthorization ** pAuth) {
+int TlsKeyManager::check_socket_for_auth(const NdbSocket &socket,
+                                         ClientAuthorization **pAuth) {
   *pAuth = nullptr;
-  if(! socket.has_tls())
-    return 0;
+  if (!socket.has_tls()) return 0;
 
-  X509 * cert = socket.peer_certificate();
-  if(! cert)
-    return TlsKeyError::auth2_no_cert;
+  X509 *cert = socket.peer_certificate();
+  if (!cert) return TlsKeyError::auth2_no_cert;
 
-  ClientAuthorization * auth = new ClientAuthorization(cert);
+  ClientAuthorization *auth = new ClientAuthorization(cert);
   Certificate::free(cert);
 
-  if(auth->m_cert->bound_hostnames() == 0) {
-    delete auth; // Hostname auth is not needed
+  if (auth->m_cert->bound_hostnames() == 0) {
+    delete auth;  // Hostname auth is not needed
     return 0;
   }
 
   /* Get peer address from socket */
-  if(ndb_getpeername(socket.ndb_socket(), &(auth->m_sockaddr))) {
+  if (ndb_getpeername(socket.ndb_socket(), &(auth->m_sockaddr))) {
     delete auth;
     return TlsKeyError::auth2_bad_socket;
   }
 
   /* Check for localhost certificate with loopback address */
-  if(auth->m_cert->bound_localhost() && auth->m_sockaddr.is_loopback())
-  {
+  if (auth->m_cert->bound_localhost() && auth->m_sockaddr.is_loopback()) {
     delete auth;
     return 0;
   }
@@ -372,12 +355,11 @@ int TlsKeyManager::check_socket_for_auth(const NdbSocket & socket,
   return 0;
 }
 
-ClientAuthorization *
-TlsKeyManager::test_client_auth(X509 * cert, const struct addrinfo * ai) {
+ClientAuthorization *TlsKeyManager::test_client_auth(
+    X509 *cert, const struct addrinfo *ai) {
   return new ClientAuthorization(ai, cert);
 }
 
-
 int ClientAuthorization::run() {
   /* The certificate contains one or more names. The socket is connected to
      exactly one peer.
@@ -395,9 +377,9 @@ int ClientAuthorization::run() {
      Iterate over the list in the cert, making a blocking call for each name.
   */
   int ck = 0;
-  for(int i = 0; i < m_cert->bound_hostnames() ; i++) {
+  for (int i = 0; i < m_cert->bound_hostnames(); i++) {
     ck = run_check_name(i);
-    if(ck == 0) break;
+    if (ck == 0) break;
   }
 
   return ck;
@@ -413,31 +395,30 @@ int ClientAuthorization::run_check_name(int n) {
   hints.ai_socktype = SOCK_STREAM;
   hints.ai_protocol = IPPROTO_TCP;
 
-  struct addrinfo* ai_list = nullptr;
+  struct addrinfo *ai_list = nullptr;
   int r = getaddrinfo(name.c_str(), nullptr, &hints, &ai_list);
-  if(r) {
+  if (r) {
     g_eventLogger->error(
-        "TLS Authorization failure checking host name '%s': '%s'",
-        name.c_str(), gai_strerror(r));
+        "TLS Authorization failure checking host name '%s': '%s'", name.c_str(),
+        gai_strerror(r));
     return TlsKeyError::auth2_resolver_error;
   }
 
   bool cmp = compare_list(ai_list);
   freeaddrinfo(ai_list);
-  if(cmp == true) return 0;
+  if (cmp == true) return 0;
   return TlsKeyError::auth2_bad_hostname;
 }
 
-bool ClientAuthorization::compare_list(const addrinfo * ai_list) const {
-  for(const addrinfo *ai = ai_list; ai != nullptr; ai = ai->ai_next) {
+bool ClientAuthorization::compare_list(const addrinfo *ai_list) const {
+  for (const addrinfo *ai = ai_list; ai != nullptr; ai = ai->ai_next) {
     ndb_sockaddr addr(ai->ai_addr, ai->ai_addrlen);
-    if(m_sockaddr.has_same_addr(addr))
-      return true;
+    if (m_sockaddr.has_same_addr(addr)) return true;
   }
   return false;
 }
 
-int TlsKeyManager::perform_client_host_auth(ClientAuthorization * auth) {
+int TlsKeyManager::perform_client_host_auth(ClientAuthorization *auth) {
   int r = auth->run();
   delete auth;
   return r;
@@ -446,84 +427,85 @@ int TlsKeyManager::perform_client_host_auth(ClientAuthorization * auth) {
 /*
  * Certificate table routines
  */
-void TlsKeyManager::describe_cert(cert_record & entry,
-                                  struct x509_st * cert) {
+void TlsKeyManager::describe_cert(cert_record &entry, struct x509_st *cert) {
   SerialNumber::print(entry.serial, cert_record::SN_buf_len,
                       X509_get0_serialNumber(cert));
   Certificate::get_common_name(cert, entry.name, cert_record::CN_buf_len);
   entry.expires = 0;
-  if(ASN1_TIME_to_tm(X509_get0_notAfter(cert), & entry.exp_tm))
-    entry.expires = mktime(& entry.exp_tm);
+  if (ASN1_TIME_to_tm(X509_get0_notAfter(cert), &entry.exp_tm))
+    entry.expires = mktime(&entry.exp_tm);
 }
 
-void TlsKeyManager::cert_table_set(int node_id, X509 * cert) {
-  Guard mutex_guard(& m_cert_table_mutex);
+void TlsKeyManager::cert_table_set(int node_id, X509 *cert) {
+  Guard mutex_guard(&m_cert_table_mutex);
   assert(node_id < MAX_NODES);
-  if(node_id == 0) return; // Client certs do not go into table
+  if (node_id == 0) return;  // Client certs do not go into table
 
   /* In the case of a multi-transporter, the entry may already be active */
-  struct cert_record & entry = m_cert_table[node_id];
-  if(! entry.active) {
+  struct cert_record &entry = m_cert_table[node_id];
+  if (!entry.active) {
     describe_cert(entry, cert);
     entry.active = true;
   }
 }
 
 void TlsKeyManager::cert_table_clear(int node_id) {
-  Guard mutex_guard(& m_cert_table_mutex);
+  Guard mutex_guard(&m_cert_table_mutex);
   assert(node_id < MAX_NODES);
 
-  struct cert_record & entry = m_cert_table[node_id];
+  struct cert_record &entry = m_cert_table[node_id];
   entry.serial[0] = '\0';
   entry.name[0] = '\0';
   entry.expires = 0;
   entry.active = false;
 }
 
-bool TlsKeyManager::cert_table_get(const cert_record & row,
-                                    cert_table_entry * client_row) const
-{
+bool TlsKeyManager::cert_table_get(const cert_record &row,
+                                   cert_table_entry *client_row) const {
   assert(row.active);
   client_row->expires = row.expires;
-  client_row->name    = & row.name[0];
-  client_row->serial  = & row.serial[0];
+  client_row->name = &row.name[0];
+  client_row->serial = &row.serial[0];
   return true;
 }
 
-bool TlsKeyManager::iterate_cert_table(int & node, cert_table_entry * client) {
-  Guard mutex_guard(& m_cert_table_mutex);
+bool TlsKeyManager::iterate_cert_table(int &node, cert_table_entry *client) {
+  Guard mutex_guard(&m_cert_table_mutex);
 
-  if(node < 0) node = 0;
-  if(m_ctx) {
-    while(node < MAX_NODES_ID) {
+  if (node < 0) node = 0;
+  if (m_ctx) {
+    while (node < MAX_NODES_ID) {
       node += 1;
-      const cert_record & row = m_cert_table[node];
-      if(row.active)
-        return cert_table_get(row, client);
+      const cert_record &row = m_cert_table[node];
+      if (row.active) return cert_table_get(row, client);
     }
   }
   return false;
 }
 
 bool TlsKeyManager::open_active_cert() {
-  if(ActivePrivateKey::find(m_search_path, m_node_id, m_type, m_key_file)) {
-    EVP_PKEY * key = PrivateKey::open(m_key_file, nullptr);
-    if(key) {
-      if(ActiveCertificate::find(m_search_path, m_node_id, m_type, m_cert_file))
-      {
-        STACK_OF(X509) * certs = Certificate::open(m_cert_file);
-        if(certs) {
-          if(EVP_PKEY_eq(key, X509_get0_pubkey(sk_X509_value(certs, 0)))) {
+  if (ActivePrivateKey::find(m_search_path, m_node_id, m_type, m_key_file)) {
+    EVP_PKEY *key = PrivateKey::open(m_key_file, nullptr);
+    if (key) {
+      if (ActiveCertificate::find(m_search_path, m_node_id, m_type,
+                                  m_cert_file)) {
+        STACK_OF(X509) *certs = Certificate::open(m_cert_file);
+        if (certs) {
+          if (EVP_PKEY_eq(key, X509_get0_pubkey(sk_X509_value(certs, 0)))) {
             m_node_cert.init_from_credentials(certs, key);
-            if(m_node_cert.is_signed()) {
-              if(check_replace_date(1.0))
-                return true;
+            if (m_node_cert.is_signed()) {
+              if (check_replace_date(1.0)) return true;
               log_error(TlsKeyError::active_cert_expired);
-            } else log_error(TlsKeyError::active_cert_invalid);
-          } else log_error(TlsKeyError::active_cert_mismatch);
-        } else log_error(TlsKeyError::cannot_read_active_cert);
-      } else log_error(TlsKeyError::active_cert_not_found);
-    } else log_error(TlsKeyError::cannot_read_active_key);
+            } else
+              log_error(TlsKeyError::active_cert_invalid);
+          } else
+            log_error(TlsKeyError::active_cert_mismatch);
+        } else
+          log_error(TlsKeyError::cannot_read_active_cert);
+      } else
+        log_error(TlsKeyError::active_cert_not_found);
+    } else
+      log_error(TlsKeyError::cannot_read_active_key);
   }
   return false;
 }
@@ -533,7 +515,7 @@ bool TlsKeyManager::check_replace_date(float pct) {
   time_t current_time = time(nullptr);
   time_t replace_time = m_node_cert.replace_time(pct);
 
-  return( (replace_time > 0) && (current_time < replace_time) );
+  return ((replace_time > 0) && (current_time < replace_time));
 }
 
 #ifdef TEST_TLSKEYMANAGER
@@ -542,7 +524,7 @@ bool TlsKeyManager::check_replace_date(float pct) {
 */
 
 /* */
-int main(int argc, const char * argv[]) {
+int main(int argc, const char *argv[]) {
   TlsKeyManager t;
   t.init_mgm_client(argc > 1 ? argv[1] : nullptr, Node::Type::ANY);
   puts(t.ctx() ? "Loaded a certificate." : "Did not load a certificate.");
