@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2003, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2003, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1274,11 +1273,11 @@ inline NdbTableImpl *NdbDictionaryImpl::getTable(const char *table_name,
 
   // Don't allow opening table without database or schema name specified,
   // the internal name format depends on those to be set
-  if (!checkDatabaseAndSchemaName()) DBUG_RETURN(NULL);
+  if (!checkDatabaseAndSchemaName()) DBUG_RETURN(nullptr);
 
   const BaseString internal_tabname(m_ndb.internalize_table_name(table_name));
   Ndb_local_table_info *info = get_local_table_info(internal_tabname);
-  if (info == nullptr) DBUG_RETURN(0);
+  if (info == nullptr) DBUG_RETURN(nullptr);
   if (data) *data = info->m_local_data;
   DBUG_RETURN(info->m_table_impl);
 }
@@ -1384,14 +1383,14 @@ inline NdbIndexImpl *NdbDictionaryImpl::getIndexGlobal(const char *index_name,
   // NdbDictionary. So if an index is not found, the error 723
   // "table not found" is returned. Map 723 to 4243 "index not found"
   if (m_error.code == 0 || m_error.code == 723) m_error.code = 4243;
-  DBUG_RETURN(0);
+  DBUG_RETURN(nullptr);
 }
 
 inline NdbIndexImpl *NdbDictionaryImpl::getIndexGlobal(const char *indexName,
                                                        const char *tableName) {
   DBUG_ENTER("NdbDictionaryImpl::getIndexGlobal");
   NdbTableImpl *t = getTableGlobal(tableName);
-  if (t == nullptr) DBUG_RETURN(0);
+  if (t == nullptr) DBUG_RETURN(nullptr);
   DBUG_RETURN(getIndexGlobal(indexName, *t));
 }
 
