@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2020, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2020, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,6 +24,10 @@
 
 #include "process_management.hpp"
 #include <NdbSleep.h>
+#include "storage/ndb/test/run-test/atrt.hpp"
+
+extern const char *opt_tls_search_path;
+extern unsigned long long opt_mgm_tls;
 
 bool ProcessManagement::startAllProcesses() {
   if (clusterProcessesStatus == ProcessesStatus::RUNNING) {
@@ -349,7 +352,14 @@ bool ProcessManagement::connectNdbMgm(atrt_process &proc) {
     return false;
   }
 
-  if (ndb_mgm_connect(handle, 30, 1, 0) != -1) {
+  tlsKeyManager.init_mgm_client(opt_tls_search_path);
+  if (tlsKeyManager.ctx()) {
+    g_logger.debug("Connecting to ndb mgm using TLS");
+  }
+  ndb_mgm_set_ssl_ctx(handle, tlsKeyManager.ctx());
+
+  if (ndb_mgm_connect_tls(handle, 30, 1, 0, opt_mgm_tls) != -1) {
+    g_logger.debug("Connected to ndb mgm %s", tmp.c_str());
     proc.m_ndb_mgm_handle = handle;
     return true;
   }
