@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2011, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2011, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1064,7 +1063,7 @@ void runTestSuite(MYSQL &mysql, Ndb &ndb) {
       default:
         //case 6:
         {
-          IndexScanOperation root(query, "PRIMARY", 0, 1000, 
+          IndexScanOperation root(query, "PRIMARY", 0, 1000,
                                  NdbQueryOptions::ScanOrdering_descending);
           LookupOperation child(query, &root);
           runCase(mysql, ndb, query, tabName, 10*(caseNo-6), 10*(caseNo-6));
@@ -1101,6 +1100,7 @@ int main(int argc, char *argv[]) {
   mySQLExec(mysql, "use CK_DB");
   {
     Ndb_cluster_connection con(connectString);
+    con.configure_tls(opt_tls_search_path, opt_mgm_tls);
     if (con.connect(12, 5, 1) != 0) {
       ndbout << "Unable to connect to management server." << endl;
       return NDBT_ProgramExit(NDBT_FAILED);
