@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2019, 2021, Oracle and/or its affiliates.
+   Copyright (c) 2019, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -25,9 +25,8 @@
 #ifndef NDB_TOOLS_PROGRAM_EXIT_CODES_HPP
 #define NDB_TOOLS_PROGRAM_EXIT_CODES_HPP
 
-namespace NdbToolsProgramExitCode
-{
-  enum {OK = 0, FAILED = 1, WRONG_ARGS = 2};
+namespace NdbToolsProgramExitCode {
+enum { OK = 0, FAILED = 1, WRONG_ARGS = 2 };
 }
 
 #endif  // NDB_TOOLS_PROGRAM_EXIT_CODES_HPP
