@@ -1,16 +1,15 @@
-/* Copyright (c) 2013, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2013, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -76,6 +75,7 @@ int init_events_transactions_history_long(
   events_transactions_history_long_index.m_u32.store(0);
 
   if (events_transactions_history_long_size == 0) {
+    events_transactions_history_long_array = nullptr;
     return 0;
   }
 
@@ -84,7 +84,12 @@ int init_events_transactions_history_long(
       events_transactions_history_long_size, sizeof(PFS_events_transactions),
       PFS_events_transactions, MYF(MY_ZEROFILL));
 
-  return (events_transactions_history_long_array ? 0 : 1);
+  if (events_transactions_history_long_array == nullptr) {
+    events_transactions_history_long_size = 0;
+    return 1;
+  }
+
+  return 0;
 }
 
 /** Cleanup table EVENTS_TRANSACTIONS_HISTORY_LONG. */
@@ -94,6 +99,7 @@ void cleanup_events_transactions_history_long() {
                  sizeof(PFS_events_transactions),
                  events_transactions_history_long_array);
   events_transactions_history_long_array = nullptr;
+  events_transactions_history_long_size = 0;
 }
 
 static inline void copy_events_transactions(
