@@ -1,17 +1,24 @@
-/* Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2008, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
+  it under the terms of the GNU General Public License, version 2.0,
+  as published by the Free Software Foundation.
+
+  This program is also distributed with certain software (including
+  but not limited to OpenSSL) that is licensed under separate terms,
+  as designated in a particular file or component or in included license
+  documentation.  The authors of MySQL hereby grant you an additional
+  permission to link the program and your derivative works with the
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  GNU General Public License, version 2.0, for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software Foundation,
-  51 Franklin Street, Suite 500, Boston, MA 02110-1335 USA */
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 #ifndef PFS_INSTR_H
 #define PFS_INSTR_H
@@ -28,36 +35,49 @@ struct PFS_file_class;
 struct PFS_table_share;
 struct PFS_thread_class;
 struct PFS_socket_class;
+class PFS_opaque_container_page;
 
 class THD;
 
-#include "my_global.h"
+#include "my_config.h"
+
+#include <sys/types.h>
+#include <time.h>
+#include <atomic>
+
+#include "my_inttypes.h"
+#include "my_io.h"
+#include "my_thread_os_id.h"
 #ifdef _WIN32
 #include <winsock2.h>
 #endif
 #ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#include "my_compiler.h"
-#include "pfs_lock.h"
-#include "pfs_stat.h"
-#include "pfs_instr_class.h"
-#include "pfs_events_waits.h"
-#include "pfs_events_stages.h"
-#include "pfs_events_statements.h"
-#include "pfs_events_transactions.h"
-#include "pfs_server.h"
 #include "lf.h"
-#include "pfs_con_slice.h"
-#include "pfs_column_types.h"
-#include "mdl.h"
+#include "my_compiler.h"
+#include "my_hostname.h" /* HOSTNAME_LENGTH */
+#include "sql/mdl.h"
+#include "storage/perfschema/pfs_column_types.h"
+#include "storage/perfschema/pfs_con_slice.h"
+#include "storage/perfschema/pfs_events_stages.h"
+#include "storage/perfschema/pfs_events_statements.h"
+#include "storage/perfschema/pfs_events_transactions.h"
+#include "storage/perfschema/pfs_events_waits.h"
+#include "storage/perfschema/pfs_instr_class.h"
+#include "storage/perfschema/pfs_lock.h"
+#include "storage/perfschema/pfs_name.h"
+#include "storage/perfschema/pfs_server.h"
+#include "storage/perfschema/pfs_stat.h"
+#include "violite.h" /* enum_vio_type */
+
+#include <mysql/components/services/mysql_server_telemetry_traces_service.h>
 
 extern PFS_single_stat *thread_instr_class_waits_array_start;
 extern PFS_single_stat *thread_instr_class_waits_array_end;
-extern my_bool show_compatibility_56;
 
 /**
-  @addtogroup Performance_schema_buffers
+  @addtogroup performance_schema_buffers
   @{
 */
 
@@ -67,20 +87,27 @@ struct PFS_user;
 struct PFS_account;
 
 /** Base structure for wait instruments. */
-struct PFS_instr
-{
+struct PFS_instr {
   /** Internal lock. */
   pfs_lock m_lock;
   /** Enabled flag. */
   bool m_enabled;
   /** Timed flag. */
   bool m_timed;
+  /** Container page. */
+  PFS_opaque_container_page *m_page;
 };
 
 /** Instrumented mutex implementation. @see PSI_mutex. */
-struct PFS_ALIGNED PFS_mutex : public PFS_instr
-{
-  /** Mutex identity, typically a pthread_mutex_t. */
+struct PFS_mutex : public PSI_mutex {
+  /** Internal lock. */
+  pfs_lock m_lock;
+  /** Timed flag. */
+  bool m_timed;
+  /** Container page. */
+  PFS_opaque_container_page *m_page;
+
+  /** Mutex identity, typically a @c pthread_mutex_t. */
   const void *m_identity;
   /** Mutex class. */
   PFS_mutex_class *m_class;
@@ -88,17 +115,25 @@ struct PFS_ALIGNED PFS_mutex : public PFS_instr
   PFS_mutex_stat m_mutex_stat;
   /** Current owner. */
   PFS_thread *m_owner;
+#ifdef LATER_WL2333
   /**
-    Timestamp of the last lock.
+    Time stamp of the last lock.
     This statistic is not exposed in user visible tables yet.
   */
   ulonglong m_last_locked;
+#endif /* LATER_WL2333 */
 };
 
 /** Instrumented rwlock implementation. @see PSI_rwlock. */
-struct PFS_ALIGNED PFS_rwlock : public PFS_instr
-{
-  /** RWLock identity, typically a pthread_rwlock_t. */
+struct PFS_rwlock : public PSI_rwlock {
+  /** Internal lock. */
+  pfs_lock m_lock;
+  /** Timed flag. */
+  bool m_timed;
+  /** Container page. */
+  PFS_opaque_container_page *m_page;
+
+  /** RWLock identity, typically a @c pthread_rwlock_t. */
   const void *m_identity;
   /** RWLock class. */
   PFS_rwlock_class *m_class;
@@ -108,22 +143,30 @@ struct PFS_ALIGNED PFS_rwlock : public PFS_instr
   PFS_thread *m_writer;
   /** Current count of readers. */
   uint m_readers;
+#ifdef LATER_WL2333
   /**
-    Timestamp of the last write.
+    Time stamp of the last write.
     This statistic is not exposed in user visible tables yet.
   */
   ulonglong m_last_written;
   /**
-    Timestamp of the last read.
+    Time stamp of the last read.
     This statistic is not exposed in user visible tables yet.
   */
   ulonglong m_last_read;
+#endif /* LATER_WL2333 */
 };
 
-/** Instrumented cond implementation. @see PSI_cond. */
-struct PFS_ALIGNED PFS_cond : public PFS_instr
-{
-  /** Condition identity, typically a pthread_cond_t. */
+/** Instrumented condition implementation. @see PSI_cond. */
+struct PFS_cond : public PSI_cond {
+  /** Internal lock. */
+  pfs_lock m_lock;
+  /** Timed flag. */
+  bool m_timed;
+  /** Container page. */
+  PFS_opaque_container_page *m_page;
+
+  /** Condition identity, typically a @c pthread_cond_t. */
   const void *m_identity;
   /** Condition class. */
   PFS_cond_class *m_class;
@@ -132,28 +175,25 @@ struct PFS_ALIGNED PFS_cond : public PFS_instr
 };
 
 /** Instrumented File and FILE implementation. @see PSI_file. */
-struct PFS_ALIGNED PFS_file : public PFS_instr
-{
-  uint32 get_version()
-  { return m_lock.get_version(); }
+struct PFS_ALIGNED PFS_file : public PFS_instr {
+  uint32 get_version() { return m_lock.get_version(); }
 
   /** File identity */
   const void *m_identity;
   /** File name. */
-  char m_filename[FN_REFLEN];
-  /** File name length in bytes. */
-  uint m_filename_length;
+  PFS_file_name m_file_name;
   /** File class. */
   PFS_file_class *m_class;
   /** File usage statistics. */
   PFS_file_stat m_file_stat;
+  /** True if a temporary file. */
+  bool m_temporary;
 };
 
 /** Instrumented table implementation. @see PSI_table. */
-struct PFS_ALIGNED PFS_table
-{
+struct PFS_ALIGNED PFS_table {
   /**
-    True if table io instrumentation is enabled.
+    True if table I/O instrumentation is enabled.
     This flag is computed.
   */
   bool m_io_enabled;
@@ -163,7 +203,7 @@ struct PFS_ALIGNED PFS_table
   */
   bool m_lock_enabled;
   /**
-    True if table io instrumentation is timed.
+    True if table I/O instrumentation is timed.
     This flag is computed.
   */
   bool m_io_timed;
@@ -173,29 +213,26 @@ struct PFS_ALIGNED PFS_table
   */
   bool m_lock_timed;
 
-  /** True if table io statistics have been collected. */
+  /** True if table I/O statistics have been collected. */
   bool m_has_io_stats;
 
   /** True if table lock statistics have been collected. */
   bool m_has_lock_stats;
 
-public:
+ public:
   /**
     Aggregate this table handle statistics to the parents.
     Only use this method for handles owned by the calling code.
     @sa sanitized_aggregate.
   */
-  void aggregate(const TABLE_SHARE *server_share)
-  {
-    if (m_has_io_stats)
-    {
-      safe_aggregate_io(server_share, & m_table_stat, m_share);
-      m_has_io_stats= false;
+  void aggregate(const TABLE_SHARE *server_share) {
+    if (m_has_io_stats) {
+      safe_aggregate_io(server_share, &m_table_stat, m_share);
+      m_has_io_stats = false;
     }
-    if (m_has_lock_stats)
-    {
-      safe_aggregate_lock(& m_table_stat, m_share);
-      m_has_lock_stats= false;
+    if (m_has_lock_stats) {
+      safe_aggregate_lock(&m_table_stat, m_share);
+      m_has_lock_stats = false;
     }
   }
 
@@ -206,19 +243,19 @@ public:
     @sa sanitized_aggregate_io
     @sa sanitized_aggregate_lock
   */
-  void sanitized_aggregate(void);
+  void sanitized_aggregate();
 
   /**
-    Aggregate this table handle io statistics to the parents.
+    Aggregate this table handle I/O statistics to the parents.
     This method is safe to call on handles not owned by the calling code.
   */
-  void sanitized_aggregate_io(void);
+  void sanitized_aggregate_io();
 
   /**
     Aggregate this table handle lock statistics to the parents.
     This method is safe to call on handles not owned by the calling code.
   */
-  void sanitized_aggregate_lock(void);
+  void sanitized_aggregate_lock();
 
   /** Internal lock. */
   pfs_lock m_lock;
@@ -236,29 +273,36 @@ public:
   PFS_TL_LOCK_TYPE m_internal_lock;
   /** Current external lock. */
   PFS_TL_LOCK_TYPE m_external_lock;
+  /** Container page. */
+  PFS_opaque_container_page *m_page;
 
-private:
+ private:
   static void safe_aggregate_io(const TABLE_SHARE *optional_server_share,
                                 PFS_table_stat *stat,
-                                PFS_table_share *safe_share);
+                                PFS_table_share *table_share);
   static void safe_aggregate_lock(PFS_table_stat *stat,
-                                  PFS_table_share *safe_share);
+                                  PFS_table_share *table_share);
 };
 
 /** Instrumented socket implementation. @see PSI_socket. */
-struct PFS_ALIGNED PFS_socket : public PFS_instr
-{
-  uint32 get_version()
-  { return m_lock.get_version(); }
+struct PFS_socket : public PSI_socket {
+  /** Internal lock. */
+  pfs_lock m_lock;
+  /** Timed flag. */
+  bool m_timed;
+  /** Container page. */
+  PFS_opaque_container_page *m_page;
+
+  uint32 get_version() { return m_lock.get_version(); }
 
   /** Socket identity, typically int */
   const void *m_identity;
   /** Owning thread, if applicable */
   PFS_thread *m_thread_owner;
   /** Socket file descriptor */
-  uint m_fd;
+  my_socket m_fd;
   /** Raw socket address */
-  struct sockaddr_storage  m_sock_addr;
+  struct sockaddr_storage m_sock_addr;
   /** Length of address */
   socklen_t m_addr_len;
   /** Idle flag. */
@@ -270,10 +314,8 @@ struct PFS_ALIGNED PFS_socket : public PFS_instr
 };
 
 /** Instrumented metadata lock implementation. @see PSI_metadata_lock. */
-struct PFS_ALIGNED PFS_metadata_lock : public PFS_instr
-{
-  uint32 get_version()
-  { return m_lock.get_version(); }
+struct PFS_ALIGNED PFS_metadata_lock : public PFS_instr {
+  uint32 get_version() { return m_lock.get_version(); }
 
   /** Lock identity. */
   const void *m_identity;
@@ -294,9 +336,9 @@ struct PFS_ALIGNED PFS_metadata_lock : public PFS_instr
   - "wait/io/table/sql/handler"
   - "wait/lock/table/sql/handler"
   are implemented by calling code in a storage engine,
-  that can cause nested waits (file io, mutex, ...)
-  Because of partitioned tables, a table io event (on the whole table)
-  can contain a nested table io event (on a partition).
+  that can cause nested waits (file I/O, mutex, ...)
+  Because of partitioned tables, a table I/O event (on the whole table)
+  can contain a nested table I/O event (on a partition).
   Because of additional debug instrumentation,
   waiting on what looks like a "mutex" (safe_mutex, innodb sync0sync, ...)
   can cause nested waits to be recorded.
@@ -324,17 +366,84 @@ struct PFS_ALIGNED PFS_metadata_lock : public PFS_instr
 /** Max size of the statements stack. */
 extern uint statement_stack_max;
 /** Max size of the digests token array. */
-extern uint pfs_max_digest_length;
+extern size_t pfs_max_digest_length;
 /** Max size of SQL TEXT. */
-extern uint pfs_max_sqltext;
+extern size_t pfs_max_sqltext;
 
 /** Instrumented thread implementation. @see PSI_thread. */
-struct PFS_ALIGNED PFS_thread : PFS_connection_slice
-{
-  static PFS_thread* get_current_thread(void);
+struct PFS_ALIGNED PFS_thread : PFS_connection_slice {
+  static PFS_thread *get_current_thread();
 
   /** Thread instrumentation flag. */
   bool m_enabled;
+  /** Thread history instrumentation flag. */
+  bool m_history;
+
+  /**
+    Derived flag flag_events_waits_history, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_WAITS_HISTORY].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_waits_history;
+  /**
+    Derived flag flag_events_waits_history_long, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_WAITS_HISTORY_LONG].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_waits_history_long;
+  /**
+    Derived flag flag_events_stages_history, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_STAGES_HISTORY].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_stages_history;
+  /**
+    Derived flag flag_events_stages_history_long, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_STAGES_HISTORY_LONG].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_stages_history_long;
+  /**
+    Derived flag flag_events_statements_history, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_STATEMENTS_HISTORY].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_statements_history;
+  /**
+    Derived flag flag_events_statements_history_long, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_STATEMENTS_HISTORY_LONG].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_statements_history_long;
+  /**
+    Derived flag flag_events_transactions_history, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_TRANSACTIONS_HISTORY].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_transactions_history;
+  /**
+    Derived flag flag_events_transactions_history_long, per thread.
+    Cached computation of
+      TABLE SETUP_CONSUMERS[EVENTS_TRANSACTIONS_HISTORY_LONG].ENABLED == 'YES'
+    AND
+      TABLE THREADS[THREAD_ID].HISTORY == 'YES'
+  */
+  bool m_flag_events_transactions_history_long;
+
   /** Current wait event in the event stack. */
   PFS_events_waits *m_events_waits_current;
   /** Event ID counter */
@@ -369,14 +478,21 @@ struct PFS_ALIGNED PFS_thread : PFS_connection_slice
   ulonglong m_thread_internal_id;
   /** Parent internal thread identifier. */
   ulonglong m_parent_thread_internal_id;
-  /** External (SHOW PROCESSLIST) thread identifier, not unique. */
+  /** External (@code SHOW PROCESSLIST @endcode) thread identifier, not unique.
+   */
   ulong m_processlist_id;
+  /** External (Operating system) thread identifier, if any. */
+  my_thread_os_id_t m_thread_os_id;
   /** Thread class. */
   PFS_thread_class *m_class;
+  /** True if a system thread. */
+  bool m_system_thread;
   /**
     Stack of events waits.
-    This member holds the data for the table PERFORMANCE_SCHEMA.EVENTS_WAITS_CURRENT.
-    Note that stack[0] is a dummy record that represents the parent stage/statement/transaction.
+    This member holds the data for the table
+    PERFORMANCE_SCHEMA.EVENTS_WAITS_CURRENT.
+    Note that stack[0] is a dummy record that represents the parent
+    stage/statement/transaction.
     For example, assuming the following tree:
     - STAGE ID 100
       - WAIT ID 101, parent STAGE 100
@@ -458,34 +574,40 @@ struct PFS_ALIGNED PFS_thread : PFS_connection_slice
     User name.
     Protected by @c m_session_lock.
   */
-  char m_username[USERNAME_LENGTH];
-  /**
-    Length of @c m_username.
-    Protected by @c m_session_lock.
-  */
-  uint m_username_length;
+  PFS_user_name m_user_name;
+
   /**
     Host name.
     Protected by @c m_session_lock.
   */
-  char m_hostname[HOSTNAME_LENGTH];
-  /**
-    Length of @c m_hostname.
-    Protected by @c m_session_lock.
-  */
-  uint m_hostname_length;
+  PFS_host_name m_host_name;
+
   /**
     Database name.
     Protected by @c m_stmt_lock.
   */
-  char m_dbname[NAME_LEN];
+  PFS_schema_name m_db_name;
+
   /**
-    Length of @c m_dbname.
-    Protected by @c m_stmt_lock.
+    Resource group name.
+    Protected by @c m_session_lock.
   */
-  uint m_dbname_length;
+  char m_groupname[NAME_LEN];
+  /**
+    Length of @c m_groupname.
+    Protected by @c m_session_lock.
+  */
+  uint m_groupname_length;
+  /**
+    Operating system name.
+  */
+  char m_os_name[PFS_MAX_OS_NAME_LENGTH];
+  /** User-defined data. */
+  void *m_user_data;
   /** Current command. */
   int m_command;
+  /** Connection type. */
+  enum_vio_type m_connection_type;
   /** Start time. */
   time_t m_start_time;
   /**
@@ -497,7 +619,7 @@ struct PFS_ALIGNED PFS_thread : PFS_connection_slice
   /** Processlist state (derived from stage). */
   PFS_stage_key m_stage;
   /** Current stage progress. */
-  PSI_stage_progress* m_stage_progress;
+  PSI_stage_progress *m_stage_progress;
   /**
     Processlist info.
     Protected by @c m_stmt_lock.
@@ -509,6 +631,9 @@ struct PFS_ALIGNED PFS_thread : PFS_connection_slice
   */
   uint m_processlist_info_length;
 
+  /** Executed on secondary engine. */
+  bool m_secondary;
+
   PFS_events_stages m_stage_current;
 
   /** Size of @c m_events_statements_stack. */
@@ -518,10 +643,18 @@ struct PFS_ALIGNED PFS_thread : PFS_connection_slice
   PFS_events_transactions m_transaction_current;
 
   THD *m_thd;
+  THD *m_cnt_thd;
   PFS_host *m_host;
   PFS_user *m_user;
   PFS_account *m_account;
 
+  /** Remote (peer) port */
+  uint m_peer_port;
+  /** Raw socket address */
+  struct sockaddr_storage m_sock_addr;
+  /** Length of address */
+  socklen_t m_sock_addr_len;
+
   /** Reset session connect attributes */
   void reset_session_connect_attrs();
 
@@ -541,16 +674,76 @@ struct PFS_ALIGNED PFS_thread : PFS_connection_slice
   */
   uint m_session_connect_attrs_cs_number;
 
-  void carry_memory_stat_delta(PFS_memory_stat_delta *delta, uint index);
+  /** Reset all memory statistics. */
+  void rebase_memory_stats();
 
-  void set_enabled(bool enabled);
+  void carry_memory_stat_alloc_delta(PFS_memory_stat_alloc_delta *delta,
+                                     uint index);
+  void carry_memory_stat_free_delta(PFS_memory_stat_free_delta *delta,
+                                    uint index);
+
+  void set_enabled(bool enabled) { m_enabled = enabled; }
+
+  void set_history(bool history) {
+    m_history = history;
+    set_history_derived_flags();
+  }
+
+  void set_history_derived_flags();
+
+  /**
+    Per thread memory aggregated statistics.
+    This member holds the data for the table
+    PERFORMANCE_SCHEMA.MEMORY_SUMMARY_BY_THREAD_BY_EVENT_NAME.
+    Immutable, safe to use without internal lock.
+  */
+  PFS_memory_safe_stat *m_instr_class_memory_stats;
+
+  void set_instr_class_memory_stats(PFS_memory_safe_stat *array) {
+    m_has_memory_stats = false;
+    m_instr_class_memory_stats = array;
+  }
+
+  const PFS_memory_safe_stat *read_instr_class_memory_stats() const {
+    if (!m_has_memory_stats) {
+      return nullptr;
+    }
+    return m_instr_class_memory_stats;
+  }
+
+  PFS_memory_safe_stat *write_instr_class_memory_stats() {
+    if (!m_has_memory_stats) {
+      rebase_memory_stats();
+      m_has_memory_stats = true;
+    }
+    return m_instr_class_memory_stats;
+  }
+  void mem_cnt_alloc(size_t size);
+  void mem_cnt_free(size_t size);
+#ifndef NDEBUG
+  const char *current_key_name;
+#endif
+
+  PFS_session_all_memory_stat m_session_all_memory_stat;
+
+  /** Copy of g_telemetry. */
+  telemetry_t *m_telemetry;
+  telemetry_session_t *m_telemetry_session;
+
+#ifndef NDEBUG
+  bool m_debug_session_notified;
+#endif
 };
 
-void carry_global_memory_stat_delta(PFS_memory_stat_delta *delta, uint index);
+void carry_global_memory_stat_alloc_delta(PFS_memory_stat_alloc_delta *delta,
+                                          uint index);
+void carry_global_memory_stat_free_delta(PFS_memory_stat_free_delta *delta,
+                                         uint index);
 
 extern PFS_stage_stat *global_instr_class_stages_array;
 extern PFS_statement_stat *global_instr_class_statements_array;
-extern PFS_memory_stat *global_instr_class_memory_array;
+extern PFS_histogram global_statements_histogram;
+extern std::atomic<PFS_memory_shared_stat *> global_instr_class_memory_array;
 
 PFS_mutex *sanitize_mutex(PFS_mutex *unsafe);
 PFS_rwlock *sanitize_rwlock(PFS_rwlock *unsafe);
@@ -564,40 +757,46 @@ int init_instruments(const PFS_global_param *param);
 void cleanup_instruments();
 int init_file_hash(const PFS_global_param *param);
 void cleanup_file_hash();
-PFS_mutex* create_mutex(PFS_mutex_class *mutex_class, const void *identity);
+PFS_mutex *create_mutex(PFS_mutex_class *klass, const void *identity);
 void destroy_mutex(PFS_mutex *pfs);
-PFS_rwlock* create_rwlock(PFS_rwlock_class *klass, const void *identity);
+PFS_rwlock *create_rwlock(PFS_rwlock_class *klass, const void *identity);
 void destroy_rwlock(PFS_rwlock *pfs);
-PFS_cond* create_cond(PFS_cond_class *klass, const void *identity);
+PFS_cond *create_cond(PFS_cond_class *klass, const void *identity);
 void destroy_cond(PFS_cond *pfs);
 
-PFS_thread* create_thread(PFS_thread_class *klass, const void *identity,
-                          ulonglong processlist_id);
+PFS_thread *create_thread(PFS_thread_class *klass, PSI_thread_seqnum seqnum,
+                          const void *identity, ulonglong processlist_id);
+
+PFS_thread *find_thread_by_processlist_id(ulonglong processlist_id);
+PFS_thread *find_thread_by_internal_id(ulonglong thread_id);
 
 void destroy_thread(PFS_thread *pfs);
 
-PFS_file* find_or_create_file(PFS_thread *thread, PFS_file_class *klass,
+PFS_file *find_or_create_file(PFS_thread *thread, PFS_file_class *klass,
                               const char *filename, uint len, bool create);
 
+PFS_file *start_file_rename(PFS_thread *thread, const char *old_name);
+int end_file_rename(PFS_thread *thread, PFS_file *pfs, const char *new_name,
+                    int rename_result);
+
+PFS_file *find_file(PFS_thread *thread, PFS_file_class *klass,
+                    const char *filename, uint len);
 void release_file(PFS_file *pfs);
-void destroy_file(PFS_thread *thread, PFS_file *pfs);
-PFS_table* create_table(PFS_table_share *share, PFS_thread *opening_thread,
+void delete_file_name(PFS_thread *thread, PFS_file *pfs);
+void destroy_file(PFS_thread *thread, PFS_file *pfs, bool delete_name);
+PFS_table *create_table(PFS_table_share *share, PFS_thread *opening_thread,
                         const void *identity);
 void destroy_table(PFS_table *pfs);
 
-PFS_socket* create_socket(PFS_socket_class *socket_class,
-                          const my_socket *fd,
-                          const struct sockaddr *addr,
-                          socklen_t addr_len);
+PFS_socket *create_socket(PFS_socket_class *klass, const my_socket *fd,
+                          const struct sockaddr *addr, socklen_t addr_len);
 void destroy_socket(PFS_socket *pfs);
 
-PFS_metadata_lock* create_metadata_lock(void *identity,
-                                        const MDL_key *mdl_key,
+PFS_metadata_lock *create_metadata_lock(void *identity, const MDL_key *mdl_key,
                                         opaque_mdl_type mdl_type,
                                         opaque_mdl_duration mdl_duration,
                                         opaque_mdl_status mdl_status,
-                                        const char *src_file,
-                                        uint src_line);
+                                        const char *src_file, uint src_line);
 void destroy_metadata_lock(PFS_metadata_lock *pfs);
 
 /* For iterators and show status. */
@@ -611,6 +810,7 @@ extern ulong events_transactions_history_per_thread;
 extern ulong locker_lost;
 extern ulong statement_lost;
 extern ulong session_connect_attrs_lost;
+extern ulong session_connect_attrs_longest_seen;
 extern ulong session_connect_attrs_size_per_thread;
 
 /* Exposing the data directly, for iterators. */
@@ -620,6 +820,7 @@ extern PFS_file **file_handle_array;
 void reset_events_waits_by_instance();
 void reset_file_instance_io();
 void reset_socket_instance_io();
+void reset_histogram_global();
 
 void aggregate_all_event_names(PFS_single_stat *from_array,
                                PFS_single_stat *to_array);
@@ -627,8 +828,7 @@ void aggregate_all_event_names(PFS_single_stat *from_array,
                                PFS_single_stat *to_array_1,
                                PFS_single_stat *to_array_2);
 
-void aggregate_all_stages(PFS_stage_stat *from_array,
-                          PFS_stage_stat *to_array);
+void aggregate_all_stages(PFS_stage_stat *from_array, PFS_stage_stat *to_array);
 void aggregate_all_stages(PFS_stage_stat *from_array,
                           PFS_stage_stat *to_array_1,
                           PFS_stage_stat *to_array_2);
@@ -645,44 +845,48 @@ void aggregate_all_transactions(PFS_transaction_stat *from_array,
                                 PFS_transaction_stat *to_array_1,
                                 PFS_transaction_stat *to_array_2);
 
-void aggregate_all_memory(bool alive,
-                          PFS_memory_stat *from_array,
-                          PFS_memory_stat *to_array);
-void aggregate_all_memory(bool alive,
-                          PFS_memory_stat *from_array,
-                          PFS_memory_stat *to_array_1,
-                          PFS_memory_stat *to_array_2);
+void aggregate_all_errors(PFS_error_stat *from_array, PFS_error_stat *to_array);
+void aggregate_all_errors(PFS_error_stat *from_array,
+                          PFS_error_stat *to_array_1,
+                          PFS_error_stat *to_array_2);
 
-void aggregate_thread(PFS_thread *thread,
-                      PFS_account *safe_account,
-                      PFS_user *safe_user,
-                      PFS_host *safe_host);
-void aggregate_thread_waits(PFS_thread *thread,
-                            PFS_account *safe_account,
-                            PFS_user *safe_user,
-                            PFS_host *safe_host);
-void aggregate_thread_stages(PFS_thread *thread,
-                             PFS_account *safe_account,
-                             PFS_user *safe_user,
-                             PFS_host *safe_host);
-void aggregate_thread_statements(PFS_thread *thread,
-                                 PFS_account *safe_account,
-                                 PFS_user *safe_user,
-                                 PFS_host *safe_host);
+void aggregate_all_memory_with_reassign(bool alive,
+                                        PFS_memory_safe_stat *from_array,
+                                        PFS_memory_shared_stat *to_array,
+                                        PFS_memory_shared_stat *global_array);
+void aggregate_all_memory_with_reassign(bool alive,
+                                        PFS_memory_safe_stat *from_array,
+                                        PFS_memory_shared_stat *to_array_1,
+                                        PFS_memory_shared_stat *to_array_2,
+                                        PFS_memory_shared_stat *global_array);
+
+void aggregate_all_memory(bool alive, PFS_memory_safe_stat *from_array,
+                          PFS_memory_shared_stat *to_array);
+void aggregate_all_memory(bool alive, PFS_memory_shared_stat *from_array,
+                          PFS_memory_shared_stat *to_array);
+void aggregate_all_memory(bool alive, PFS_memory_shared_stat *from_array,
+                          PFS_memory_shared_stat *to_array_1,
+                          PFS_memory_shared_stat *to_array_2);
+
+void aggregate_thread(PFS_thread *thread, PFS_account *safe_account,
+                      PFS_user *safe_user, PFS_host *safe_host);
+void aggregate_thread_waits(PFS_thread *thread, PFS_account *safe_account,
+                            PFS_user *safe_user, PFS_host *safe_host);
+void aggregate_thread_stages(PFS_thread *thread, PFS_account *safe_account,
+                             PFS_user *safe_user, PFS_host *safe_host);
+void aggregate_thread_statements(PFS_thread *thread, PFS_account *safe_account,
+                                 PFS_user *safe_user, PFS_host *safe_host);
 void aggregate_thread_transactions(PFS_thread *thread,
                                    PFS_account *safe_account,
-                                   PFS_user *safe_user,
-                                   PFS_host *safe_host);
-
+                                   PFS_user *safe_user, PFS_host *safe_host);
+void aggregate_thread_errors(PFS_thread *thread, PFS_account *safe_account,
+                             PFS_user *safe_user, PFS_host *safe_host);
 void aggregate_thread_memory(bool alive, PFS_thread *thread,
-                             PFS_account *safe_account,
-                             PFS_user *safe_user,
+                             PFS_account *safe_account, PFS_user *safe_user,
                              PFS_host *safe_host);
 
-void aggregate_thread_status(PFS_thread *thread,
-                             PFS_account *safe_account,
-                             PFS_user *safe_user,
-                             PFS_host *safe_host);
+void aggregate_thread_status(PFS_thread *thread, PFS_account *safe_account,
+                             PFS_user *safe_user, PFS_host *safe_host);
 
 void clear_thread_account(PFS_thread *thread);
 void set_thread_account(PFS_thread *thread);
@@ -706,8 +910,11 @@ void update_thread_derived_flags();
 /** Update derived flags for all instruments. */
 void update_instruments_derived_flags();
 
+/** Clear source file pointers for all statements, stages, waits and
+ * transactions. */
+void reset_source_file_pointers();
+
 extern LF_HASH filename_hash;
 
 /** @} */
 #endif
-
