@@ -1,16 +1,15 @@
-/* Copyright (c) 2008, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2008, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
+  This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
+  separately licensed software that they have included with MySQL.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -48,6 +47,7 @@
 #include "storage/perfschema/pfs_stat.h"
 #include "storage/perfschema/pfs_timer.h"
 
+struct CHARSET_INFO;
 struct PFS_host;
 struct PFS_user;
 struct PFS_account;
@@ -1470,6 +1470,24 @@ class PFS_key_event_name : public PFS_key_string<PFS_MAX_INFO_NAME_LENGTH> {
   bool match_view(uint view);
 };
 
+class PFS_key_meter_name : public PFS_key_string<PFS_MAX_INFO_NAME_LENGTH> {
+ public:
+  explicit PFS_key_meter_name(const char *name) : PFS_key_string(name) {}
+
+  ~PFS_key_meter_name() override = default;
+
+  bool match(PFS_meter_class *pfs);
+};
+
+class PFS_key_metric_name : public PFS_key_string<PFS_MAX_INFO_NAME_LENGTH> {
+ public:
+  explicit PFS_key_metric_name(const char *name) : PFS_key_string(name) {}
+
+  ~PFS_key_metric_name() override = default;
+
+  bool match(PFS_metric_class *pfs);
+};
+
 class PFS_key_user : public PFS_key_string<USERNAME_LENGTH> {
  public:
   explicit PFS_key_user(const char *name) : PFS_key_string(name) {}
