@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2002, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -27,15 +27,16 @@
 #include <algorithm>
 
 #include "errmsg.h"
-#include "m_ctype.h"
-#include "m_string.h"
 #include "my_alloc.h"
 #include "my_default.h"
 #include "my_getopt.h"
 #include "my_sys.h"
 #include "mysql/service_mysql_alloc.h"
+#include "mysql/strings/m_ctype.h"
+#include "nulls.h"
 #include "print_version.h"
 #include "sql_common.h"
+#include "strxmov.h"
 #include "welcome_copyright_notice.h" /* ORACLE_WELCOME_COPYRIGHT_NOTICE */
 
 #define MAX_TEST_QUERY_LENGTH 300 /* MAX QUERY BUFFER LENGTH */
@@ -49,7 +50,7 @@ static char *opt_password = nullptr;
 static char *opt_host = nullptr;
 static char *opt_unix_socket = nullptr;
 #if defined(_WIN32)
-static char *shared_memory_base_name = 0;
+static char *shared_memory_base_name = nullptr;
 #endif
 static unsigned int opt_port;
 static bool tty_password = false;
@@ -109,11 +110,10 @@ static void print_error(MYSQL *l_mysql, const char *msg);
 static void print_st_error(MYSQL_STMT *stmt, const char *msg);
 static void client_disconnect(MYSQL *mysql);
 static void get_options(int *argc, char ***argv);
-static void die(const char *file, int line, const char *expr)
-    MY_ATTRIBUTE((noreturn));
+[[noreturn]] static void die(const char *file, int line, const char *expr);
 
 /*
-Abort unless given experssion is non-zero.
+Abort unless given expression is non-zero.
 
 SYNOPSIS
 DIE_UNLESS(expr)
@@ -141,14 +141,14 @@ static void die(const char *file, int line, const char *expr) {
 
 #define myquery(RES)      \
   {                       \
-    int r = (RES);        \
+    const int r = (RES);  \
     if (r) myerror(NULL); \
     DIE_UNLESS(r == 0);   \
   }
 
 #define myquery2(L_MYSQL, RES)      \
   {                                 \
-    int r = (RES);                  \
+    const int r = (RES);            \
     if (r) myerror2(L_MYSQL, NULL); \
     DIE_UNLESS(r == 0);             \
   }
@@ -171,16 +171,16 @@ static void die(const char *file, int line, const char *expr) {
     DIE_UNLESS(r != 0);           \
   }
 
-#define check_stmt(stmt)          \
-  {                               \
-    if (stmt == 0) myerror(NULL); \
-    DIE_UNLESS(stmt != 0);        \
+#define check_stmt(stmt)                   \
+  {                                        \
+    if (stmt == nullptr) myerror(nullptr); \
+    DIE_UNLESS(stmt != nullptr);           \
   }
 
-#define check_stmt_r(stmt)        \
-  {                               \
-    if (stmt == 0) myerror(NULL); \
-    DIE_UNLESS(stmt == 0);        \
+#define check_stmt_r(stmt)                 \
+  {                                        \
+    if (stmt == nullptr) myerror(nullptr); \
+    DIE_UNLESS(stmt == nullptr);           \
   }
 
 #define mytest(x)      \
@@ -194,25 +194,28 @@ static void die(const char *file, int line, const char *expr) {
     DIE_UNLESS(false); \
   }
 
+#define mytest2(lmysql, x)  \
+  if (!(x)) {               \
+    myerror2(lmysql, NULL); \
+    DIE_UNLESS(false);      \
+  }
+
 /* Silence unused function warnings for some of the static functions. */
-static int cmp_double(double *a, double *b) MY_ATTRIBUTE((unused));
-static void verify_col_data(const char *table, const char *col,
-                            const char *exp_data) MY_ATTRIBUTE((unused));
-static void do_verify_prepare_field(MYSQL_RES *result, unsigned int no,
-                                    const char *name, const char *org_name,
-                                    enum enum_field_types type,
-                                    const char *table, const char *org_table,
-                                    const char *db, unsigned long length,
-                                    const char *def, const char *file, int line)
-    MY_ATTRIBUTE((unused));
-static void verify_st_affected_rows(MYSQL_STMT *stmt, ulonglong exp_count)
-    MY_ATTRIBUTE((unused));
-static void verify_affected_rows(ulonglong exp_count) MY_ATTRIBUTE((unused));
-static void verify_field_count(MYSQL_RES *result, uint exp_count)
-    MY_ATTRIBUTE((unused));
-static void execute_prepare_query(const char *query, ulonglong exp_count)
-    MY_ATTRIBUTE((unused));
-static bool thread_query(const char *query) MY_ATTRIBUTE((unused));
+[[maybe_unused]] static int cmp_double(double *a, double *b);
+[[maybe_unused]] static void verify_col_data(const char *table, const char *col,
+                                             const char *exp_data);
+[[maybe_unused]] static void do_verify_prepare_field(
+    MYSQL_RES *result, unsigned int no, const char *name, const char *org_name,
+    enum enum_field_types type, const char *table, const char *org_table,
+    const char *db, unsigned long length, const char *file, int line);
+[[maybe_unused]] static void verify_st_affected_rows(MYSQL_STMT *stmt,
+                                                     ulonglong exp_count);
+[[maybe_unused]] static void verify_affected_rows(ulonglong exp_count);
+[[maybe_unused]] static void verify_field_count(MYSQL_RES *result,
+                                                uint exp_count);
+[[maybe_unused]] static void execute_prepare_query(const char *query,
+                                                   ulonglong exp_count);
+[[maybe_unused]] static bool thread_query(const char *query);
 
 /* A workaround for Sun Forte 5.6 on Solaris x86 */
 
@@ -685,18 +688,16 @@ static void verify_col_data(const char *table, const char *col,
 /* Utility function to verify the field members */
 
 #define verify_prepare_field(result, no, name, org_name, type, table,          \
-                             org_table, db, length, def)                       \
+                             org_table, db, length)                            \
   do_verify_prepare_field((result), (no), (name), (org_name), (type), (table), \
-                          (org_table), (db), (length), (def), __FILE__,        \
-                          __LINE__)
+                          (org_table), (db), (length), __FILE__, __LINE__)
 
 static void do_verify_prepare_field(MYSQL_RES *result, unsigned int no,
                                     const char *name, const char *org_name,
                                     enum enum_field_types type,
                                     const char *table, const char *org_table,
                                     const char *db, unsigned long length,
-                                    const char *def, const char *file,
-                                    int line) {
+                                    const char *file, int line) {
   MYSQL_FIELD *field;
   CHARSET_INFO *cs;
   ulonglong expected_field_length;
@@ -728,8 +729,6 @@ static void do_verify_prepare_field(MYSQL_RES *result, unsigned int no,
             expected_field_length);
     fprintf(stdout, "\n    maxlength:`%ld`", field->max_length);
     fprintf(stdout, "\n    charsetnr:`%d`", field->charsetnr);
-    fprintf(stdout, "\n    default  :`%s`\t(expected: `%s`)",
-            field->def ? field->def : "(null)", def ? def : "(null)");
     fprintf(stdout, "\n");
   }
   DIE_UNLESS(strcmp(field->name, name) == 0);
@@ -754,7 +753,7 @@ static void do_verify_prepare_field(MYSQL_RES *result, unsigned int no,
   DIE_UNLESS(strcmp(field->db, db) == 0);
   /*
   Character set should be taken into account for multibyte encodings, such
-  as utf8. Field length is calculated as number of characters * maximum
+  as utf8mb4. Field length is calculated as number of characters * maximum
   number of bytes a character can occupy.
   */
   if (length && (field->length != expected_field_length)) {
@@ -762,7 +761,6 @@ static void do_verify_prepare_field(MYSQL_RES *result, unsigned int no,
             expected_field_length, field->length);
     DIE_UNLESS(field->length == expected_field_length);
   }
-  if (def) DIE_UNLESS(strcmp(field->def, def) == 0);
 }
 
 /* Utility function to verify the parameter count */
@@ -971,8 +969,7 @@ bool fetch_n(const char **query_list, unsigned query_count,
              enum fetch_type fetch_type) {
   unsigned open_statements = query_count;
   int rc, error_count = 0;
-  Stmt_fetch *fetch_array =
-      (Stmt_fetch *)calloc(1, sizeof(Stmt_fetch) * query_count);
+  auto *fetch_array = (Stmt_fetch *)calloc(1, sizeof(Stmt_fetch) * query_count);
   Stmt_fetch *fetch;
   DBUG_TRACE;
 
@@ -1091,8 +1088,8 @@ static struct my_option client_test_long_options[] = {
      NO_ARG, 0, 0, 0, nullptr, 0, nullptr},
 #if defined(_WIN32)
     {"shared-memory-base-name", 'm', "Base name of shared memory.",
-     &shared_memory_base_name, (uchar **)&shared_memory_base_name, 0, GET_STR,
-     REQUIRED_ARG, 0, 0, 0, 0, 0, 0},
+     &shared_memory_base_name, (uchar **)&shared_memory_base_name, nullptr,
+     GET_STR, REQUIRED_ARG, 0, 0, 0, nullptr, 0, nullptr},
 #endif
     {"socket", 'S', "Socket file to use for connection", &opt_unix_socket,
      &opt_unix_socket, nullptr, GET_STR, REQUIRED_ARG, 0, 0, 0, nullptr, 0,
@@ -1116,7 +1113,7 @@ static struct my_option client_test_long_options[] = {
     {nullptr, 0, nullptr, nullptr, nullptr, nullptr, GET_NO_ARG, NO_ARG, 0, 0,
      0, nullptr, 0, nullptr}};
 
-static void usage(void) {
+static void usage() {
   /* show the usage string when the user asks for this */
   print_version();
   puts(ORACLE_WELCOME_COPYRIGHT_NOTICE("2002"));
@@ -1131,7 +1128,7 @@ static struct my_tests_st *get_my_tests(); /* To be defined in main .c file */
 static struct my_tests_st *my_testlist = nullptr;
 
 static bool get_one_option(int optid,
-                           const struct my_option *opt MY_ATTRIBUTE((unused)),
+                           const struct my_option *opt [[maybe_unused]],
                            char *argument) {
   switch (optid) {
     case '#':
@@ -1187,7 +1184,6 @@ static void get_options(int *argc, char ***argv) {
     exit(ho_error);
 
   if (tty_password) opt_password = get_tty_password(NullS);
-  return;
 }
 
 /*
