@@ -1,4 +1,4 @@
-/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -54,12 +54,9 @@ class mock_gcs_xcom_view_change_control_interface
   MOCK_METHOD1(set_belongs_to_group, void(bool));
   MOCK_METHOD1(set_unsafe_current_view, void(Gcs_view *));
   MOCK_METHOD0(get_unsafe_current_view, Gcs_view *());
-};
 
-class mock_gcs_xcom_statistics_updater : public Gcs_xcom_statistics_updater {
- public:
-  MOCK_METHOD1(update_message_sent, void(unsigned long long message_length));
-  MOCK_METHOD1(update_message_received, void(long message_length));
+  MOCK_METHOD0(finalize, void());
+  MOCK_METHOD0(is_finalized, bool());
 };
 
 class mock_gcs_communication_event_listener
@@ -78,7 +75,8 @@ class mock_gcs_xcom_proxy : public Gcs_xcom_proxy_base {
   }
 
   MOCK_METHOD3(new_node_address_uuid,
-               node_address *(unsigned int n, char *names[], blob uuids[]));
+               node_address *(unsigned int n, char const *names[],
+                              blob uuids[]));
   MOCK_METHOD2(delete_node_address, void(unsigned int n, node_address *na));
   MOCK_METHOD3(xcom_client_add_node, bool(connection_descriptor *con,
                                           node_list *nl, uint32_t group_id));
@@ -89,6 +87,13 @@ class mock_gcs_xcom_proxy : public Gcs_xcom_proxy_base {
                bool(uint32_t group_id, xcom_event_horizon &event_horizon));
   MOCK_METHOD2(xcom_client_set_event_horizon,
                bool(uint32_t group_id, xcom_event_horizon event_horizon));
+  MOCK_METHOD2(xcom_client_set_max_leaders,
+               bool(uint32_t group_id, node_no max_leaders));
+  MOCK_METHOD4(xcom_client_set_leaders,
+               bool(uint32_t group_id, u_int n, char const *names[],
+                    node_no max_nr_leaders));
+  MOCK_METHOD2(xcom_client_get_leaders,
+               bool(uint32_t gid, leader_info_data &leaders));
   MOCK_METHOD4(xcom_client_get_synode_app_data,
                bool(connection_descriptor *con, uint32_t group_id_hash,
                     synode_no_array &synodes, synode_app_data_array &reply));
@@ -149,6 +154,62 @@ class mock_gcs_xcom_proxy : public Gcs_xcom_proxy_base {
   MOCK_METHOD0(xcom_input_try_pop, xcom_input_request_ptr());
 };
 
+class mock_gcs_network_provider_management_interface
+    : public Network_provider_management_interface {
+ public:
+  MOCK_METHOD0(initialize, bool());
+  MOCK_METHOD0(finalize, bool());
+  MOCK_METHOD1(set_running_protocol, void(enum_transport_protocol new_value));
+  MOCK_METHOD1(add_network_provider,
+               void(std::shared_ptr<Network_provider> provider));
+  MOCK_CONST_METHOD0(get_running_protocol, enum_transport_protocol());
+  MOCK_CONST_METHOD0(get_incoming_connections_protocol,
+                     enum_transport_protocol());
+  MOCK_CONST_METHOD0(is_xcom_using_ssl, int());
+  MOCK_METHOD1(xcom_set_ssl_mode, int(int mode));
+  MOCK_METHOD1(xcom_get_ssl_mode, int(const char *mode));
+  MOCK_METHOD0(xcom_get_ssl_mode, int());
+  MOCK_METHOD1(xcom_set_ssl_fips_mode, int(int mode));
+  MOCK_METHOD1(xcom_get_ssl_fips_mode, int(const char *mode));
+  MOCK_METHOD0(xcom_get_ssl_fips_mode, int());
+  MOCK_METHOD0(cleanup_secure_connections_context, void());
+  MOCK_METHOD0(delayed_cleanup_secure_connections_context, void());
+  MOCK_METHOD0(finalize_secure_connections_context, void());
+  MOCK_METHOD0(remove_all_network_provider, void());
+  MOCK_METHOD1(remove_network_provider, void(enum_transport_protocol));
+};
+
+class Mock_gcs_xcom_statistics_manager
+    : public Gcs_xcom_statistics_manager_interface {
+  MOCK_METHOD(uint64_t, get_sum_var_value,
+              (Gcs_cumulative_statistics_enum to_get), (const, override));
+  MOCK_METHOD(void, set_sum_var_value,
+              (Gcs_cumulative_statistics_enum to_set, uint64_t to_add),
+              (override));
+
+  // COUNT VARS
+  MOCK_METHOD(uint64_t, get_count_var_value,
+              (Gcs_counter_statistics_enum to_get), (const, override));
+  MOCK_METHOD(void, set_count_var_value, (Gcs_counter_statistics_enum to_set),
+              (override));
+
+  // TIMESTAMP VALUES
+  MOCK_METHOD(unsigned long long, get_timestamp_var_value,
+              (Gcs_time_statistics_enum to_get), (const, override));
+  MOCK_METHOD(void, set_timestamp_var_value,
+              (Gcs_time_statistics_enum to_set, unsigned long long new_value),
+              (override));
+  MOCK_METHOD(void, set_sum_timestamp_var_value,
+              (Gcs_time_statistics_enum to_set, unsigned long long to_add),
+              (override));
+
+  // ALL OTHER VARS
+  MOCK_METHOD(std::vector<Gcs_node_suspicious>, get_all_suspicious, (),
+              (const, override));
+  MOCK_METHOD(void, add_suspicious_for_a_node, (std::string node_id),
+              (override));
+};
+
 class XComCommunicationTest : public GcsBaseTest {
  protected:
   void SetUp() override {
@@ -161,21 +222,28 @@ class XComCommunicationTest : public GcsBaseTest {
     mock_xcom_address = new Gcs_xcom_node_address("127.0.0.1:12345");
     static_cast<Gcs_xcom_interface *>(Gcs_xcom_interface::get_interface())
         ->set_node_address(mock_xcom_address->get_member_address());
-    mock_stats = new mock_gcs_xcom_statistics_updater();
+    mock_stats = new Mock_gcs_xcom_statistics_manager();
     mock_proxy = new mock_gcs_xcom_proxy();
     mock_vce = new mock_gcs_xcom_view_change_control_interface();
-    xcom_comm_if = new Gcs_xcom_communication(mock_stats, mock_proxy, mock_vce,
-                                              engine, *mock_gid);
+    net_mgr_interface =
+        std::make_unique<mock_gcs_network_provider_management_interface>();
+    xcom_comm_if =
+        new Gcs_xcom_communication(mock_stats, mock_proxy, mock_vce, engine,
+                                   *mock_gid, std::move(net_mgr_interface));
 
     // clang-format off
     xcom_comm_if->get_msg_pipeline().register_stage<Gcs_message_stage_lz4>();
     xcom_comm_if->get_msg_pipeline().register_stage<Gcs_message_stage_lz4_v2>();
+    xcom_comm_if->get_msg_pipeline().register_stage<Gcs_message_stage_lz4_v3>();
     xcom_comm_if->get_msg_pipeline().register_pipeline({
       {
         Gcs_protocol_version::V1, { Stage_code::ST_LZ4_V1 }
       },
       {
         Gcs_protocol_version::V2, { Stage_code::ST_LZ4_V2 }
+      },
+      {
+        Gcs_protocol_version::V3, { Stage_code::ST_LZ4_V3 }
       }
     });
     // clang-format on
@@ -193,12 +261,14 @@ class XComCommunicationTest : public GcsBaseTest {
   }
 
   Gcs_xcom_communication *xcom_comm_if;
-  mock_gcs_xcom_statistics_updater *mock_stats;
+  Mock_gcs_xcom_statistics_manager *mock_stats;
   mock_gcs_xcom_proxy *mock_proxy;
   mock_gcs_xcom_view_change_control_interface *mock_vce;
   Gcs_xcom_node_address *mock_xcom_address;
   Gcs_xcom_engine *engine;
   Gcs_group_identifier *mock_gid;
+  std::unique_ptr<mock_gcs_network_provider_management_interface>
+      net_mgr_interface;
 };
 
 TEST_F(XComCommunicationTest, SetEventListenerTest) {
@@ -260,7 +330,6 @@ TEST_F(XComCommunicationTest, SendMessageTest) {
   EXPECT_CALL(*mock_proxy, xcom_client_send_data(_, _))
       .Times(1)
       .WillOnce(Invoke(&mock_xcom_client_send_data));
-  EXPECT_CALL(*mock_stats, update_message_sent(_)).Times(1);
   EXPECT_CALL(*mock_vce, belongs_to_group()).Times(1).WillOnce(Return(true));
 
   std::string test_header("header");
@@ -287,7 +356,6 @@ TEST_F(XComCommunicationTest, ReceiveMessageTest) {
 
   // Test Expectations
   EXPECT_CALL(ev_listener, on_message_received(_)).Times(1);
-  EXPECT_CALL(*mock_stats, update_message_received(_)).Times(1);
 
   // Test
   std::string test_header("header");
@@ -326,7 +394,6 @@ TEST_F(XComCommunicationTest, ReceiveMessageTest) {
   EXPECT_CALL(*mock_proxy, xcom_client_send_data(_, _))
       .Times(1)
       .WillOnce(Invoke(&mock_xcom_client_send_data));
-  EXPECT_CALL(*mock_stats, update_message_sent(_)).Times(1);
   enum_gcs_error message_result = xcom_comm_if->send_message(
       Gcs_message(member_id, group_id, new Gcs_message_data(0, 0)));
   ASSERT_EQ(GCS_OK, message_result);
@@ -337,7 +404,7 @@ TEST_F(XComCommunicationTest, ReceiveMessageTest) {
   packet_synode.msgno = 0;
   packet_synode.node = 0;
   auto packet = Gcs_packet::make_incoming_packet(
-      std::move(buffer), buffer_len, packet_synode,
+      std::move(buffer), buffer_len, packet_synode, packet_synode,
       xcom_comm_if->get_msg_pipeline());
 
   int listener_ref = xcom_comm_if->add_event_listener(ev_listener);
@@ -358,8 +425,6 @@ TEST_F(XComCommunicationTest, BufferMessageTest) {
   // Test Expectations
   EXPECT_CALL(ev_listener, on_message_received(_)).Times(1);
 
-  EXPECT_CALL(*mock_stats, update_message_received(_)).Times(1);
-
   // Set up the environment.
   std::string test_header("header");
   std::string test_payload("payload");
@@ -398,7 +463,6 @@ TEST_F(XComCommunicationTest, BufferMessageTest) {
   EXPECT_CALL(*mock_proxy, xcom_client_send_data(_, _))
       .Times(1)
       .WillOnce(Invoke(&mock_xcom_client_send_data));
-  EXPECT_CALL(*mock_stats, update_message_sent(_)).Times(1);
   enum_gcs_error message_result = xcom_comm_if->send_message(
       Gcs_message(member_id, group_id, new Gcs_message_data(0, 0)));
   ASSERT_EQ(GCS_OK, message_result);
@@ -409,7 +473,7 @@ TEST_F(XComCommunicationTest, BufferMessageTest) {
   packet_synode.msgno = 0;
   packet_synode.node = 0;
   auto packet = Gcs_packet::make_incoming_packet(
-      std::move(buffer), buffer_len, packet_synode,
+      std::move(buffer), buffer_len, packet_synode, packet_synode,
       xcom_comm_if->get_msg_pipeline());
 
   /*
@@ -580,7 +644,7 @@ TEST_F(XComCommunicationTest, SuccessfulSynodRecoveryTest) {
     std::tie(buffer, buffer_len) = packet_out.serialize();
     synode_no const &packet_synode = synodes_in_order.at(i);
     auto packet = Gcs_packet::make_incoming_packet(
-        std::move(buffer), buffer_len, packet_synode, pipeline);
+        std::move(buffer), buffer_len, packet_synode, packet_synode, pipeline);
 
     /* Reassemble the packets. */
     Gcs_pipeline_incoming_result error_code;
