@@ -1,4 +1,4 @@
-/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -37,6 +37,8 @@
 
 using std::string;
 
+using ::testing::NiceMock;
+
 namespace gcs_xcom_control_unittest {
 typedef enum { JJ = 0, LL = 1, JL = 2, LJ = 3 } InvocationOrder;
 
@@ -150,6 +152,9 @@ class mock_gcs_xcom_view_change_control_interface
   MOCK_METHOD0(wait_for_view_change_end, void());
   MOCK_METHOD0(is_view_changing, bool());
 
+  MOCK_METHOD0(finalize, void());
+  MOCK_METHOD0(is_finalized, bool());
+
   bool start_leave() override {
     bool retval = false;
 
@@ -242,7 +247,9 @@ class mock_gcs_xcom_state_exchange_interface
  private:
   int m_process_member_state_iteration;
 
-  bool free_xcom_member_state(Xcom_member_state *m) {
+  bool free_xcom_member_state(Xcom_member_state *m,
+                              const Gcs_member_identifier &,
+                              Gcs_protocol_version, Gcs_protocol_version) {
     delete m;
     if (m_process_member_state_iteration == 0) {
       m_process_member_state_iteration++;
@@ -251,8 +258,14 @@ class mock_gcs_xcom_state_exchange_interface
       return true;
   }
 
-  bool free_members_joined(std::vector<Gcs_member_identifier *> &total,
-                           std::vector<Gcs_member_identifier *> &joined) {
+  bool free_members_joined(synode_no,
+                           std::vector<Gcs_member_identifier *> &total,
+                           std::vector<Gcs_member_identifier *> &,
+                           std::vector<Gcs_member_identifier *> &joined,
+                           std::vector<std::unique_ptr<Gcs_message_data>> &,
+                           Gcs_view *, std::string *,
+                           const Gcs_member_identifier &,
+                           const Gcs_xcom_nodes &) {
     std::vector<Gcs_member_identifier *>::iterator it;
 
     for (it = total.begin(); it != total.end(); it++) delete (*it);
@@ -268,14 +281,14 @@ class mock_gcs_xcom_state_exchange_interface
   mock_gcs_xcom_state_exchange_interface()
       : m_process_member_state_iteration(0) {
     ON_CALL(*this, process_member_state(_, _, _, _))
-        .WillByDefault(WithArgs<0>(Invoke(
+        .WillByDefault(Invoke(
             this,
-            &mock_gcs_xcom_state_exchange_interface::free_xcom_member_state)));
+            &mock_gcs_xcom_state_exchange_interface::free_xcom_member_state));
 
     ON_CALL(*this, state_exchange(_, _, _, _, _, _, _, _, _))
-        .WillByDefault(WithArgs<1, 3>(Invoke(
+        .WillByDefault(Invoke(
             this,
-            &mock_gcs_xcom_state_exchange_interface::free_members_joined)));
+            &mock_gcs_xcom_state_exchange_interface::free_members_joined));
     ON_CALL(*this, compute_incompatible_members())
         .WillByDefault(Return(std::vector<Gcs_xcom_node_information>()));
     ON_CALL(*this, process_recovery_state()).WillByDefault(Return(true));
@@ -327,9 +340,9 @@ class mock_gcs_xcom_proxy : public Gcs_xcom_proxy_base {
     ON_CALL(*this, xcom_client_add_node(_, _, _)).WillByDefault(Return(false));
     ON_CALL(*this, xcom_client_send_data(_, _)).WillByDefault(Return(10));
     ON_CALL(*this, new_node_address_uuid(_, _, _))
-        .WillByDefault(WithArgs<0, 1, 2>(Invoke(::new_node_address_uuid)));
+        .WillByDefault(Invoke(::new_node_address_uuid));
     ON_CALL(*this, delete_node_address(_, _))
-        .WillByDefault(WithArgs<0, 1>(Invoke(::delete_node_address)));
+        .WillByDefault(Invoke(::delete_node_address));
     ON_CALL(*this, xcom_wait_ready()).WillByDefault(Return(GCS_OK));
     ON_CALL(*this, xcom_wait_for_xcom_comms_status_change(_))
         .WillByDefault(SetArgReferee<0>(XCOM_COMMS_OK));
@@ -338,7 +351,8 @@ class mock_gcs_xcom_proxy : public Gcs_xcom_proxy_base {
   }
 
   MOCK_METHOD3(new_node_address_uuid,
-               node_address *(unsigned int n, char *names[], blob uuids[]));
+               node_address *(unsigned int n, char const *names[],
+                              blob uuids[]));
   MOCK_METHOD2(delete_node_address, void(unsigned int n, node_address *na));
   MOCK_METHOD3(xcom_client_add_node, bool(connection_descriptor *con,
                                           node_list *nl, uint32_t group_id));
@@ -352,6 +366,13 @@ class mock_gcs_xcom_proxy : public Gcs_xcom_proxy_base {
                     xcom_event_horizon event_horizon));
   MOCK_METHOD2(xcom_client_set_event_horizon,
                bool(uint32_t group_id, xcom_event_horizon event_horizon));
+  MOCK_METHOD2(xcom_client_set_max_leaders,
+               bool(uint32_t group_id, node_no max_leaders));
+  MOCK_METHOD4(xcom_client_set_leaders,
+               bool(uint32_t group_id, u_int n, char const *names[],
+                    node_no max_nr_leaders));
+  MOCK_METHOD2(xcom_client_get_leaders,
+               bool(uint32_t gid, leader_info_data &leaders));
   MOCK_METHOD4(xcom_client_get_synode_app_data,
                bool(connection_descriptor *con, uint32_t group_id,
                     synode_no_array &synodes, synode_app_data_array &reply));
@@ -434,20 +455,80 @@ class mock_my_xp_socket_util : public My_xp_socket_util {
   MOCK_METHOD1(disable_nagle_in_socket, int(int fd));
 };
 
+class mock_gcs_network_provider_operations_interface
+    : public Network_provider_operations_interface {
+ public:
+  mock_gcs_network_provider_operations_interface() {
+    ON_CALL(*this, start_active_network_provider())
+        .WillByDefault(Return(false));
+    ON_CALL(*this, stop_all_network_providers()).WillByDefault(Return(false));
+    ON_CALL(*this, stop_active_network_provider()).WillByDefault(Return(false));
+    ON_CALL(*this, configure_active_provider(_)).WillByDefault(Return(false));
+    ON_CALL(*this, configure_active_provider_secure_connections(_))
+        .WillByDefault(Return(false));
+  }
+
+  MOCK_METHOD0(start_active_network_provider, bool());
+  MOCK_METHOD0(stop_all_network_providers, bool());
+  MOCK_METHOD0(stop_active_network_provider, bool());
+  MOCK_METHOD1(configure_active_provider,
+               bool(Network_configuration_parameters &params));
+  MOCK_METHOD1(configure_active_provider_secure_connections,
+               bool(Network_configuration_parameters &params));
+  MOCK_METHOD0(remove_all_network_provider, void());
+  MOCK_METHOD1(remove_network_provider,
+               void(enum_transport_protocol provider_key));
+};
+
+class Mock_gcs_xcom_statistics_manager
+    : public Gcs_xcom_statistics_manager_interface {
+ public:
+  MOCK_METHOD(uint64_t, get_sum_var_value,
+              (Gcs_cumulative_statistics_enum to_get), (const, override));
+  MOCK_METHOD(void, set_sum_var_value,
+              (Gcs_cumulative_statistics_enum to_set, uint64_t to_add),
+              (override));
+
+  // COUNT VARS
+  MOCK_METHOD(uint64_t, get_count_var_value,
+              (Gcs_counter_statistics_enum to_get), (const, override));
+  MOCK_METHOD(void, set_count_var_value, (Gcs_counter_statistics_enum to_set),
+              (override));
+
+  // TIMESTAMP VALUES
+  MOCK_METHOD(unsigned long long, get_timestamp_var_value,
+              (Gcs_time_statistics_enum to_get), (const, override));
+  MOCK_METHOD(void, set_timestamp_var_value,
+              (Gcs_time_statistics_enum to_set, unsigned long long new_value),
+              (override));
+  MOCK_METHOD(void, set_sum_timestamp_var_value,
+              (Gcs_time_statistics_enum to_set, unsigned long long to_add),
+              (override));
+
+  // ALL OTHER VARS
+  MOCK_METHOD(std::vector<Gcs_node_suspicious>, get_all_suspicious, (),
+              (const, override));
+  MOCK_METHOD(void, add_suspicious_for_a_node, (std::string node_id),
+              (override));
+};
+
 class mock_gcs_xcom_control : public Gcs_xcom_control {
  public:
-  mock_gcs_xcom_control(Gcs_xcom_node_address *xcom_node_address,
-                        std::vector<Gcs_xcom_node_address *> &xcom_peers,
-                        Gcs_group_identifier group_identifier,
-                        Gcs_xcom_proxy *xcom_proxy,
-                        Gcs_xcom_group_management *xcom_group_management,
-                        Gcs_xcom_engine *gcs_engine,
-                        Gcs_xcom_state_exchange_interface *state_exchange,
-                        Gcs_xcom_view_change_control_interface *view_control,
-                        bool boot, My_xp_socket_util *socket_util)
+  mock_gcs_xcom_control(
+      Gcs_xcom_node_address *xcom_node_address,
+      std::vector<Gcs_xcom_node_address *> &xcom_peers,
+      Gcs_group_identifier group_identifier, Gcs_xcom_proxy *xcom_proxy,
+      Gcs_xcom_group_management *xcom_group_management,
+      Gcs_xcom_engine *gcs_engine,
+      Gcs_xcom_state_exchange_interface *state_exchange,
+      Gcs_xcom_view_change_control_interface *view_control, bool boot,
+      My_xp_socket_util *socket_util,
+      std::unique_ptr<Network_provider_operations_interface> network_ops,
+      Gcs_xcom_statistics_manager_interface *stats_mgr)
       : Gcs_xcom_control(xcom_node_address, xcom_peers, group_identifier,
                          xcom_proxy, xcom_group_management, gcs_engine,
-                         state_exchange, view_control, boot, socket_util) {}
+                         state_exchange, view_control, boot, socket_util,
+                         std::move(network_ops), stats_mgr) {}
 
   enum_gcs_error join() override { return join(nullptr); }
 
@@ -509,18 +590,18 @@ void finalize_xcom() { extern_xcom_control_if->do_leave(); }
 
 class XComControlTest : public GcsBaseTest {
  protected:
-  XComControlTest() {}
+  XComControlTest() = default;
 
-  ~XComControlTest() override {}
+  ~XComControlTest() override = default;
 
   void SetUp() override {
     m_wait_called = false;
     m_wait_called_mutex.init(PSI_NOT_INSTRUMENTED, nullptr);
     m_wait_called_cond.init(PSI_NOT_INSTRUMENTED);
 
-    mock_se = new mock_gcs_xcom_state_exchange_interface();
+    mock_se = new NiceMock<mock_gcs_xcom_state_exchange_interface>();
 
-    mock_vce = new mock_gcs_xcom_view_change_control_interface();
+    mock_vce = new NiceMock<mock_gcs_xcom_view_change_control_interface>();
 
     xcom_node_address = new Gcs_xcom_node_address("127.0.0.1:12345");
     peers.push_back(new Gcs_xcom_node_address("127.0.0.1:12345"));
@@ -530,15 +611,22 @@ class XComControlTest : public GcsBaseTest {
     string group_name("only_group");
     group_id = new Gcs_group_identifier(group_name);
 
-    mock_socket_util = new mock_my_xp_socket_util();
+    mock_socket_util = new NiceMock<mock_my_xp_socket_util>();
 
     gcs_engine.initialize(nullptr);
 
-    xcom_group_mgm = new Gcs_xcom_group_management(&proxy, *group_id);
+    xcom_group_mgm = new Gcs_xcom_group_management(&proxy, *group_id, mock_vce);
 
-    xcom_control_if = new mock_gcs_xcom_control(
+    mock_net_ops_for_interface =
+        std::make_unique<mock_gcs_network_provider_operations_interface>();
+    mock_net_ops = mock_net_ops_for_interface.get();
+
+    mock_stats_mgr = new NiceMock<Mock_gcs_xcom_statistics_manager>();
+
+    xcom_control_if = new NiceMock<mock_gcs_xcom_control>(
         xcom_node_address, peers, *group_id, &proxy, xcom_group_mgm,
-        &gcs_engine, mock_se, mock_vce, true, mock_socket_util);
+        &gcs_engine, mock_se, mock_vce, true, mock_socket_util,
+        std::move(mock_net_ops_for_interface), mock_stats_mgr);
     extern_xcom_control_if = xcom_control_if;
   }
 
@@ -558,6 +646,8 @@ class XComControlTest : public GcsBaseTest {
 
     m_wait_called_mutex.destroy();
     m_wait_called_cond.destroy();
+
+    delete mock_stats_mgr;
   }
 
   Gcs_xcom_node_address *xcom_node_address;
@@ -565,13 +655,17 @@ class XComControlTest : public GcsBaseTest {
 
   Gcs_group_identifier *group_id;
 
-  mock_gcs_xcom_proxy proxy;
-  mock_gcs_control_event_listener mock_ev_listener;
+  NiceMock<mock_gcs_xcom_proxy> proxy;
+  NiceMock<mock_gcs_control_event_listener> mock_ev_listener;
 
-  mock_gcs_xcom_control *xcom_control_if;
-  mock_gcs_xcom_state_exchange_interface *mock_se;
-  mock_gcs_xcom_view_change_control_interface *mock_vce;
-  mock_my_xp_socket_util *mock_socket_util;
+  NiceMock<mock_gcs_xcom_control> *xcom_control_if;
+  NiceMock<mock_gcs_xcom_state_exchange_interface> *mock_se;
+  NiceMock<mock_gcs_xcom_view_change_control_interface> *mock_vce;
+  NiceMock<mock_my_xp_socket_util> *mock_socket_util;
+  mock_gcs_network_provider_operations_interface *mock_net_ops;
+  std::unique_ptr<mock_gcs_network_provider_operations_interface>
+      mock_net_ops_for_interface;
+  NiceMock<Mock_gcs_xcom_statistics_manager> *mock_stats_mgr;
 
   bool m_wait_called;
   My_xp_mutex_impl m_wait_called_mutex;
@@ -601,14 +695,18 @@ class XComControlTest : public GcsBaseTest {
   }
 };
 
+/**
+ * @brief This test exercices a basic leave-join scenario.
+ *
+ */
 TEST_F(XComControlTest, JoinLeaveTest) {
   EXPECT_CALL(proxy, xcom_input_connect(_, _)).Times(1);
   EXPECT_CALL(proxy, test_xcom_tcp_connection(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_remove_node(_, _)).Times(1);
-  EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_))
+  /*EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_))
       .Times(1)
-      .WillOnce(SetArgReferee<0>(GCS_OK));
+      .WillOnce(SetArgReferee<0>(GCS_OK));*/
   EXPECT_CALL(proxy, xcom_wait_ready()).Times(1);
   EXPECT_CALL(proxy, xcom_wait_exit()).Times(1);
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
@@ -623,14 +721,16 @@ TEST_F(XComControlTest, JoinLeaveTest) {
   ASSERT_FALSE(xcom_control_if->is_xcom_running());
 }
 
+/**
+ * @brief This test exercises a join() after a successful join()
+ *
+ */
 TEST_F(XComControlTest, JoinTestFailedMultipleJoins) {
   EXPECT_CALL(proxy, xcom_input_connect(_, _)).Times(1);
   EXPECT_CALL(proxy, test_xcom_tcp_connection(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_remove_node(_, _)).Times(1);
-  EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_))
-      .Times(1)
-      .WillOnce(SetArgReferee<0>(GCS_OK));
+
   EXPECT_CALL(proxy, xcom_wait_ready()).Times(1);
   EXPECT_CALL(proxy, xcom_wait_exit()).Times(1);
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
@@ -649,11 +749,14 @@ TEST_F(XComControlTest, JoinTestFailedMultipleJoins) {
   ASSERT_FALSE(xcom_control_if->is_xcom_running());
 }
 
+/**
+ * @brief This test exercises a failed
+ *
+ */
 TEST_F(XComControlTest, JoinTestFailedToStartComms) {
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(0);
   EXPECT_CALL(proxy, xcom_wait_ready()).Times(0);
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
-  EXPECT_CALL(proxy, xcom_exit()).Times(1);
 
   /*
     The join is forced to wait until the XCOM's tread is running.
@@ -702,28 +805,6 @@ TEST_F(XComControlTest, JoinTestFailedToSendBootToXCom) {
   ASSERT_FALSE(xcom_control_if->is_xcom_running());
 }
 
-TEST_F(XComControlTest, JoinTestTimeoutStartingComms) {
-  Gcs_xcom_proxy *my_proxy = new Gcs_xcom_proxy_impl();
-
-  EXPECT_CALL(proxy, xcom_init(_)).Times(1);
-  EXPECT_CALL(proxy, xcom_exit()).Times(1);
-
-  /*
-    The join is forced to wait until the XCOM's tread is running.
-    In this test case though, we make the operation time out.
-  */
-  EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_))
-      .Times(1)
-      .WillOnce(Invoke(
-          my_proxy, &Gcs_xcom_proxy::xcom_wait_for_xcom_comms_status_change));
-
-  enum_gcs_error result = xcom_control_if->join();
-  ASSERT_EQ(GCS_NOK, result);
-  ASSERT_FALSE(xcom_control_if->is_xcom_running());
-
-  delete my_proxy;
-}
-
 TEST_F(XComControlTest, JoinTestFailedToStartXCom) {
   EXPECT_CALL(proxy, xcom_input_connect(_, _)).Times(1);
   EXPECT_CALL(proxy, test_xcom_tcp_connection(_, _)).Times(1);
@@ -731,7 +812,6 @@ TEST_F(XComControlTest, JoinTestFailedToStartXCom) {
   EXPECT_CALL(proxy, xcom_wait_ready()).Times(1).WillOnce(Return(GCS_NOK));
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
   EXPECT_CALL(proxy, xcom_exit()).Times(1);
-  EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_)).Times(1);
 
   enum_gcs_error result = xcom_control_if->join();
 
@@ -749,7 +829,6 @@ TEST_F(XComControlTest, JoinTestTimeoutStartingXCom) {
       .WillOnce(Invoke(my_proxy, &Gcs_xcom_proxy::xcom_wait_ready));
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
   EXPECT_CALL(proxy, xcom_exit()).Times(1);
-  EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_)).Times(1);
 
   enum_gcs_error result = xcom_control_if->join();
 
@@ -781,6 +860,32 @@ TEST_F(XComControlTest, JoinTestSkipOwnNodeAndCycleThroughPeerNodes) {
       (connection_descriptor *)malloc(sizeof(connection_descriptor));
   con->fd = 0;
 
+  /*connection_descriptor *failed_con =
+      (connection_descriptor *)malloc(sizeof(connection_descriptor *));
+  failed_con->fd = -1;*/
+
+  auto create_failed_con_lambda = [](std::string a, xcom_port b) {
+    (void)a;
+    (void)b;
+
+    connection_descriptor *failed_con =
+        (connection_descriptor *)malloc(sizeof(connection_descriptor));
+    failed_con->fd = -1;
+
+    return failed_con;
+  };
+
+  auto create_good_con_lambda = [](std::string a, xcom_port b) {
+    (void)a;
+    (void)b;
+
+    connection_descriptor *failed_con =
+        (connection_descriptor *)malloc(sizeof(connection_descriptor));
+    failed_con->fd = 0;
+
+    return failed_con;
+  };
+
   EXPECT_CALL(proxy, xcom_input_connect(_, _)).Times(1);
   EXPECT_CALL(proxy, test_xcom_tcp_connection(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(0);
@@ -790,7 +895,7 @@ TEST_F(XComControlTest, JoinTestSkipOwnNodeAndCycleThroughPeerNodes) {
   // Fail to connect to the peer every time.
   EXPECT_CALL(proxy, xcom_client_open_connection(Eq("127.0.0.1"), Eq(12346)))
       .Times(3)
-      .WillRepeatedly(Return((connection_descriptor *)nullptr));
+      .WillRepeatedly(create_failed_con_lambda);
 
   /*
    Fail to connect on the first attempt.
@@ -799,8 +904,8 @@ TEST_F(XComControlTest, JoinTestSkipOwnNodeAndCycleThroughPeerNodes) {
   */
   EXPECT_CALL(proxy, xcom_client_open_connection(Eq("127.0.0.1"), Eq(12347)))
       .Times(3)
-      .WillOnce(Return((connection_descriptor *)nullptr))
-      .WillRepeatedly(Return((connection_descriptor *)con));
+      .WillOnce(create_failed_con_lambda)
+      .WillRepeatedly(create_good_con_lambda);
   EXPECT_CALL(*mock_socket_util, disable_nagle_in_socket(_))
       .Times(2)
       .WillOnce(Return(-1))
@@ -822,24 +927,34 @@ TEST_F(XComControlTest, JoinTestSkipOwnNodeAndCycleThroughPeerNodes) {
   result = xcom_control_if->leave();
   ASSERT_EQ(GCS_OK, result);
   ASSERT_FALSE(xcom_control_if->is_xcom_running());
-
-  free(con);
 }
 
 TEST_F(XComControlTest, JoinTestAllPeersUnavailable) {
+  auto create_failed_con_lambda = [](std::string a, xcom_port b) {
+    (void)a;
+    (void)b;
+
+    connection_descriptor *failed_con =
+        (connection_descriptor *)malloc(sizeof(connection_descriptor));
+    failed_con->fd = -1;
+
+    return failed_con;
+  };
+
   EXPECT_CALL(proxy, xcom_input_connect(_, _)).Times(1);
   EXPECT_CALL(proxy, test_xcom_tcp_connection(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(0);
   EXPECT_CALL(proxy, xcom_wait_ready()).Times(0);
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
   EXPECT_CALL(proxy, xcom_exit()).Times(1);
+
   /*
    Fail to connect to all peers every time.
    peers.size() - 1 because we skip our own address.
   */
   EXPECT_CALL(proxy, xcom_client_open_connection(_, _))
       .Times((peers.size() - 1) * Gcs_xcom_control::CONNECTION_ATTEMPTS)
-      .WillRepeatedly(Return((connection_descriptor *)nullptr));
+      .WillRepeatedly(create_failed_con_lambda);
   EXPECT_CALL(*mock_socket_util, disable_nagle_in_socket(_)).Times(0);
   EXPECT_CALL(proxy, xcom_client_add_node(_, _, _)).Times(0);
   EXPECT_CALL(proxy, xcom_client_remove_node(_, _, _)).Times(0);
@@ -1015,9 +1130,14 @@ TEST_F(XComControlTest, ViewChangedJoiningTest) {
   uuid_2.encode(reinterpret_cast<uchar **>(&blob_2.data.data_val),
                 &blob_2.data.data_len);
 
-  node_address node_addrs[2] = {
-      {const_cast<char *>("127.0.0.1:12345"), blob_1, {x_1_0, x_1_2}},
-      {const_cast<char *>("127.0.0.1:12346"), blob_2, {x_1_0, x_1_2}}};
+  node_address node_addrs[2] = {{const_cast<char *>("127.0.0.1:12345"),
+                                 blob_1,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN},
+                                {const_cast<char *>("127.0.0.1:12346"),
+                                 blob_2,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN}};
 
   // Common unit test data
   Gcs_xcom_view_identifier *view_id = new Gcs_xcom_view_identifier(999999, 27);
@@ -1129,7 +1249,6 @@ TEST_F(XComControlTest, ViewChangedJoiningTest) {
 
   const Gcs_xcom_view_identifier &current_view_id =
       down_cast<const Gcs_xcom_view_identifier &>(current_view->get_view_id());
-  ASSERT_TRUE((&current_view_id) != nullptr);
   ASSERT_EQ(typeid(Gcs_xcom_view_identifier).name(),
             typeid(current_view_id).name());
 
@@ -1175,6 +1294,7 @@ TEST_F(XComControlTest, FailedNodeRemovalTest) {
   EXPECT_CALL(proxy, delete_node_address(_, _)).Times(4);
   EXPECT_CALL(mock_ev_listener, on_view_changed(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_remove_node(_, _)).Times(3);
+  EXPECT_CALL(*mock_stats_mgr, add_suspicious_for_a_node(_)).Times(1);
 
   // Get suspicions manager and enable majority
   Gcs_suspicions_manager *mgr = xcom_control_if->get_suspicions_manager();
@@ -1197,10 +1317,18 @@ TEST_F(XComControlTest, FailedNodeRemovalTest) {
   uuid_3.encode(reinterpret_cast<uchar **>(&blob_3.data.data_val),
                 &blob_3.data.data_len);
 
-  node_address node_addrs[3] = {
-      {const_cast<char *>("127.0.0.1:12345"), blob_1, {x_1_0, x_1_2}},
-      {const_cast<char *>("127.0.0.1:12343"), blob_2, {x_1_0, x_1_2}},
-      {const_cast<char *>("127.0.0.1:12341"), blob_3, {x_1_0, x_1_2}}};
+  node_address node_addrs[3] = {{const_cast<char *>("127.0.0.1:12345"),
+                                 blob_1,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN},
+                                {const_cast<char *>("127.0.0.1:12343"),
+                                 blob_2,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN},
+                                {const_cast<char *>("127.0.0.1:12341"),
+                                 blob_3,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN}};
 
   site_def *site_config = new_site_def();
   init_site_def(3, node_addrs, site_config);
@@ -1287,7 +1415,7 @@ TEST_F(XComControlTest, FailedNodeRemovalTest) {
   free_node_set(&nodes);
 }
 
-void check_view_ok(const Gcs_view &view) {
+void check_view_ok(const Gcs_view &view, const Exchanged_data &) {
   ASSERT_EQ(view.get_error_code(), Gcs_view::OK);
 }
 
@@ -1309,7 +1437,7 @@ TEST_F(XComControlTest, FailedNodeGlobalViewTest) {
 
   EXPECT_CALL(mock_ev_listener, on_view_changed(_, _))
       .Times(1)
-      .WillOnce(WithArgs<0>(Invoke(check_view_ok)));
+      .WillOnce(Invoke(check_view_ok));
 
   Gcs_xcom_uuid uuid_1 = Gcs_xcom_uuid::create_uuid();
   blob blob_1 = {{0, static_cast<char *>(malloc(uuid_1.actual_value.size()))}};
@@ -1321,9 +1449,14 @@ TEST_F(XComControlTest, FailedNodeGlobalViewTest) {
   uuid_2.encode(reinterpret_cast<uchar **>(&blob_2.data.data_val),
                 &blob_2.data.data_len);
 
-  node_address node_addrs[2] = {
-      {const_cast<char *>("127.0.0.1:12345"), blob_1, {x_1_0, x_1_2}},
-      {const_cast<char *>("127.0.0.1:12343"), blob_2, {x_1_0, x_1_2}}};
+  node_address node_addrs[2] = {{const_cast<char *>("127.0.0.1:12345"),
+                                 blob_1,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN},
+                                {const_cast<char *>("127.0.0.1:12343"),
+                                 blob_2,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN}};
 
   site_def *site_config = new_site_def();
   init_site_def(2, node_addrs, site_config);
@@ -1927,7 +2060,6 @@ TEST_F(XComControlTest, ParallellJoinsTest) {
   EXPECT_CALL(proxy, test_xcom_tcp_connection(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_remove_node(_, _)).Times(1);
-  EXPECT_CALL(proxy, xcom_wait_for_xcom_comms_status_change(_)).Times(1);
   EXPECT_CALL(proxy, xcom_wait_ready()).Times(1);
   EXPECT_CALL(proxy, xcom_init(_)).Times(1);
   EXPECT_CALL(proxy, xcom_exit()).Times(0);
@@ -2170,8 +2302,10 @@ TEST_F(XComControlTest, LocalViewAfterExpel) {
   uuid.encode(reinterpret_cast<uchar **>(&blob.data.data_val),
               &blob.data.data_len);
 
-  node_address node_addrs[1] = {
-      {const_cast<char *>(member_id_2.c_str()), blob, {x_1_0, x_1_2}}};
+  node_address node_addrs[1] = {{const_cast<char *>(member_id_2.c_str()),
+                                 blob,
+                                 {x_1_0, x_1_2},
+                                 P_PROP | P_ACC | P_LEARN}};
 
   site_def *site_config = new_site_def();
   init_site_def(1, node_addrs, site_config);
@@ -2229,9 +2363,9 @@ TEST_F(XComControlTest, LocalViewAfterExpel) {
 
    Upon receiving V2, does NOT expel `suspect_1`. The only reason to expel
    `suspect_1` is because the view states that there is a majority of members
-   alive, `(me, suspect_2)` vs. `{suspect_1}`. But we have already ordered the
-   expel of `suspect_2`, so it should be counted as if it is failed. In this
-   case, there is no majority, `(me)` vs. `{suspect_1, suspect_2}`, so
+   alive, `(me, suspect_2)` vs. `{suspect_1}`. But we have already ordered
+   the expel of `suspect_2`, so it should be counted as if it is failed. In
+   this case, there is no majority, `(me)` vs. `{suspect_1, suspect_2}`, so
    `suspect_1` should not be expelled.
 
    Upon receiving V3, expels `me`, due to the `force_remove` flag in the
@@ -2247,13 +2381,14 @@ TEST_F(XComControlTest, DoNotDisbandEntireGroup) {
   xcom_nodes.add_node(Gcs_xcom_node_information("127.0.0.1:12346", true));
   xcom_nodes.add_node(Gcs_xcom_node_information("127.0.0.1:12347", true));
 
-  auto suspect_is_me = [suspect = me.get()](node_list *nl) -> bool {
+  auto suspect_is_me = [suspect = me.get()](node_list *nl, uint32_t) -> bool {
     EXPECT_EQ(nl->node_list_len, 1);
     EXPECT_EQ(std::string{nl->node_list_val[0].address},
               suspect->get_member_id());
     return true;
   };
-  auto suspect_is_2 = [suspect = suspect_2.get()](node_list *nl) -> bool {
+  auto suspect_is_2 = [suspect = suspect_2.get()](node_list *nl,
+                                                  uint32_t) -> bool {
     EXPECT_EQ(nl->node_list_len, 1);
     EXPECT_EQ(std::string{nl->node_list_val[0].address},
               suspect->get_member_id());
@@ -2265,8 +2400,8 @@ TEST_F(XComControlTest, DoNotDisbandEntireGroup) {
   EXPECT_CALL(proxy, xcom_client_boot(_, _)).Times(1);
   EXPECT_CALL(proxy, xcom_client_remove_node(_, _))
       .Times(2)  // once for expulsion, once for leave
-      .WillOnce(WithArgs<0>(Invoke(suspect_is_2)))
-      .WillOnce(WithArgs<0>(Invoke(suspect_is_me)));
+      .WillOnce(Invoke(suspect_is_2))
+      .WillOnce(Invoke(suspect_is_me));
   EXPECT_CALL(proxy, delete_node_address(_, _))
       .Times(3);  // once for boot, once for expulsion, once for leave
 
