@@ -1,17 +1,16 @@
 /*
-   Copyright (c) 2001, 2024, Oracle and/or its affiliates.
+   Copyright (c) 2001, 2023, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is designed to work with certain software (including
+   This program is also distributed with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have either included with
-   the program or referenced in the documentation.
+   separately licensed software that they have included with MySQL.
 
    Without limiting anything contained in the foregoing, this file,
    which is part of C Driver for MySQL (Connector/C), is also subject to the
@@ -48,6 +47,7 @@
 
 #include <algorithm>
 
+#include "m_string.h"
 #include "my_compiler.h"
 #include "my_dbug.h"
 #include "my_inttypes.h"
@@ -180,7 +180,7 @@ size_t vio_read_buff(Vio *vio, uchar *buf, size_t size) {
   size_t rc;
 #define VIO_UNBUFFERED_READ_MIN_SIZE 2048
   DBUG_TRACE;
-  DBUG_PRINT("enter", ("sd: %d  buf: %p  size: %u",
+  DBUG_PRINT("enter", ("sd: " MY_SOCKET_FMT "  buf: %p  size: %u",
                        mysql_socket_getfd(vio->mysql_socket), buf, (uint)size));
 
   if (vio->read_pos < vio->read_end) {
@@ -259,8 +259,8 @@ int vio_set_blocking(Vio *vio, bool status) {
   {
     int flags;
 
-    if ((flags = fcntl(mysql_socket_getfd(vio->mysql_socket), F_GETFL, NULL)) <
-        0)
+    if ((flags = fcntl(mysql_socket_getfd(vio->mysql_socket), F_GETFL,
+                       nullptr)) < 0)
       return -1;
 
     /*
@@ -401,7 +401,7 @@ int vio_keepalive(Vio *vio, bool set_keep_alive) {
   uint opt = 0;
   DBUG_TRACE;
   DBUG_PRINT("enter",
-             ("sd: %d  set_keep_alive: %d",
+             ("sd: " MY_SOCKET_FMT "  set_keep_alive: %d",
               mysql_socket_getfd(vio->mysql_socket), (int)set_keep_alive));
   if (vio->type != VIO_TYPE_NAMEDPIPE) {
     if (set_keep_alive) opt = 1;
@@ -448,7 +448,7 @@ static void vio_wait_until_woken(Vio *vio) {
   if (vio->kq_fd != -1) {
     struct kevent kev;
 
-    EV_SET(&kev, WAKEUP_EVENT_ID, EVFILT_USER, 0, NOTE_TRIGGER, 0, NULL);
+    EV_SET(&kev, WAKEUP_EVENT_ID, EVFILT_USER, 0, NOTE_TRIGGER, 0, nullptr);
     int nev = kevent(vio->kq_fd, &kev, 1, nullptr, 0, nullptr);
     if (nev != -1) {
       while (vio->kevent_wakeup_flag.test_and_set()) {
@@ -947,7 +947,7 @@ int vio_io_wait(Vio *vio, enum enum_vio_io_event event, int timeout) {
   /* The first argument is ignored on Windows. */
   do {
     ret = select((int)(fd + 1), &readfds, &writefds, &exceptfds,
-                 (timeout >= 0) ? &tm : NULL);
+                 (timeout >= 0) ? &tm : nullptr);
   } while (ret < 0 && vio_should_retry(vio) &&
            (retry_count++ < vio->retry_count));
 
